@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2021 the Claws Mail Team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -363,7 +363,9 @@ static gchar *parse_action_cmd(gchar *action, MsgInfo *msginfo,
 		return NULL;
 	}
 
-	return g_string_free(cmd, FALSE);
+	p = cmd->str;
+	g_string_free(cmd, FALSE);
+	return p;
 }
 
 static gboolean parse_append_filename(GString *cmd, MsgInfo *msginfo)
@@ -957,12 +959,9 @@ static ChildInfo *fork_child(gchar *cmd, const gchar *msg_str,
 	ret_str = g_locale_from_utf8(cmd, strlen(cmd),
 				     &by_read, &by_written,
 				     NULL);
-	if (!ret_str || !by_written) {
-		if (ret_str)
-			g_free(ret_str);
+	if (!ret_str || !by_written)
 		ret_str = g_strdup(cmd);
-	}
-    
+
 	trim_cmd = ret_str;
 
 	while (g_ascii_isspace(trim_cmd[0]))
@@ -1043,13 +1042,11 @@ static ChildInfo *fork_child(gchar *cmd, const gchar *msg_str,
 		int r;
 		ret_str = g_locale_from_utf8(msg_str, strlen(msg_str),
 					     &by_read, &by_written, NULL);
-		if (ret_str && by_written)
+		if (ret_str && by_written) {
 			r = write(chld_in, ret_str, strlen(ret_str));
-		else
-			r = write(chld_in, msg_str, strlen(msg_str));
-		if (ret_str)
 			g_free(ret_str);
-
+		} else
+			r = write(chld_in, msg_str, strlen(msg_str));
 		if (!(children->action_type &
 		      (ACTION_USER_IN | ACTION_USER_HIDDEN_IN)))
 			r = close(chld_in);
@@ -1147,7 +1144,7 @@ static gint io_dialog_key_pressed_cb(GtkWidget *widget, GdkEventKey *event,
 {
 	if (event && (event->keyval == GDK_KEY_Escape ||
 		      event->keyval == GDK_KEY_Return ||
-		      event->keyval == GDK_KEY_KP_Enter))
+			  event->keyval == GDK_KEY_KP_Enter))
 		hide_io_dialog_cb(widget, data);
 	return TRUE;
 }
@@ -1221,6 +1218,7 @@ static void update_io_dialog(Children *children)
 		text = g_strdup_printf(format, _("Completed"), 
 				       children->initial_nb - children->nb,
 				       children->initial_nb);
+		gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(children->progress_bar), TRUE);
 		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(children->progress_bar), text);
 		g_free(text);
 	}
@@ -1278,8 +1276,8 @@ static void actions_io_size_allocate_cb(GtkWidget *widget,
 {
 	cm_return_if_fail(allocation != NULL);
 
-	prefs_common.actionsiodialog_width = allocation->width;
-	prefs_common.actionsiodialog_height = allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+		&prefs_common.actionsiodialog_width, &prefs_common.actionsiodialog_height);
 }
 
 static void create_io_dialog(Children *children)
@@ -1315,7 +1313,7 @@ static void create_io_dialog(Children *children)
 	g_signal_connect(G_OBJECT(dialog), "size_allocate",
 			 G_CALLBACK(actions_io_size_allocate_cb), NULL);
 
-	vbox = gtk_vbox_new(FALSE, 8);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 8);
 	gtk_container_add(GTK_CONTAINER(
 				gtk_dialog_get_content_area(GTK_DIALOG(dialog))), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
@@ -1331,6 +1329,7 @@ static void create_io_dialog(Children *children)
 				       GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
 					    GTK_SHADOW_IN);
+	gtk_scrolled_window_set_propagate_natural_height(GTK_SCROLLED_WINDOW(scrolledwin), TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledwin, TRUE, TRUE, 0);
 	gtk_widget_hide(scrolledwin);
 
@@ -1341,7 +1340,7 @@ static void create_io_dialog(Children *children)
 		font_desc = pango_font_description_from_string
 			(prefs_common.textfont);
 		if (font_desc) {
-			gtk_widget_modify_font(text, font_desc);
+			gtk_widget_override_font(text, font_desc);
 			pango_font_description_free(font_desc);
 		}
 	}
@@ -1354,7 +1353,7 @@ static void create_io_dialog(Children *children)
 	gtk_widget_show(text);
 
 	if (children->open_in) {
-		input_hbox = gtk_hbox_new(FALSE, 8);
+		input_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show(input_hbox);
 
 		entry = gtk_entry_new();
@@ -1367,7 +1366,7 @@ static void create_io_dialog(Children *children)
 		}
 		gtk_widget_show(entry);
 
-		send_button = gtk_button_new_from_stock(GTK_STOCK_EXECUTE);
+		send_button = gtkut_stock_button("system-run");
 		g_signal_connect(G_OBJECT(send_button), "clicked",
 				 G_CALLBACK(send_input), children);
 		gtk_box_pack_start(GTK_BOX(input_hbox), send_button, FALSE,
@@ -1388,8 +1387,11 @@ static void create_io_dialog(Children *children)
 #endif
 		
 		progress_bar = gtk_progress_bar_new();
-		gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(progress_bar),
-				GTK_PROGRESS_LEFT_TO_RIGHT);
+		gtk_orientable_set_orientation(GTK_ORIENTABLE(progress_bar),
+				GTK_ORIENTATION_HORIZONTAL);
+		gtk_progress_bar_set_inverted(GTK_PROGRESS_BAR(progress_bar),
+				FALSE);
+
 		text = g_strdup_printf(format, _("Completed"), 
 		                       children->initial_nb);
 		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progress_bar),
@@ -1399,8 +1401,8 @@ static void create_io_dialog(Children *children)
 		gtk_widget_show(progress_bar);
 	}
 
-	gtkut_stock_button_set_create(&hbox, &abort_button, GTK_STOCK_STOP,
-				      &close_button, GTK_STOCK_CLOSE, NULL, NULL);
+	gtkut_stock_button_set_create(&hbox, &abort_button, "process-stop",
+				      &close_button, _("_Close"), NULL, NULL);
 	g_signal_connect(G_OBJECT(abort_button), "clicked",
 			 G_CALLBACK(kill_children_cb), children);
 	g_signal_connect(G_OBJECT(close_button), "clicked",
@@ -1420,7 +1422,7 @@ static void create_io_dialog(Children *children)
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(dialog), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
-	gtk_widget_set_size_request(dialog, prefs_common.actionsiodialog_width,
+	gtk_window_set_default_size(GTK_WINDOW(dialog), prefs_common.actionsiodialog_width,
 				    prefs_common.actionsiodialog_height);
 
 	gtk_widget_show(dialog);
@@ -1518,12 +1520,9 @@ static void catch_input(gpointer data, gint source, GIOCondition cond)
 				       0, -1);
 	ret_str = g_locale_from_utf8(input, strlen(input), &by_read,
 				     &by_written, NULL);
-	if (ret_str) {
-		if (by_written) {
-			g_free(input);
-			input = ret_str;
-		} else
-			g_free(ret_str);
+	if (ret_str && by_written) {
+		g_free(input);
+		input = ret_str;
 	}
 
 	len = strlen(input);
@@ -1574,18 +1573,18 @@ static void catch_output(gpointer data, gint source, GIOCondition cond)
 			gchar *ret_str;
 
 			c = read(source, buf, sizeof(buf) - 1);
-			if (c <= 0)
+			if (c == 0)
 				break;
 
-			buf[c] = 0;
 			ret_str = g_locale_to_utf8
-				(buf, c, &bytes_read, &bytes_written, NULL);
-			if (ret_str && bytes_written > 0)
-				gtk_text_buffer_insert(textbuf, &iter, ret_str, -1);
-			else
-				gtk_text_buffer_insert(textbuf, &iter, buf, c);
-			if (ret_str)
+				(buf, c - 1, &bytes_read, &bytes_written, NULL);
+			if (ret_str && bytes_written > 0) {
+				gtk_text_buffer_insert
+					(textbuf, &iter, ret_str,
+					 -1);
 				g_free(ret_str);
+			} else
+				gtk_text_buffer_insert(textbuf, &iter, buf, c - 1);
 		}
 
 		if (child_info->children->is_selection) {
@@ -1601,15 +1600,12 @@ static void catch_output(gpointer data, gint source, GIOCondition cond)
 			gsize bytes_read = 0, bytes_written = 0;
 			gchar *ret_str;
 
-			buf[c] = 0;
 			ret_str = g_locale_to_utf8
 				(buf, c, &bytes_read, &bytes_written, NULL);
-			if (ret_str) {
-				if (bytes_written) {
-					g_string_append_len
-						(child_info->output, ret_str,
-						bytes_written);
-				}
+			if (ret_str && bytes_written > 0) {
+				g_string_append_len
+					(child_info->output, ret_str,
+					 bytes_written);
 				g_free(ret_str);
 			} else
 				g_string_append_len(child_info->output, buf, c);
@@ -1659,7 +1655,7 @@ static gchar *get_user_string(const gchar *action, ActionType type)
 			(_("Action's user argument"), message, NULL);
 		break;
 	default:
-		g_warning("unsupported action type %d", type);
+		g_warning("Unsupported action type %d", type);
 	}
 
 	return user_str;
