@@ -392,7 +392,7 @@ static void read_address_book(gchar *folderpath) {
 	
 	addrcompl_initialize();
 	if (! addrindex_dbus_load_completion(add_address, &error)) {
-		g_warning("failed to populate address completion list");
+		g_warning("Failed to populate address completion list");
         g_error_free(error);
 		return;
 	}
@@ -958,13 +958,12 @@ static void completion_window_advance_selection(GtkTreeView *list_view, gboolean
 static void addrcompl_resize_window( CompletionWindow *cw ) {
 	GtkRequisition r;
 	GdkGrabStatus status;
-	gint x, y, width, height, depth;
+	gint x, y, width, height;
 
-	/* Get current geometry of window */
-	gdk_window_get_geometry( gtk_widget_get_window( cw->window ), &x, &y, &width, &height, &depth );
+	gdk_window_get_geometry( gtk_widget_get_window( cw->window ), &x, &y, &width, &height );
 
 	gtk_widget_queue_resize_no_redraw(cw->list_view);
-	gtk_widget_size_request( cw->list_view, &r );
+	gtk_widget_get_preferred_size( cw->list_view, &r, NULL);
 
 	/* Adjust window height to available screen space */
 	if( y + r.height > gdk_screen_height())
@@ -1456,13 +1455,13 @@ static gboolean address_completion_complete_address_in_entry(GtkEntry *entry,
  */
 static void address_completion_create_completion_window( GtkEntry *entry_ )
 {
-	gint x, y, height, width, depth;
+	gint x, y;
+	GdkRectangle rect;
 	GtkWidget *scroll, *list_view;
 	GdkGrabStatus status;
 	GtkRequisition r;
 	GtkWidget *window;
 	GtkWidget *entry = GTK_WIDGET(entry_);
-	GdkWindow *gdkwin;
 
 	/* Create new window and list */
 	window = gtk_window_new(GTK_WINDOW_POPUP);
@@ -1485,18 +1484,24 @@ static void address_completion_create_completion_window( GtkEntry *entry_ )
 	gtk_container_add(GTK_CONTAINER(scroll), list_view);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scroll),
 		GTK_SHADOW_OUT);
-	/* Use entry widget to create initial window */
-	gdkwin = gtk_widget_get_window(entry),
-	gdk_window_get_geometry(gdkwin, &x, &y, &width, &height, &depth);
-	gdk_window_get_origin (gdkwin, &x, &y);
-	y += height;
-	gtk_window_move(GTK_WINDOW(window), x, y);
+
+	/* Use entry widget to position initial window */
+	gtk_widget_get_allocation(entry, &rect);
+
+	/* rect.x and rect.y are relative to parent of our GtkEntry,
+	 * we need to convert them to absolute coordinates */
+	gdk_window_get_root_coords(
+			gtk_widget_get_window(gtk_widget_get_parent(entry)),
+			rect.x, rect.y, &x, &y);
+
+	/* Move the window to just below the GtkEntry */
+	gtk_window_move(GTK_WINDOW(window), x, y + rect.height);
 
 	/* Resize window to fit initial (empty) address list */
-	gtk_widget_size_request( list_view, &r );
-	gtk_widget_set_size_request( window, width, r.height );
+	gtk_widget_get_preferred_size( list_view, &r, NULL);
+	gtk_widget_set_size_request( window, rect.width, r.height );
 	gtk_widget_show_all( window );
-	gtk_widget_size_request( list_view, &r );
+	gtk_widget_get_preferred_size( list_view, &r, NULL );
 
 	/* Setup handlers */
 	g_signal_connect(G_OBJECT(list_view), "button_press_event",
