@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2024 the Claws Mail team and Match Grun
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 2001-2019 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /*
@@ -160,8 +159,8 @@ static void addressadd_size_allocate_cb(GtkWidget *widget,
 {
 	cm_return_if_fail(allocation != NULL);
 
-	prefs_common.addressaddwin_width = allocation->width;
-	prefs_common.addressaddwin_height = allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+		&prefs_common.addressaddwin_width, &prefs_common.addressaddwin_height);
 }
 
 static void addressadd_create( void ) {
@@ -180,7 +179,6 @@ static void addressadd_create( void ) {
 	GtkWidget *hbbox;
 	GtkWidget *ok_btn;
 	GtkWidget *cancel_btn;
-	gint top;
 	static GdkGeometry geometry;
 	GtkTreeStore *store;
 	GtkTreeViewColumn *col;
@@ -199,18 +197,18 @@ static void addressadd_create( void ) {
 	g_signal_connect(G_OBJECT(window), "size_allocate",
 			 G_CALLBACK(addressadd_size_allocate_cb), NULL);
 	
-	hbox = gtk_hbox_new(FALSE, 10);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
-	vbox = gtk_vbox_new(FALSE, 8);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 8);
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 
 	picture = gtk_image_new();
 	gtk_box_pack_start(GTK_BOX(hbox), picture, FALSE, FALSE, 0);
 
-	table = gtk_table_new(3, 2, FALSE);
+	table = gtk_grid_new();
 	gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
-	gtk_table_set_row_spacings(GTK_TABLE(table), VSPACING_NARROW);
-	gtk_table_set_col_spacings(GTK_TABLE(table), HSPACING_NARROW);
+	gtk_grid_set_row_spacing(GTK_GRID(table), VSPACING_NARROW);
+	gtk_grid_set_column_spacing(GTK_GRID(table), HSPACING_NARROW);
 
 	frame = gtk_frame_new(_("Contact"));
 	gtk_frame_set_label_align(GTK_FRAME(frame), 0.01, 0.5);
@@ -219,40 +217,41 @@ static void addressadd_create( void ) {
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
 	/* First row */
-	top = 0;
 	label = gtk_label_new(_("Name"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, top, (top + 1), GTK_FILL, 0, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(table), label, 0, 0, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	entry_name = gtk_entry_new();
 	gtk_widget_set_size_request(entry_name, 150, -1);
 	gtk_entry_set_text (GTK_ENTRY(entry_name),"");
 	
-	gtk_table_attach(GTK_TABLE(table), entry_name, 1, 2, top, (top + 1), GTK_FILL | GTK_EXPAND , 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), entry_name, 1, 0, 1, 1);
+	gtk_widget_set_hexpand(entry_name, TRUE);
+	gtk_widget_set_halign(entry_name, GTK_ALIGN_FILL);
 
 	/* Second row */
-	top = 1;
 	label = gtk_label_new(_("Address"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, top, (top + 1), GTK_FILL, 0, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), label, 0, 1, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	label_addr = gtk_label_new("");
 	gtk_widget_set_size_request(label_addr, 150, -1);
-	gtk_table_attach(GTK_TABLE(table), label_addr, 1, 2, top, (top + 1), GTK_FILL | GTK_EXPAND, 0, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label_addr), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(table), label_addr, 1, 1, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label_addr), 0.0);
 
 	/* Third row */
-	top = 2;
 	label = gtk_label_new(_("Remarks"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, top, (top + 1), GTK_FILL, 0, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(table), label, 0, 2, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	entry_rems = gtk_entry_new();
 	gtk_widget_set_size_request(entry_rems, 150, -1);
-	gtk_table_attach(GTK_TABLE(table), entry_rems, 1, 2, top, (top + 1), GTK_FILL | GTK_EXPAND, 0, 0, 0);
-	
+	gtk_grid_attach(GTK_GRID(table), entry_rems, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(entry_rems, TRUE);
+	gtk_widget_set_halign(entry_rems, GTK_ALIGN_FILL);
+
 	/* Address book/folder tree */
-	vlbox = gtk_vbox_new(FALSE, VBOX_BORDER);
+	vlbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_box_pack_start(GTK_BOX(vbox), vlbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width( GTK_CONTAINER(vlbox), 4);
 
@@ -266,8 +265,8 @@ static void addressadd_create( void ) {
 			GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER);
 
 	tree_folder = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), ADDRADD_COL_NAME, GTK_SORT_ASCENDING);
 	g_object_unref(store);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), ADDRADD_COL_NAME, GTK_SORT_ASCENDING);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tree_folder), prefs_common.use_stripes_everywhere);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree_folder), TRUE);
 	gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(tree_folder), FALSE);
@@ -298,8 +297,8 @@ static void addressadd_create( void ) {
 			G_CALLBACK(addressadd_tree_row_activated), NULL);
 
 	/* Button panel */
-	gtkut_stock_button_set_create(&hbbox, &cancel_btn, GTK_STOCK_CANCEL,
-				      &ok_btn, GTK_STOCK_OK,
+	gtkut_stock_button_set_create(&hbbox, &cancel_btn, _("_Cancel"),
+				      &ok_btn, _("_OK"),
 				      NULL, NULL);
 	gtk_box_pack_end(GTK_BOX(vbox), hbbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width( GTK_CONTAINER(hbbox), HSPACING_NARROW );
@@ -317,7 +316,8 @@ static void addressadd_create( void ) {
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(window), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
-	gtk_widget_set_size_request(window, prefs_common.addressaddwin_width,
+	gtk_window_set_default_size(GTK_WINDOW(window),
+				    prefs_common.addressaddwin_width,
 				    prefs_common.addressaddwin_height);
 
 	addressadd_dlg.window        = window;
@@ -374,7 +374,7 @@ static void addressadd_load_folder( GtkTreeIter *parent_iter,
 	gchar *name;
 	FolderInfo *fi;
 
-	list = parentFolder != NULL? parentFolder->listFolder: NULL;
+	list = parentFolder->listFolder;
 	while( list ) {
 		folder = list->data;
 		name = g_strdup( ADDRITEM_NAME(folder) );
@@ -546,7 +546,8 @@ gboolean addressadd_selection(const gchar *name, const gchar *address,
 								ADDRITEM_ID(person), ".png", NULL );
 					gdk_pixbuf_save(picture, name, "png", &error, NULL);
 					if (error) {
-						g_warning("failed to save image: %s", error->message);
+						g_warning("Failed to save image: %s",
+								error->message);
 						g_error_free(error);
 					}
 					addritem_person_set_picture( person, ADDRITEM_ID(person) ) ;
@@ -597,7 +598,7 @@ gboolean addressadd_selection(const gchar *name, const gchar *address,
 				if (server->retVal != LDAPRC_SUCCESS) {
 					alertpanel( _("Add address(es)"),
 						_("Can't add the specified address"),
-						GTK_STOCK_CLOSE, NULL, NULL, ALERTFOCUS_FIRST );
+						_("_Close"), NULL, NULL, ALERTFOCUS_FIRST );
 					return server->retVal;
 				}
 			}
