@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2022 the Claws Mail Team
+ * Copyright (C) 2002-2015 the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ const gchar *plugin_feature_names[] =
 	  N_("filtering"),
 	  N_("a privacy interface"),
 	  N_("a notifier"),
-	  N_("a utility"),
+	  N_("an utility"),
 	  N_("things"),
 	  NULL };
 
@@ -154,7 +154,6 @@ void plugin_save_list(void)
 		    (prefs_set_block_label(pfile, block) < 0)) {
 			g_warning("failed to write plugin list");
 			g_free(rcpath);
-			g_free(block);
 			return;
 		}
 		g_free(block);
@@ -584,9 +583,7 @@ static void replace_old_plugin_name(gchar *plugin_name)
 		
 		strncpy(plugin_name + offset, new_name_end, strlen(old_name_end) - 1);
 		debug_print(" to %s\n", plugin_name);
-		g_free(new_name_end);
 	}
-	g_free(old_name_end);
 }
 
 void plugin_load_all(const gchar *type)
@@ -595,17 +592,15 @@ void plugin_load_all(const gchar *type)
 	gchar buf[BUFFSIZE];
 	PrefFile *pfile;
 	gchar *error = NULL, *block;
-	gint failed = 0;
 
 	plugin_types = g_slist_append(plugin_types, g_strdup(type));
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, COMMON_RC, NULL);	
 	block = g_strconcat(PLUGINS_BLOCK_PREFIX, type, NULL);
 	if ((pfile = prefs_read_open(rcpath)) == NULL ||
-	    ((failed = prefs_set_block_label(pfile, block)) < 0)) {
+	    (prefs_set_block_label(pfile, block) < 0)) {
 		g_free(rcpath);
-		g_free(block);
-		if (!failed)
+		if (pfile)
 			prefs_file_close(pfile);
 		return;
 	}
