@@ -46,6 +46,7 @@ static gint smtp_starttls(SMTPSession *session);
 static gint smtp_auth_cram_md5(SMTPSession *session);
 static gint smtp_auth_login(SMTPSession *session);
 static gint smtp_auth_plain(SMTPSession *session);
+static gint smtp_auth_oauth2(SMTPSession *session);
 
 static gint smtp_ehlo(SMTPSession *session);
 static gint smtp_ehlo_recv(SMTPSession *session, const gchar *msg);
@@ -175,6 +176,11 @@ static gint smtp_auth(SMTPSession *session)
                  &&
 		  (session->avail_auth_type & SMTPAUTH_PLAIN) != 0)
 		smtp_auth_plain(session);
+	else if ((session->forced_auth_type == SMTPAUTH_OAUTH2
+		  || session->forced_auth_type == 0)
+                 &&
+		  (session->avail_auth_type & SMTPAUTH_OAUTH2) != 0)
+		smtp_auth_oauth2(session);
 	else if (session->forced_auth_type == 0) {
 		log_warning(LOG_PROTOCOL, _("No SMTP AUTH method available\n"));
 		return SM_AUTHFAIL;
@@ -317,6 +323,8 @@ static gint smtp_ehlo_recv(SMTPSession *session, const gchar *msg)
 				session->avail_auth_type |= SMTPAUTH_CRAM_MD5;
 			if (strcasestr(p, "DIGEST-MD5"))
 				session->avail_auth_type |= SMTPAUTH_DIGEST_MD5;
+			if (strcasestr(p, "XOAUTH2"))
+				session->avail_auth_type |= SMTPAUTH_OAUTH2;
 		}
 		if (g_ascii_strncasecmp(p, "SIZE", 4) == 0) {
 			p += 5;
@@ -391,6 +399,36 @@ static gint smtp_auth_plain(SMTPSession *session)
 	return SM_OK;
 }
 
+
+static gint smtp_auth_oauth2(SMTPSession *session)
+{
+	gchar buf[MESSAGEBUFSIZE], *b64buf, *out;
+	gint len;
+
+	session->state = SMTP_AUTH_OAUTH2;
+	session->auth_type = SMTPAUTH_OAUTH2;
+
+	memset(buf, 0, sizeof buf);
+
+	/* "user=" {User} "^Aauth=Bearer " {Access Token} "^A^A"*/
+        /* session->pass contains the OAUTH2 Access Token*/
+	len = sprintf(buf, "user=%s\1auth=Bearer %s\1\1", session->user, session->pass);
+	b64buf = g_base64_encode(buf, len);
+	out = g_strconcat("AUTH XOAUTH2 ", b64buf, NULL);
+	g_free(b64buf);
+
+	if (session_send_msg(SESSION(session), out) < 0) {
+		g_free(out);
+		return SM_ERROR;
+	}
+
+	g_free(out);
+
+	log_print(LOG_PROTOCOL, "ESMTP> [AUTH XOAUTH2]\n");
+
+	return SM_OK;
+}
+
 static gint smtp_auth_login(SMTPSession *session)
 {
 	session->state = SMTP_AUTH;
@@ -509,6 +547,7 @@ static gint smtp_session_recv_msg(Session *session, const gchar *msg)
 	case SMTP_AUTH_PLAIN:
 	case SMTP_AUTH_LOGIN_USER:
 	case SMTP_AUTH_LOGIN_PASS:
+        case SMTP_AUTH_OAUTH2:
 	case SMTP_AUTH_CRAM_MD5:
 		log_print(LOG_PROTOCOL, "ESMTP< %s\n", msg);
 		break;
@@ -631,6 +670,7 @@ static gint smtp_session_recv_msg(Session *session, const gchar *msg)
 		break;
 	case SMTP_AUTH_PLAIN:
 	case SMTP_AUTH_LOGIN_PASS:
+        case SMTP_AUTH_OAUTH2:
 	case SMTP_AUTH_CRAM_MD5:
 		ret = smtp_from(smtp_session);
 		break;
