@@ -179,7 +179,11 @@ static void gnutls_export_X509_fp(FILE *fp, gnutls_x509_crt_t x509_cert, gnutls_
 		g_warning("couldn't export cert %s (%"G_GSIZE_FORMAT")", gnutls_strerror(r), cert_size);
 		return;
 	}
-	debug_print("writing %" G_GSIZE_FORMAT " bytes\n",cert_size);
+#ifdef G_OS_WIN32
+	debug_print("writing %Iu bytes\n",cert_size);
+#else
+	debug_print("writing %zd bytes\n",cert_size);
+#endif
 	if (claws_fwrite(&output, 1, cert_size, fp) < cert_size) {
 		g_warning("failed to write cert: %d %s", errno, g_strerror(errno));
 	}
@@ -494,11 +498,6 @@ static gboolean ssl_certificate_compare (SSLCertificate *cert_a, SSLCertificate
 		return FALSE;
 	}
 
-	if (cert_size_a != cert_size_b) {
-		debug_print("sizes differ: %"G_GSIZE_FORMAT" != %"G_GSIZE_FORMAT"\n", cert_size_a, cert_size_b);
-		return FALSE;
-	}
-
 	output_a = g_malloc(cert_size_a);
 	output_b = g_malloc(cert_size_b);
 	if ((r = gnutls_x509_crt_export(cert_a->x509_cert, GNUTLS_X509_FMT_DER, output_a, &cert_size_a)) < 0) {
@@ -513,8 +512,14 @@ static gboolean ssl_certificate_compare (SSLCertificate *cert_a, SSLCertificate
 		g_free(output_b);
 		return FALSE;
 	}
+	if (cert_size_a != cert_size_b) {
+		g_warning("size differ %"G_GSIZE_FORMAT" %"G_GSIZE_FORMAT, cert_size_a, cert_size_b);
+		g_free(output_a);
+		g_free(output_b);
+		return FALSE;
+	}
 	if (memcmp(output_a, output_b, cert_size_a)) {
-		debug_print("contents differ\n");
+		g_warning("contents differ");
 		g_free(output_a);
 		g_free(output_b);
 		return FALSE;
@@ -831,7 +836,7 @@ gboolean ssl_certificate_check_chain(gnutls_x509_crt_t *certs, gint chain_len,
 		}
 
 		if (r < 0)
-			g_warning("can't read SSL_CERT_FILE '%s': %s",
+			g_warning("Can't read SSL_CERT_FILE '%s': %s",
 				claws_ssl_get_cert_file(), 
 				gnutls_strerror(r));
 	} else {
