@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -121,10 +120,10 @@ static void export_create(void)
 			 G_CALLBACK(key_pressed), NULL);
 	MANAGE_WINDOW_SIGNALS_CONNECT(window);
 
-	vbox = gtk_vbox_new(FALSE, 4);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
 
@@ -133,53 +132,47 @@ static void export_create(void)
 	gtk_label_set_line_wrap(GTK_LABEL(desc_label), TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox), desc_label, FALSE, FALSE, 0);
 
-	table = gtk_table_new(2, 3, FALSE);
+	table = gtk_grid_new();
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(table), 8);
-	gtk_table_set_row_spacings(GTK_TABLE(table), 8);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 8);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 	gtk_widget_set_size_request(table, 420, -1);
 
 	src_label = gtk_label_new(_("Source folder:"));
-	gtk_table_attach(GTK_TABLE(table), src_label, 0, 1, 0, 1,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (GTK_EXPAND|GTK_FILL), 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(src_label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(src_label), 1.0);
+	gtk_grid_attach(GTK_GRID(table), src_label, 0, 0, 1, 1);
 
 	file_label = gtk_label_new(_("Mbox file:"));
-	gtk_table_attach(GTK_TABLE(table), file_label, 0, 1, 1, 2,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (GTK_EXPAND|GTK_FILL), 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(file_label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(file_label), 1.0);
+	gtk_grid_attach(GTK_GRID(table), file_label, 0, 1, 1, 1);
 
 	src_entry = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), src_entry, 1, 2, 0, 1,
-			 (GtkAttachOptions) (GTK_EXPAND|GTK_SHRINK|GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), src_entry, 1, 0, 1, 1);
+	gtk_widget_set_hexpand(src_entry, TRUE);
+	gtk_widget_set_halign(src_entry, GTK_ALIGN_FILL);
 
 	file_entry = gtk_entry_new();
-	gtk_table_attach(GTK_TABLE(table), file_entry, 1, 2, 1, 2,
-			 (GtkAttachOptions) (GTK_EXPAND|GTK_SHRINK|GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
 	gtk_entry_set_activates_default(GTK_ENTRY(file_entry), TRUE);
+	gtk_grid_attach(GTK_GRID(table), file_entry, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(file_entry, TRUE);
+	gtk_widget_set_halign(file_entry, GTK_ALIGN_FILL);
 
 	src_button = gtkut_get_browse_directory_btn(_("_Browse"));
-	gtk_table_attach(GTK_TABLE(table), src_button, 2, 3, 0, 1,
-			 (GtkAttachOptions) (0),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), src_button, 2, 0, 1, 1);
+
 	g_signal_connect(G_OBJECT(src_button), "clicked",
 			 G_CALLBACK(export_srcsel_cb), NULL);
 
 	file_button = gtkut_get_browse_file_btn(_("B_rowse"));
-	gtk_table_attach(GTK_TABLE(table), file_button, 2, 3, 1, 2,
-			 (GtkAttachOptions) (0),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), file_button, 2, 1, 1, 1);
+
 	g_signal_connect(G_OBJECT(file_button), "clicked",
 			 G_CALLBACK(export_filesel_cb), NULL);
 
 	gtkut_stock_button_set_create(&confirm_area,
-				      &cancel_button, GTK_STOCK_CANCEL,
-				      &ok_button, GTK_STOCK_OK,
+				      &cancel_button, _("_Cancel"),
+				      &ok_button, _("_OK"),
 				      NULL, NULL);
 	gtk_box_pack_end(GTK_BOX(vbox), confirm_area, FALSE, FALSE, 0);
 	gtk_widget_grab_default(ok_button);
@@ -201,12 +194,12 @@ static void export_ok_cb(GtkWidget *widget, gpointer data)
 	srcdir = gtk_entry_get_text(GTK_ENTRY(src_entry));
 	utf8mbox = gtk_entry_get_text(GTK_ENTRY(file_entry));
 
-	if (!utf8mbox || !*utf8mbox) {
-		alertpanel_error(_("Mbox file can't be left empty."));
+	if (utf8mbox && !*utf8mbox) {
+		alertpanel_error(_("Target mbox filename can't be left empty."));
 		gtk_widget_grab_focus(file_entry);
 		return;
 	}
-	if (!srcdir || !*srcdir) {
+	if (srcdir && !*srcdir) {
 		alertpanel_error(_("Source folder can't be left empty."));
 		gtk_widget_grab_focus(src_entry);
 		return;
@@ -214,7 +207,7 @@ static void export_ok_cb(GtkWidget *widget, gpointer data)
 
 	mbox = g_filename_from_utf8(utf8mbox, -1, NULL, NULL, NULL);
 	if (!mbox) {
-		g_warning("export_ok_cb(): failed to convert character set");
+		g_warning("export_ok_cb(): failed to convert character set.");
 		mbox = g_strdup(utf8mbox);
 	}
 
@@ -253,7 +246,7 @@ static void export_filesel_cb(GtkWidget *widget, gpointer data)
 						conv_get_locale_charset_str(),
 						CS_UTF_8);
 		if (!filename) {
-			g_warning("export_filesel_cb(): failed to convert character set");
+			g_warning("export_filesel_cb(): failed to convert character set.");
 			filename = g_strdup(oldstr);
 		}
 		gtk_entry_set_text(GTK_ENTRY(file_entry), filename);
