@@ -16,7 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "defs.h"
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -541,8 +540,6 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 			} else {
 				g_warning("header '%s' not set or empty", action->header?action->header:"(null)");
 			}
-			if (header)
-				procheader_header_free(header);
 			return (errors == 0);
 		}
 	default:
@@ -600,39 +597,27 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 
 		/* debug output */
 		if (debug_filtering_session) {
-			if (matches) {
-				/* either because rule is not account-based */
-    			if (filtering->account_id == 0) {
-					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
-       					log_status_ok(LOG_DEBUG_FILTERING,
-	    						_("rule is not account-based\n"));
-                    }
+			if (matches && prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+				if (filtering->account_id == 0) {
+					log_status_ok(LOG_DEBUG_FILTERING,
+							_("rule is not account-based\n"));
 				} else {
-					/* or because it is account-based, and matching current account */
-					if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-						/* with fewer detail when rule is OK */
+					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
 						log_status_ok(LOG_DEBUG_FILTERING,
-								_("rule is account-based, "
-								"matching the account currently used to retrieve messages\n"));
-					} else {
-						if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_HIGH) {
-							/* with more detail when rule is OK */
-							log_status_ok(LOG_DEBUG_FILTERING,
-									_("rule is account-based [id=%d, name='%s'], "
-									"matching the account currently used to retrieve messages\n"),
-									ac_prefs->account_id, ac_prefs?ac_prefs->account_name:_("NON_EXISTENT"));
-						}
+								_("rule is account-based [id=%d, name='%s'], "
+								"matching the account currently used to retrieve messages\n"),
+								ac_prefs->account_id, ac_prefs?ac_prefs->account_name:_("NON_EXISTENT"));
 					}
 				}
-			} else {
-				if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-					/* with fewer detail when rule is skipped */
+			}
+			else
+			if (!matches) {
+				if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
 					log_status_skip(LOG_DEBUG_FILTERING,
 							_("rule is account-based, "
 							"not matching the account currently used to retrieve messages\n"));
 				} else {
-					if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_HIGH) {
-						/* with more detail when rule is skipped */
+					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 						PrefsAccount *account = account_find_from_id(filtering->account_id);
 
 						log_status_skip(LOG_DEBUG_FILTERING,
@@ -652,28 +637,18 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 
 			/* debug output */
 			if (debug_filtering_session) {
-				if (filtering->account_id == 0) {
-					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
-        				log_status_ok(LOG_DEBUG_FILTERING,
-		    					_("rule is not account-based, "
-			    				"but all rules are applied on user request anyway\n"));
-                    }
-				} else {
-					if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-						/* with fewer detail when rule is OK */
+				if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+					if (filtering->account_id == 0) {
 						log_status_ok(LOG_DEBUG_FILTERING,
-								_("rule is account-based, "
-								"but all rules are applied on user request anyway\n"));
+								_("rule is not account-based, "
+								"all rules are applied on user request anyway\n"));
 					} else {
-						if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-							/* with more detail when rule is OK */
-							PrefsAccount *account = account_find_from_id(filtering->account_id);
+						PrefsAccount *account = account_find_from_id(filtering->account_id);
 
-							log_status_ok(LOG_DEBUG_FILTERING,
-									_("rule is account-based [id=%d, name='%s'], "
-									"but all rules are applied on user request anyway\n"),
-									filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
-						}
+						log_status_ok(LOG_DEBUG_FILTERING,
+								_("rule is account-based [id=%d, name='%s'], "
+								"but all rules are applied on user request\n"),
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
 					}
 				}
 			}
@@ -684,27 +659,23 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 
 			/* debug output */
 			if (debug_filtering_session) {
-				if (matches) {
-					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
-    					log_status_ok(LOG_DEBUG_FILTERING,
-	    						_("rule is not account-based\n"));
-                    }
-				} else {
-					if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-						/* with fewer detail when rule is skipped */
+				if (!matches) {
+					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+						PrefsAccount *account = account_find_from_id(filtering->account_id);
+
+						log_status_skip(LOG_DEBUG_FILTERING,
+								_("rule is account-based [id=%d, name='%s'], "
+								"skipped on user request\n"),
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
+					} else {
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based, "
 								"skipped on user request\n"));
-					} else {
-						if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_HIGH) {
-							/* with more detail when rule is skipped */
-							PrefsAccount *account = account_find_from_id(filtering->account_id);
-
-							log_status_skip(LOG_DEBUG_FILTERING,
-									_("rule is account-based [id=%d, name='%s'], "
-									"skipped on user request\n"),
-									filtering->account_id, account?account->account_name:_("NON_EXISTENT"));
-						}
+					}
+				} else {
+					if (matches && prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+						log_status_ok(LOG_DEBUG_FILTERING,
+								_("rule is not account-based\n"));
 					}
 				}
 			}
@@ -715,46 +686,32 @@ static gboolean filtering_match_condition(FilteringProp *filtering, MsgInfo *inf
 
 			/* debug output */
 			if (debug_filtering_session) {
-				if (matches) {
-					if (filtering->account_id == 0) {
-						if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_MED) {
-							log_status_ok(LOG_DEBUG_FILTERING,
-									_("rule is not account-based\n"));
-                        }
-					} else {
-						if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-							/* with fewer detail when rule is OK */
-							log_status_ok(LOG_DEBUG_FILTERING,
-									_("rule is account-based, "
-									"matching current account\n"));
-						} else {
-							if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-								/* with more detail when rule is OK */
-								PrefsAccount *account = account_find_from_id(filtering->account_id);
+				if (!matches) {
+					if (prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+						PrefsAccount *account = account_find_from_id(filtering->account_id);
 
-								log_status_ok(LOG_DEBUG_FILTERING,
-										_("rule is account-based [id=%d, name='%s'], "
-										"matching current account [id=%d, name='%s']\n"),
-										account->account_id, account?account->account_name:_("NON_EXISTENT"),
-										cur_account->account_id, cur_account?cur_account->account_name:_("NON_EXISTENT"));
-							}
-						}
-					}
-				} else {
-					if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_MED) {
-						/* with fewer detail when rule is skipped */
+						log_status_skip(LOG_DEBUG_FILTERING,
+								_("rule is account-based [id=%d, name='%s'], "
+								"not matching current account [id=%d, name='%s']\n"),
+								filtering->account_id, account?account->account_name:_("NON_EXISTENT"),
+								cur_account->account_id, cur_account?cur_account->account_name:_("NON_EXISTENT"));
+					} else {
 						log_status_skip(LOG_DEBUG_FILTERING,
 								_("rule is account-based, "
 								"not matching current account\n"));
-					} else {
-						if (prefs_common.filtering_debug_level == FILTERING_DEBUG_LEVEL_HIGH) {
-							/* with more detail when rule is skipped */
+					}
+				} else {
+					if (matches && prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+						if (filtering->account_id == 0) {
+							log_status_ok(LOG_DEBUG_FILTERING,
+									_("rule is not account-based\n"));
+						} else {
 							PrefsAccount *account = account_find_from_id(filtering->account_id);
 
-							log_status_skip(LOG_DEBUG_FILTERING,
+							log_status_ok(LOG_DEBUG_FILTERING,
 									_("rule is account-based [id=%d, name='%s'], "
-									"not matching current account [id=%d, name='%s']\n"),
-									filtering->account_id, account?account->account_name:_("NON_EXISTENT"),
+									"current account [id=%d, name='%s']\n"),
+									account->account_id, account?account->account_name:_("NON_EXISTENT"),
 									cur_account->account_id, cur_account?cur_account->account_name:_("NON_EXISTENT"));
 						}
 					}
@@ -990,14 +947,13 @@ gchar *filteringaction_to_string(FilteringAction *action)
 	gchar * quoted_dest;
 	gchar * quoted_header;
 	GString *dest = g_string_new("");
+	gchar *deststr = NULL;
 
 	command_str = get_matchparser_tab_str(action->type);
 
-	if (command_str == NULL) {
-		g_string_free(dest, TRUE);
+	if (command_str == NULL)
 		return NULL;
-	}
-    
+
 	switch(action->type) {
 	case MATCHACTION_MOVE:
 	case MATCHACTION_COPY:
@@ -1052,10 +1008,11 @@ gchar *filteringaction_to_string(FilteringAction *action)
 		break;
 
 	default:
-		g_string_free(dest, TRUE);
 		return NULL;
 	}
-	return g_string_free(dest, FALSE);
+	deststr = dest->str;
+	g_string_free(dest, FALSE);
+	return deststr;
 }
 
 gchar * filteringaction_list_to_string(GSList * action_list)
@@ -1120,8 +1077,8 @@ static void prefs_filtering_free(GSList * prefs_filtering)
  	while (prefs_filtering != NULL) {
  		FilteringProp * filtering = (FilteringProp *)
 			prefs_filtering->data;
- 		prefs_filtering = g_slist_remove(prefs_filtering, filtering);
  		filteringprop_free(filtering);
+ 		prefs_filtering = g_slist_remove(prefs_filtering, filtering);
  	}
 }
 
@@ -1195,7 +1152,7 @@ gboolean filtering_action_list_rename_path(GSList *action_list, const gchar *old
 	gint destlen;
 	gint prefixlen;
 	gint oldpathlen;
-	GSList * action_cur;
+        GSList * action_cur;
 	const gchar *separator=G_DIR_SEPARATOR_S;
 	gboolean matched = FALSE;
 #ifdef G_OS_WIN32
@@ -1208,7 +1165,7 @@ again:
 		action_cur = action_cur->next) {
 
 		FilteringAction *action = action_cur->data;
-
+                        
 		if (action->type == MATCHACTION_SET_TAG ||
 		    action->type == MATCHACTION_UNSET_TAG)
 			continue;
@@ -1216,31 +1173,35 @@ again:
 			continue;
 		
 		destlen = strlen(action->destination);
-
+                        
 		if (destlen > oldpathlen) {
 			prefixlen = destlen - oldpathlen;
 			suffix = action->destination + prefixlen;
-
+                                
 			if (!strncmp(old_path, suffix, oldpathlen)) {
 				prefix = g_malloc0(prefixlen + 1);
 				strncpy2(prefix, action->destination, prefixlen);
-
+                                        
 				base = suffix + oldpathlen;
-				while (*base == G_DIR_SEPARATOR)
-					base++;
-				if (*base == '\0')
-					dest_path = g_strconcat(prefix, separator, new_path, NULL);
+				while (*base == G_DIR_SEPARATOR) base++;
+                                if (*base == '\0')
+                                	dest_path = g_strconcat(prefix, separator,
+                                				new_path, NULL);
 				else
-					dest_path = g_strconcat(prefix, separator, new_path, separator, base, NULL);
-
-				g_free(prefix);
-				g_free(action->destination);
-				action->destination = dest_path;
-				matched = TRUE;
+					dest_path = g_strconcat(prefix,
+								separator,
+								new_path,
+								separator,
+								base, NULL);
+                                        
+					g_free(prefix);
+					g_free(action->destination);
+					action->destination = dest_path;
+					matched = TRUE;
 			} else { /* for non-leaf folders */
 				/* compare with trailing slash */
 				if (!strncmp(old_path_with_sep, action->destination, oldpathlen+1)) {
-
+                                                
 					suffix = action->destination + oldpathlen + 1;
 					dest_path = g_strconcat(new_path, separator,
 								suffix, NULL);
@@ -1252,10 +1213,10 @@ again:
 		} else {
 			/* folder-moving a leaf */
 			if (!strcmp(old_path, action->destination)) {
-				dest_path = g_strdup(new_path);
-				g_free(action->destination);
-				action->destination = dest_path;
-				matched = TRUE;
+                        	dest_path = g_strdup(new_path);
+                        	g_free(action->destination);
+                        	action->destination = dest_path;
+                        	matched = TRUE;
 			}
 		}
 	}
