@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
+ * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "defs.h"
 
 #include <glib.h>
@@ -109,6 +108,9 @@ static void foldersel_cancel		(GtkButton	*button,
 static void foldersel_new_folder	(GtkButton	*button,
 					 gpointer	 data);
 
+static void foldersel_entry_activated	(GtkEntry	*entry,
+					 gpointer	 data);
+
 static void foldersel_tree_activated	(GtkTreeView		*treeview,
 					 GtkTreePath		*path,
 					 GtkTreeViewColumn	*column,
@@ -215,13 +217,10 @@ static gboolean foldersel_search_name_func(GtkTreeModel *model, gint column,
 		gtk_tree_model_get(model, iter, column, &store_string, -1);
 	}
 
-	if (!store_string)
+	if (!store_string || !key)
 		return FALSE;
 
-	if (!key)
-		retval = FALSE;
-	else
-		retval = (strcasestr(store_string, key) == NULL);
+	retval = (strcasestr(store_string, key) == NULL);
 
 	g_free(store_string);
 
@@ -233,8 +232,8 @@ static void foldersel_size_allocate_cb(GtkWidget *widget,
 {
 	cm_return_if_fail(allocation != NULL);
 
-	prefs_common.folderselwin_width = allocation->width;
-	prefs_common.folderselwin_height = allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+		&prefs_common.folderselwin_width, &prefs_common.folderselwin_height);
 }
 
 static void foldersel_create(const gchar *title)
@@ -264,7 +263,7 @@ static void foldersel_create(const gchar *title)
 			 G_CALLBACK(foldersel_size_allocate_cb), NULL);
 	MANAGE_WINDOW_SIGNALS_CONNECT(window);
 
-	vbox = gtk_vbox_new(FALSE, 4);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 
 	if (title != NULL) {
@@ -285,7 +284,7 @@ static void foldersel_create(const gchar *title)
 					G_TYPE_POINTER,
 					GDK_TYPE_PIXBUF,
 					GDK_TYPE_PIXBUF,
-					GDK_TYPE_COLOR,
+					GDK_TYPE_RGBA,
 					G_TYPE_INT);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(tree_store),
 					FOLDERSEL_FOLDERNAME,
@@ -331,7 +330,7 @@ static void foldersel_create(const gchar *title)
 	gtk_tree_view_column_set_attributes
 		(column, renderer,
 		 "text", FOLDERSEL_FOLDERNAME,
-		 "foreground-gdk", FOLDERSEL_FOREGROUND,
+		 "foreground-rgba", FOLDERSEL_FOREGROUND,
 		 "weight", FOLDERSEL_BOLD,
 		 NULL);
 	g_object_set(G_OBJECT(renderer), "weight", PANGO_WEIGHT_BOLD, NULL);
@@ -343,11 +342,13 @@ static void foldersel_create(const gchar *title)
 	statusbar_cid = gtk_statusbar_get_context_id(
 		        GTK_STATUSBAR(statusbar), "Select Folder Dialog" );
 	gtk_box_pack_start(GTK_BOX(vbox), statusbar, FALSE, FALSE, 0);
+	g_signal_connect(G_OBJECT(statusbar), "activate",
+			 G_CALLBACK(foldersel_entry_activated), NULL);
 
 	gtkut_stock_button_set_create(&confirm_area,
-				      &new_button,    GTK_STOCK_NEW,
-				      &cancel_button, GTK_STOCK_CANCEL,
-				      &ok_button,     GTK_STOCK_OK);
+				      &new_button,    _("_New"),
+				      &cancel_button, _("_Cancel"),
+				      &ok_button,     _("_OK"));
 
 	gtk_box_pack_end(GTK_BOX(vbox), confirm_area, FALSE, FALSE, 0);
 	gtk_widget_grab_default(ok_button);
@@ -366,7 +367,8 @@ static void foldersel_create(const gchar *title)
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(window), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
-	gtk_widget_set_size_request(window, prefs_common.folderselwin_width,
+	gtk_window_set_default_size(GTK_WINDOW(window),
+				    prefs_common.folderselwin_width,
 				    prefs_common.folderselwin_height);
 
 	gtk_widget_show_all(vbox);
@@ -400,11 +402,8 @@ static void foldersel_append_item(GtkTreeStore *store, FolderItem *item,
 	GdkPixbuf *pixbuf, *pixbuf_open;
 	gboolean use_color;
 	PangoWeight weight = PANGO_WEIGHT_NORMAL;
-	GdkColor *foreground = NULL;
-	static GdkColor color_noselect = {0, COLOR_DIM, COLOR_DIM, COLOR_DIM};
-	static GdkColor color_new;
-
-	gtkut_convert_int_to_gdk_color(prefs_common.color[COL_NEW], &color_new);
+	GdkRGBA *foreground = NULL;
+	GdkRGBA color_noselect = {COLOR_DIM, COLOR_DIM, COLOR_DIM, 1.0};
 
 	name = folder_item_get_name(item);
 
@@ -439,7 +438,7 @@ static void foldersel_append_item(GtkTreeStore *store, FolderItem *item,
 	if (item->no_select)
 		foreground = &color_noselect;
 	else if (use_color)
-		foreground = &color_new;
+		foreground = &prefs_common.color[COL_NEW];
 
 	/* insert this node */
 	gtk_tree_store_append(store, iter, parent);
@@ -629,6 +628,11 @@ static void foldersel_new_folder(GtkButton *button, gpointer data)
 	folder_write_list();
 }
 
+static void foldersel_entry_activated(GtkEntry *entry, gpointer data)
+{
+	gtk_button_clicked(GTK_BUTTON(ok_button));
+}
+
 static void foldersel_tree_activated(GtkTreeView *treeview, GtkTreePath *path,
 				     GtkTreeViewColumn *column, gpointer data)
 {
