@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -141,8 +141,8 @@ GSList *grouplist_dialog(Folder *folder)
 
 static void grouplist_dialog_create(void)
 {
-	GtkWidget *vbox;
-	GtkWidget *hbox;
+	GtkWidget *grid;
+	GtkWidget *hgrid;
 	GtkWidget *msg_label;
 	GtkWidget *search_button;
 	GtkWidget *confirm_area;
@@ -167,36 +167,47 @@ static void grouplist_dialog_create(void)
 			 G_CALLBACK(grouplist_size_allocate), NULL);
 	MANAGE_WINDOW_SIGNALS_CONNECT(dialog);
 
-	vbox = gtk_vbox_new(FALSE, 8);
+	grid = gtk_grid_new();
+	gtk_grid_set_row_spacing(GTK_GRID(grid), 8);
+	gtk_container_set_border_width(GTK_CONTAINER(grid), 8);
+	gtk_orientable_set_orientation(GTK_ORIENTABLE(grid),
+			GTK_ORIENTATION_VERTICAL);
 	gtk_container_add(GTK_CONTAINER(
-				gtk_dialog_get_content_area(GTK_DIALOG(dialog))), vbox);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
-
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+				gtk_dialog_get_content_area(GTK_DIALOG(dialog))), grid);
 
 	msg_label = gtk_label_new(_("Select newsgroups for subscription:"));
-	gtk_box_pack_start(GTK_BOX(hbox), msg_label, FALSE, FALSE, 0);
+	gtk_widget_set_hexpand(msg_label, TRUE);
+	gtk_widget_set_vexpand(msg_label, FALSE);
+	gtk_widget_set_halign(msg_label, GTK_ALIGN_START);
+	gtk_container_add(GTK_CONTAINER(grid), msg_label);
 
-	hbox = gtk_hbox_new(FALSE, 8);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	hgrid = gtk_grid_new();
+	gtk_grid_set_column_spacing(GTK_GRID(hgrid), 8);
+	gtk_orientable_set_orientation(GTK_ORIENTABLE(hgrid),
+			GTK_ORIENTATION_HORIZONTAL);
+	gtk_widget_set_hexpand(hgrid, TRUE);
+	gtk_widget_set_vexpand(hgrid, FALSE);
+	gtk_container_add(GTK_CONTAINER(grid), hgrid);
 
 	msg_label = gtk_label_new(_("Find groups:"));
-	gtk_box_pack_start(GTK_BOX(hbox), msg_label, FALSE, FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(hgrid), msg_label);
 
 	entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+	gtk_widget_set_hexpand(entry, TRUE);
+	gtk_container_add(GTK_CONTAINER(hgrid), entry);
 	g_signal_connect(G_OBJECT(entry), "activate",
 			 G_CALLBACK(entry_activated), NULL);
 
 	search_button = gtk_button_new_with_label(_(" Search "));
-	gtk_box_pack_start(GTK_BOX(hbox), search_button, FALSE, FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(hgrid), search_button);
 
 	g_signal_connect(G_OBJECT(search_button), "clicked",
 			 G_CALLBACK(search_clicked), NULL);
 
 	scrolledwin = gtk_scrolled_window_new(NULL, NULL);
-	gtk_box_pack_start(GTK_BOX (vbox), scrolledwin, TRUE, TRUE, 0);
+	gtk_widget_set_hexpand(scrolledwin, TRUE);
+	gtk_widget_set_vexpand(scrolledwin, TRUE);
+	gtk_container_add(GTK_CONTAINER(grid), scrolledwin);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (scrolledwin),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
@@ -219,16 +230,16 @@ static void grouplist_dialog_create(void)
 	g_signal_connect(G_OBJECT(ctree), "button-press-event",
 			 G_CALLBACK(button_press_cb), NULL);
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-
 	status_label = gtk_label_new("");
-	gtk_box_pack_start(GTK_BOX(hbox), status_label, FALSE, FALSE, 0);
+	gtk_widget_set_hexpand(status_label, TRUE);
+	gtk_widget_set_vexpand(status_label, FALSE);
+	gtk_widget_set_halign(status_label, GTK_ALIGN_START);
+	gtk_container_add(GTK_CONTAINER(grid), status_label);
 
 	gtkut_stock_button_set_create(&confirm_area,
-				      &refresh_button, GTK_STOCK_REFRESH,
-				      &cancel_button, GTK_STOCK_CANCEL,
-				      &ok_button, GTK_STOCK_OK);
+				      &refresh_button, "view-refresh",
+				      &cancel_button, _("_Cancel"),
+				      &ok_button, _("_OK"));
 	gtk_container_add(GTK_CONTAINER(gtk_dialog_get_action_area(GTK_DIALOG(dialog))),
 			  confirm_area);
 	gtk_widget_grab_default(ok_button);
@@ -345,7 +356,7 @@ static GtkCMCTreeNode *grouplist_create_branch(NewsGroupInfo *ginfo,
 	else if (ginfo->type == 'm')
 		cols[2] = _("moderated");
 	else if (ginfo->type == 'n')
-		cols[2] = _("read-only");
+		cols[2] = _("readonly");
 	else
 		cols[2] = _("unknown");
 
@@ -378,7 +389,7 @@ static GtkCMCTreeNode *grouplist_create_branch(NewsGroupInfo *ginfo,
 
 static void grouplist_expand_upwards(GtkCMCTree *ctree, const gchar *name) {
 	const gchar *ptr;
-	gchar *newname=g_malloc0(strlen(name) + 1);
+	gchar *newname=g_malloc0(strlen(name));
 	GtkCMCTreeNode *node;
 
 	for (ptr=name; *ptr; ptr++) {
@@ -406,9 +417,10 @@ static void grouplist_dialog_set_list(const gchar *pattern, gboolean refresh)
 	if (!pattern || *pattern == '\0')
 		pattern = "*";
 
-	if (!watch_cursor)
-		watch_cursor = gdk_cursor_new(GDK_WATCH);
 	window = gtk_widget_get_window(dialog);
+	if (!watch_cursor)
+		watch_cursor = gdk_cursor_new_for_display(
+				gdk_window_get_display(window), GDK_WATCH);
 	gdk_window_set_cursor(window, watch_cursor);
 	main_window_cursor_wait(mainwindow_get_mainwindow());
 	GTK_EVENTS_FLUSH();
@@ -440,11 +452,8 @@ static void grouplist_dialog_set_list(const gchar *pattern, gboolean refresh)
 
 	for (cur = group_list; cur != NULL ; cur = cur->next) {
 		NewsGroupInfo *ginfo = (NewsGroupInfo *)cur->data;
-#if GLIB_CHECK_VERSION(2,70,0)
-		if (g_pattern_spec_match_string(pspec, ginfo->name)) {
-#else
+
 		if (g_pattern_match_string(pspec, ginfo->name)) {
-#endif
 			node = grouplist_create_branch(ginfo, pattern);
 			if (g_slist_find_custom(subscribed, ginfo->name,
 						(GCompareFunc)g_ascii_strcasecmp)
@@ -508,8 +517,8 @@ static void grouplist_size_allocate(GtkWidget *widget, GtkAllocation *allocation
 {
 	cm_return_if_fail( allocation != NULL );
 	
-	prefs_common.news_subscribe_width	= allocation->width;
-	prefs_common.news_subscribe_height	= allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+		&prefs_common.news_subscribe_width, &prefs_common.news_subscribe_height);
 }
 
 static gint window_deleted(GtkWidget *widget, GdkEventAny *event, gpointer data)
@@ -590,8 +599,8 @@ static gboolean button_press_cb(GtkCMCTree *ctree, GdkEventButton *button,
 	list = g_slist_find_custom(subscribed, ginfo->name,
 				   (GCompareFunc)g_ascii_strcasecmp);
 	if (list) {
-		subscribed = g_slist_remove(subscribed, list->data);
 		g_free(list->data);
+		subscribed = g_slist_remove(subscribed, list->data);
 		gtk_cmclist_unselect_row(GTK_CMCLIST(ctree), row, 0);
 	} else {
 		subscribed = g_slist_append(subscribed, g_strdup(ginfo->name));
