@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2012 Hiroyuki Yamamoto & The Claws Mail Team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 2001-2018 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /* (alfons) - based on a contribution by Satoshi Nagayasu; revised for colorful 
@@ -22,7 +21,6 @@
  * file is just that it make it easier to allow "user changeable" label colors.
  */
 
-#include "config.h"
 #include "defs.h"
 
 #include <glib.h>
@@ -53,22 +51,23 @@ static gchar *labels[COLORLABELS] = {
 	N_("Magenta")
 };
 
-static GdkColor default_colors[COLORLABELS] = {
-	{ 0, 0xffff, (0x99 << 8), 0x0 },
-	{ 0, 0xffff, 0x0, 0x0 },
-	{ 0, 0xffff, (0x66 << 8), 0xffff },
-	{ 0, 0x0, (0xcc << 8), 0xffff },
-	{ 0, 0x0, 0x0, 0xffff },
-	{ 0, 0x0, (0x99 << 8), 0x0 },
-	{ 0, (0x66 << 8), (0x33 << 8), (0x33 << 8) },
-	{ 0, (0xaa << 8), (0xaa << 8), (0xaa << 8) },
-	{ 0, (0xc0 << 8), (0x72 << 8), (0x54 << 8) },
-	{ 0, (0xc0 << 8), 0x0, 0x0 },
-	{ 0, (0xcc << 8), (0x10 << 8), (0x74 << 8) },
-	{ 0, (0x50 << 8), (0x94 << 8), (0xcd << 8) },
-	{ 0, 0xffff, (0xd5 << 8), 0x0 },
-	{ 0, 0x0, (0xd8 << 8), 0x0 },
-	{ 0, (0xc0 << 8), (0x60 << 8), (0xc0 << 8) }
+#define CL(x) ((gdouble)x / 65535)
+static GdkRGBA default_colors[COLORLABELS] = {
+	{ CL(65535), CL(39168), CL(0),     1.0 },
+	{ CL(65535), CL(0),     CL(0),     1.0 },
+	{ CL(65535), CL(26112), CL(65535), 1.0 },
+	{ CL(0),     CL(52224), CL(65535), 1.0 },
+	{ CL(0),     CL(0),     CL(65535), 1.0 },
+	{ CL(0),     CL(39168), CL(0),     1.0 },
+	{ CL(26112), CL(13056), CL(13056), 1.0 },
+	{ CL(43520), CL(43520), CL(43520), 1.0 },
+	{ CL(49152), CL(29184), CL(21504), 1.0 },
+	{ CL(49152), CL(0),     CL(0),     1.0 },
+	{ CL(52224), CL(4096),  CL(29696), 1.0 },
+	{ CL(20480), CL(37888), CL(52480), 1.0 },
+	{ CL(65535), CL(54528), CL(0),     1.0 },
+	{ CL(0),     CL(55296), CL(0),     1.0 },
+	{ CL(49152), CL(24576), CL(49152), 1.0 }
 };
 
 	
@@ -84,7 +83,7 @@ static struct
 {
 	LabelColorChangeFlags	changed; 
 	/* color here is initialized from default_colors[] at startup */
-	GdkColor		color;
+	GdkRGBA		color;
 
 	/* XXX: note that the label member is supposed to be dynamically 
 	 * allocated and freed */
@@ -135,11 +134,6 @@ static struct
 		return val;				    	\
 	} while(0)
 
-#define INTCOLOR_TO_GDKCOLOR(intcolor, gdkcolor) \
-	gdkcolor.red   = ((intcolor >> 16UL) & 0xFFUL) << 8UL; \
-	gdkcolor.green = ((intcolor >>  8UL) & 0xFFUL) << 8UL; \
-	gdkcolor.blue  = ((intcolor)         & 0xFFUL) << 8UL;
-
 static void colorlabel_recreate        (gint);
 static void colorlabel_recreate_label  (gint);
 
@@ -149,8 +143,7 @@ void colorlabel_update_colortable_from_prefs(void)
 
 	for (i = 0; i < NUM_MENUS; i++) {
 		for (c = 0; c < COLORLABELS; c++) {
-			INTCOLOR_TO_GDKCOLOR(prefs_common.custom_colorlabel[c].color,
-					label_colors[i][c].color);
+			label_colors[i][c].color = prefs_common.custom_colorlabel[c].color;
 			g_free(label_colors[i][c].label);
 			label_colors[i][c].label =
 					g_strdup(prefs_common.custom_colorlabel[c].label);
@@ -164,18 +157,18 @@ gint colorlabel_get_color_count(void)
 	return LABEL_COLORS_ELEMS;
 }
 
-GdkColor colorlabel_get_color(gint color_index)
+GdkRGBA colorlabel_get_color(gint color_index)
 {
-	GdkColor invalid = { 0 };
+	GdkRGBA invalid = { 0 };
 
 	G_RETURN_VAL_IF_INVALID_COLOR(color_index, invalid);
 
 	return label_colors[0][color_index].color;
 }
 
-GdkColor colorlabel_get_default_color(gint color_index)
+GdkRGBA colorlabel_get_default_color(gint color_index)
 {
-	GdkColor invalid = { 0 };
+	GdkRGBA invalid = { 0 };
 
 	G_RETURN_VAL_IF_INVALID_COLOR(color_index, invalid);
 
@@ -190,18 +183,11 @@ gchar *colorlabel_get_color_default_text(gint color_index)
 }
 
 static gboolean colorlabel_drawing_area_expose_event_cb
-	(GtkWidget *widget, GdkEventExpose *expose, gpointer data)
+	(GtkWidget *widget, cairo_t *cr, gpointer data)
 {
-	cairo_t *cr;
-	GdkWindow *drawable = gtk_widget_get_window(widget);
+	GdkRGBA *color = (GdkRGBA *)data;
 	GtkAllocation allocation;
-	gulong c = (gulong) GPOINTER_TO_INT(data);
-	GdkColor color;
 
-	INTCOLOR_TO_GDKCOLOR(c, color)
-
-	gdk_colormap_alloc_color(gtk_widget_get_colormap(widget), &color, FALSE, TRUE);
-	cr = gdk_cairo_create(drawable);
 	gtk_widget_get_allocation(widget, &allocation);
 
 	cairo_set_source_rgb(cr, 0., 0., 0.);
@@ -209,17 +195,17 @@ static gboolean colorlabel_drawing_area_expose_event_cb
 	    allocation.width - 1,
 	    allocation.height - 1);
 	cairo_stroke(cr);
-	gdk_cairo_set_source_color(cr, &color);
+
+	gdk_cairo_set_source_rgba(cr, color);
 	cairo_rectangle(cr, 1, 1,
 	    allocation.width - 2,
 	    allocation.height - 2);
 	cairo_fill(cr);
-	cairo_destroy(cr);
-
+	
 	return FALSE;
 }
 
-static GtkWidget *colorlabel_create_color_widget(GdkColor color)
+static GtkWidget *colorlabel_create_color_widget(GdkRGBA *color)
 {
 	GtkWidget *widget;
 
@@ -227,20 +213,32 @@ static GtkWidget *colorlabel_create_color_widget(GdkColor color)
 	gtk_widget_set_size_request(widget, LABEL_COLOR_WIDTH - 2, 
 				    LABEL_COLOR_HEIGHT - 4);
 
-#define CL(x)		(((gulong) (x) >> (gulong) 8) & 0xFFUL)	
-#define CR(r, g, b)	((CL(r) << (gulong) 16) | \
-			 (CL(g) << (gulong)  8) | \
-			 (CL(b)))
-
-	g_signal_connect(G_OBJECT(widget), "expose_event", 
-			 G_CALLBACK
-			   	(colorlabel_drawing_area_expose_event_cb),
-			 GINT_TO_POINTER
-			   	((gint)CR(color.red, color.green, color.blue)));
+	g_signal_connect(G_OBJECT(widget), "draw", 
+			G_CALLBACK(colorlabel_drawing_area_expose_event_cb),
+			color);
 
 	return widget;
 }
 
+static GdkPixbuf *colorlabel_create_colormenu_pixbuf(GdkRGBA *color)
+{
+	GdkPixbuf *pixbuf;
+	guint32 pixel = 0;
+
+	cm_return_val_if_fail(color != NULL, NULL);
+
+	pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8,
+			LABEL_COLOR_WIDTH - 2, LABEL_COLOR_HEIGHT - 4);
+
+	/* "pixel" needs to be set to 0xrrggbb00 */
+	pixel += (guint32)(color->red   * 255) << 24;
+	pixel += (guint32)(color->green * 255) << 16;
+	pixel += (guint32)(color->blue  * 255) <<  8;
+	gdk_pixbuf_fill(pixbuf, pixel);
+
+	return pixbuf;
+}
+
 /* XXX: colorlabel_recreate_XXX are there to make sure everything
  * is initialized ok, without having to call a global _xxx_init_
  * function */
@@ -253,7 +251,7 @@ static void colorlabel_recreate_color(gint color)
 		if (!(label_colors[i][color].changed & LCCF_COLOR))
 			continue;
 
-		widget = colorlabel_create_color_widget(label_colors[i][color].color);
+		widget = colorlabel_create_color_widget(&label_colors[i][color].color);
 		cm_return_if_fail(widget);
 
 		if (label_colors[i][color].widget) 
@@ -320,11 +318,11 @@ GtkWidget *colorlabel_create_check_color_menu_item(gint color_index, gboolean fo
 	label = gtk_label_new(label_colors[menu_index][color_index].label);
 
 	gtk_widget_show(label);
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show(hbox);
 	gtk_container_add(GTK_CONTAINER(item), hbox);
 
-	vbox = gtk_vbox_new(TRUE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 1);
 
@@ -338,14 +336,14 @@ GtkWidget *colorlabel_create_check_color_menu_item(gint color_index, gboolean fo
 		accel = gtk_accelerator_get_label(GDK_KEY_1+color_index, GDK_CONTROL_MASK);
 		label = gtk_label_new(accel);
 		gtk_widget_show(label);
-		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+		gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 		g_free(accel);
 		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 4);
 		g_object_set_data(G_OBJECT(item), "accel_label", label);
 	} else {
 		label = gtk_label_new("");
 		gtk_widget_show(label);
-		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+		gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 4);
 		g_object_set_data(G_OBJECT(item), "accel_label", label);
 	}
@@ -389,15 +387,15 @@ GtkWidget *colorlabel_create_color_menu(void)
 		label = gtk_label_new(label_colors[0][i].label);
 		
 		gtk_widget_show(label);
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_widget_show(hbox);
 		gtk_container_add(GTK_CONTAINER(item), hbox);
 
-		vbox = gtk_vbox_new(TRUE, 0);
+		vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		gtk_widget_show(vbox);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 1);
 
-		widget = colorlabel_create_color_widget(label_colors[0][i].color);
+		widget = colorlabel_create_color_widget(&label_colors[0][i].color);
 		gtk_widget_show(widget);
 		gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
 
@@ -423,3 +421,140 @@ guint colorlabel_get_color_menu_active_item(GtkWidget *menu)
 		(g_object_get_data(G_OBJECT(menuitem), "color"));
 	return color;
 }
+
+static gboolean colormenu_separator_func(GtkTreeModel *model,
+		GtkTreeIter *iter, gpointer data)
+{
+	gchar *txt;
+
+	gtk_tree_model_get(model, iter, COLORMENU_COL_TEXT, &txt, -1);
+
+	if (txt == NULL)
+		return TRUE;
+
+	return FALSE;
+}
+
+GtkWidget *colorlabel_create_combobox_colormenu()
+{
+	GtkWidget *combobox;
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
+
+	store = gtk_list_store_new(3,
+			GDK_TYPE_PIXBUF,
+			G_TYPE_STRING,
+			G_TYPE_INT);
+	combobox = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+
+	gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(combobox),
+			(GtkTreeViewRowSeparatorFunc)colormenu_separator_func,
+			NULL, NULL);
+
+	renderer = gtk_cell_renderer_pixbuf_new();
+	gtk_cell_renderer_set_padding(renderer, 2, 0);
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox),
+			renderer, FALSE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combobox),
+			renderer,
+			"pixbuf", COLORMENU_COL_PIXBUF,
+			NULL);
+
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox),
+			renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combobox),
+			renderer,
+			"text", COLORMENU_COL_TEXT,
+			NULL);
+
+	colorlabel_refill_combobox_colormenu(GTK_COMBO_BOX(combobox));
+
+	return combobox;
+}
+
+void colorlabel_refill_combobox_colormenu(GtkComboBox *combobox)
+{
+	GtkListStore *store;
+	GtkTreeIter iter;
+	gint i;
+
+	cm_return_if_fail(combobox != NULL);
+
+	store = GTK_LIST_STORE(gtk_combo_box_get_model(combobox));
+
+	cm_return_if_fail(store != NULL);
+
+	gtk_list_store_clear(store);
+
+	/* "None" */
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			COLORMENU_COL_PIXBUF, NULL,
+			COLORMENU_COL_TEXT, _("None"),
+			COLORMENU_COL_ID, -1,
+			-1);
+	/* Separator */
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			COLORMENU_COL_PIXBUF, NULL,
+			COLORMENU_COL_TEXT, NULL,
+			COLORMENU_COL_ID, -1,
+			-1);
+
+	/* Menu items for individual colors */
+	for (i = 0; i < LABEL_COLORS_ELEMS; i++) {
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter,
+				COLORMENU_COL_PIXBUF, colorlabel_create_colormenu_pixbuf(&label_colors[0][i].color),
+				COLORMENU_COL_TEXT, label_colors[0][i].label,
+				COLORMENU_COL_ID, i,
+				-1);
+	}
+}
+
+gint colorlabel_get_combobox_colormenu_active(GtkComboBox *combobox)
+{
+	gint value;
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+
+	cm_return_val_if_fail(combobox != NULL, 0);
+
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combobox), &iter))
+		return 0;
+
+	model = gtk_combo_box_get_model(GTK_COMBO_BOX(combobox));
+	gtk_tree_model_get(model, &iter,
+			COLORMENU_COL_ID, &value,
+			-1);
+
+	return value + 1;
+}
+
+void colorlabel_set_combobox_colormenu_active(GtkComboBox *combobox,
+		gint color)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	gint id;
+
+	cm_return_if_fail(combobox != NULL);
+
+	model = gtk_combo_box_get_model(combobox);
+	cm_return_if_fail(model != NULL);
+
+	if (!gtk_tree_model_get_iter_first(model, &iter))
+		return;
+
+	do {
+		gtk_tree_model_get(model, &iter,
+				COLORMENU_COL_ID, &id,
+				-1);
+
+		if (id == color - 1)
+			break;
+	} while (gtk_tree_model_iter_next(model, &iter));
+
+	gtk_combo_box_set_active_iter(combobox, &iter);
+}
