@@ -26,8 +26,6 @@
  * 
  */
 
-#include "config.h"
-
 #include <stdlib.h>
 
 #include "gtksctree.h"
@@ -167,7 +165,7 @@ gtk_sctree_change_focus_row_expansion (GtkCMCTree          *ctree,
 
   clist = GTK_CMCLIST (ctree);
 
-  if (gdk_display_pointer_is_grabbed (gtk_widget_get_display (GTK_WIDGET (ctree))) && 
+  if (gtkut_pointer_is_grabbed (GTK_WIDGET (ctree)) && 
       gtk_widget_has_grab (GTK_WIDGET(ctree)))
     return;
   
@@ -978,7 +976,7 @@ GtkWidget *gtk_sctree_new_with_titles (gint columns, gint tree_column,
 	cm_return_val_if_fail (tree_column >= 0, NULL);
 	
 	if (tree_column >= columns) {
-		g_warning("wrong tree column");
+		g_warning("Wrong tree column");
 		tree_column = 0;
 		print_backtrace();
 	}
