@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,39 @@
 #include "prefs_common.h"
 #include "manage_window.h"
 #include "manual.h"
+#include "combobox.h"
+
+static struct {
+	const gchar *icon_name;
+	const gchar *icon_label;
+} STOCK_BTNS[] __attribute__((unused)) = {
+	{ "dialog-information",		N_("_Information") },
+	{ "document-open",		N_("_Open") },
+	{ "document-properties",	N_("_Properties") },
+	{ "document-save",		N_("_Save") },
+	{ "edit-clear", 		N_("C_lear") },
+	{ "edit-copy",			N_("_Copy") },
+	{ "edit-delete", 		N_("D_elete") },
+	{ "edit-find", 			N_("_Find") },
+	{ "edit-find-replace",		N_("Find and _Replace") },
+	{ "edit-redo",			N_("_Replace") },
+	{ "edit-undo",			N_("_Undo") },
+	{ "folder",			N_("_Browse") },
+	{ "go-bottom",			N_("_Bottom") },	
+	{ "go-down",			N_("_Down") },
+	{ "go-next",			N_("_Next") },
+	{ "go-previous",		N_("_Previous") },
+	{ "go-top",			N_("_Top") },
+	{ "go-up", 			N_("_Up") },
+	{ "help-browser",		N_("Help") },
+	{ "list-add",			N_("_Add") },
+	{ "list-remove",		N_("_Remove") },
+	{ "process-stop",		N_("_Stop") },
+	{ "system-run",			N_("_Execute") },
+	{ "view-refresh",		N_("_Refresh") },
+	{ "window-close",		N_("_Close") },
+	{ NULL, NULL }
+};
 
 gboolean gtkut_get_font_size(GtkWidget *widget,
 			     gint *width, gint *height)
@@ -88,41 +121,20 @@ void gtkut_widget_set_small_font_size(GtkWidget *widget)
 		font_desc = pango_font_description_from_string(NORMAL_FONT);
 		size = pango_font_description_get_size(font_desc);
 		pango_font_description_set_size(font_desc, size * PANGO_SCALE_SMALL);
-		gtk_widget_modify_font(widget, font_desc);
+		gtk_widget_override_font(widget, font_desc);
 		pango_font_description_free(font_desc);
 	} else {
 		font_desc = pango_font_description_from_string(SMALL_FONT);
-		gtk_widget_modify_font(widget, font_desc);
+		gtk_widget_override_font(widget, font_desc);
 		pango_font_description_free(font_desc);
 	}
 }
 
-void gtkut_convert_int_to_gdk_color(gint rgbvalue, GdkColor *color)
-{
-	cm_return_if_fail(color != NULL);
-
-	color->pixel = 0L;
-	color->red   = (int) (((gdouble)((rgbvalue & 0xff0000) >> 16) / 255.0) * 65535.0);
-	color->green = (int) (((gdouble)((rgbvalue & 0x00ff00) >>  8) / 255.0) * 65535.0);
-	color->blue  = (int) (((gdouble) (rgbvalue & 0x0000ff)        / 255.0) * 65535.0);
-}
-
-#define CL(x)	(((gulong) (x) >> (gulong) 8) & 0xFFUL)
-#define RGB_FROM_GDK_COLOR(c) \
-	((CL(c->red)   << (gulong) 16) | \
-	 (CL(c->green) << (gulong)  8) | \
-	 (CL(c->blue)))
-
-gint gtkut_convert_gdk_color_to_int(GdkColor *color)
-{
-	return RGB_FROM_GDK_COLOR(color);
-}
-
 void gtkut_stock_button_add_help(GtkWidget *bbox, GtkWidget **help_btn)
 {
 	cm_return_if_fail(bbox != NULL);
 
-	*help_btn = gtk_button_new_from_stock(GTK_STOCK_HELP);
+	*help_btn = gtkut_stock_button("help-browser");
 
 	gtk_widget_set_can_default(*help_btn, TRUE);
 	gtk_box_pack_end(GTK_BOX (bbox), *help_btn, TRUE, TRUE, 0);
@@ -156,24 +168,24 @@ void gtkut_stock_button_set_create(GtkWidget **bbox,
 	cm_return_if_fail(bbox != NULL);
 	cm_return_if_fail(button1 != NULL);
 
-	*bbox = gtk_hbutton_box_new();
+	*bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(*bbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing(GTK_BOX(*bbox), 5);
 
-	*button1 = gtk_button_new_from_stock(label1);
+	*button1 = gtkut_stock_button(label1);
 	gtk_widget_set_can_default(*button1, TRUE);
 	gtk_box_pack_start(GTK_BOX(*bbox), *button1, TRUE, TRUE, 0);
 	gtk_widget_show(*button1);
 
 	if (button2) {
-		*button2 = gtk_button_new_from_stock(label2);
+		*button2 = gtkut_stock_button(label2);
 		gtk_widget_set_can_default(*button2, TRUE);
 		gtk_box_pack_start(GTK_BOX(*bbox), *button2, TRUE, TRUE, 0);
 		gtk_widget_show(*button2);
 	}
 
 	if (button3) {
-		*button3 = gtk_button_new_from_stock(label3);
+		*button3 = gtkut_stock_button(label3);
 		gtk_widget_set_can_default(*button3, TRUE);
 		gtk_box_pack_start(GTK_BOX(*bbox), *button3, TRUE, TRUE, 0);
 		gtk_widget_show(*button3);
@@ -188,13 +200,13 @@ void gtkut_stock_with_text_button_set_create(GtkWidget **bbox,
 	cm_return_if_fail(bbox != NULL);
 	cm_return_if_fail(button1 != NULL);
 
-	*bbox = gtk_hbutton_box_new();
+	*bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(*bbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing(GTK_BOX(*bbox), 5);
 
 	*button1 = gtk_button_new_with_mnemonic(text1);
 	gtk_button_set_image(GTK_BUTTON(*button1),
-		gtk_image_new_from_stock(label1, GTK_ICON_SIZE_BUTTON));
+		gtk_image_new_from_icon_name(label1, GTK_ICON_SIZE_BUTTON));
 	gtk_widget_set_can_default(*button1, TRUE);
 	gtk_box_pack_start(GTK_BOX(*bbox), *button1, TRUE, TRUE, 0);
 	gtk_widget_show(*button1);
@@ -202,7 +214,7 @@ void gtkut_stock_with_text_button_set_create(GtkWidget **bbox,
 	if (button2) {
 		*button2 = gtk_button_new_with_mnemonic(text2);
 		gtk_button_set_image(GTK_BUTTON(*button2),
-			gtk_image_new_from_stock(label2, GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name(label2, GTK_ICON_SIZE_BUTTON));
 		gtk_widget_set_can_default(*button2, TRUE);
 		gtk_box_pack_start(GTK_BOX(*bbox), *button2, TRUE, TRUE, 0);
 		gtk_widget_show(*button2);
@@ -211,7 +223,7 @@ void gtkut_stock_with_text_button_set_create(GtkWidget **bbox,
 	if (button3) {
 		*button3 = gtk_button_new_with_mnemonic(text3);
 		gtk_button_set_image(GTK_BUTTON(*button3),
-			gtk_image_new_from_stock(label3, GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name(label3, GTK_ICON_SIZE_BUTTON));
 		gtk_widget_set_can_default(*button3, TRUE);
 		gtk_box_pack_start(GTK_BOX(*bbox), *button3, TRUE, TRUE, 0);
 		gtk_widget_show(*button3);
@@ -391,11 +403,6 @@ void gtkut_clist_set_focus_row(GtkCMCList *clist, gint row)
 	GTKUT_CTREE_REFRESH(clist);
 }
 
-void gtkut_container_remove(GtkContainer *container, GtkWidget *widget)
-{
-	gtk_container_remove(container, widget);
-}
-
 static gboolean gtkut_text_buffer_match_string(GtkTextBuffer *textbuf,
 					const GtkTextIter *iter,
 					gunichar *wcs, gint len,
@@ -455,7 +462,7 @@ static gboolean gtkut_text_buffer_find(GtkTextBuffer *buffer, const GtkTextIter
 
 	wcs = g_utf8_to_ucs4(str, -1, &items_read, &items_written, &error);
 	if (error != NULL) {
-		g_warning("an error occurred while converting a string from UTF-8 to UCS-4: %s",
+		g_warning("An error occurred while converting a string from UTF-8 to UCS-4: %s",
 			  error->message);
 		g_error_free(error);
 	}
@@ -491,7 +498,7 @@ static gboolean gtkut_text_buffer_find_backward(GtkTextBuffer *buffer,
 
 	wcs = g_utf8_to_ucs4(str, -1, &items_read, &items_written, &error);
 	if (error != NULL) {
-		g_warning("an error occurred while converting a string from UTF-8 to UCS-4: %s",
+		g_warning("An error occurred while converting a string from UTF-8 to UCS-4: %s",
 			  error->message);
 		g_error_free(error);
 	}
@@ -624,8 +631,8 @@ void gtkut_window_popup(GtkWidget *window)
 	cm_return_if_fail(window != NULL);
 	cm_return_if_fail(gdkwin != NULL);
 
-	sx = MAX(1, gdk_screen_width());
-	sy = MAX(1, gdk_screen_height());
+	sx = gdk_screen_width();
+	sy = gdk_screen_height();
 
 	gdk_window_get_origin(gdkwin, &x, &y);
 	new_x = x % sx; if (new_x < 0) new_x = 0;
@@ -648,8 +655,8 @@ void gtkut_widget_get_uposition(GtkWidget *widget, gint *px, gint *py)
 	cm_return_if_fail(widget != NULL);
 	cm_return_if_fail(gdkwin != NULL);
 
-	sx = MAX(1, gdk_screen_width());
-	sy = MAX(1, gdk_screen_height());
+	sx = gdk_screen_width();
+	sy = gdk_screen_height();
 
 	/* gdk_window_get_root_origin ever return *rootwindow*'s position */
 	gdk_window_get_root_origin(gdkwin, &x, &y);
@@ -660,12 +667,6 @@ void gtkut_widget_get_uposition(GtkWidget *widget, gint *px, gint *py)
 	*py = y;
 }
 
-void gtkut_widget_draw_now(GtkWidget *widget)
-{
-	if (widget && gtk_widget_get_visible(widget) && gtk_widget_is_drawable(widget))
-		gdk_window_process_updates(gtk_widget_get_window(widget), FALSE);
-}
-
 static void gtkut_clist_bindings_add(GtkWidget *clist)
 {
 	GtkBindingSet *binding_set;
@@ -714,8 +715,8 @@ void gtkut_widget_set_app_icon(GtkWidget *widget)
 	cm_return_if_fail(gtk_widget_get_window(widget) != NULL);
 	if (!icon_list) {
 		GdkPixbuf *icon = NULL, *big_icon = NULL;
-		priv_pixbuf_gdk(PRIV_PIXMAP_CLAWS_MAIL_ICON, &icon);
-		priv_pixbuf_gdk(PRIV_PIXMAP_CLAWS_MAIL_LOGO, &big_icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_LOGO, &big_icon);
 		if (icon)
 			icon_list = g_list_append(icon_list, icon);
 		if (big_icon)
@@ -745,7 +746,7 @@ void gtkut_widget_set_composer_icon(GtkWidget *widget)
 }
 
 static gboolean move_bar = FALSE;
-static guint move_bar_id;
+static gint move_bar_id = -1;
 
 static gboolean move_bar_cb(gpointer data)
 {
@@ -779,22 +780,21 @@ GtkWidget *label_window_create(const gchar *str)
 
 	label = gtk_label_new(str);
 	
-	vbox = gtk_vbox_new(FALSE, 6);
-	hbox = gtk_hbox_new(FALSE, 6);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
-	hbox = gtk_hbox_new(FALSE, 6);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start(GTK_BOX(hbox), wait_progress, TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-	gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
 	gtk_widget_show_all(vbox);
 
 	gtk_widget_show_now(window);
 	
-	if (move_bar_id == 0) {
+	if (move_bar_id == -1) {
 		move_bar_id = g_timeout_add(200, move_bar_cb, wait_progress);
 		move_bar = TRUE;
 	}
@@ -808,7 +808,7 @@ void label_window_destroy(GtkWidget *window)
 {
 	move_bar = FALSE;
 	g_source_remove(move_bar_id);
-	move_bar_id = 0;
+	move_bar_id = -1;
 	GTK_EVENTS_FLUSH();
 	gtk_widget_destroy(window);	
 }
@@ -851,12 +851,12 @@ GtkWidget *gtkut_account_menu_new(GList			*ac_list,
 	return optmenu;
 }
 
-void gtkut_set_widget_bgcolor_rgb(GtkWidget *widget, guint rgbvalue)
+void gtkut_set_widget_bgcolor_rgb(GtkWidget *widget, GdkRGBA rgba)
 {
 	GtkStyle *newstyle;
 	GdkColor gdk_color;
 
-	gtkut_convert_int_to_gdk_color(rgbvalue, &gdk_color);
+	GTKUT_GDKRGBA_TO_GDKCOLOR(rgba, gdk_color);
 	newstyle = gtk_style_copy(gtk_widget_get_default_style());
 	newstyle->bg[GTK_STATE_NORMAL]   = gdk_color;
 	newstyle->bg[GTK_STATE_PRELIGHT] = gdk_color;
@@ -925,7 +925,7 @@ GtkWidget *gtkut_get_browse_file_btn(const gchar *button_label)
 
 	button = gtk_button_new_with_mnemonic(button_label);
 	gtk_button_set_image(GTK_BUTTON(button),
-		gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_BUTTON));
+		gtk_image_new_from_icon_name("folder", GTK_ICON_SIZE_BUTTON));
 
 	return button;
 }
@@ -939,7 +939,7 @@ GtkWidget *gtkut_get_browse_directory_btn(const gchar *button_label)
 
 	button = gtk_button_new_with_mnemonic(button_label);
 	gtk_button_set_image(GTK_BUTTON(button),
-		gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_BUTTON));
+		gtk_image_new_from_icon_name("folder", GTK_ICON_SIZE_BUTTON));
 
 	return button;
 }
@@ -950,11 +950,35 @@ GtkWidget *gtkut_get_replace_btn(const gchar *button_label)
 
 	button = gtk_button_new_with_mnemonic(button_label);
 	gtk_button_set_image(GTK_BUTTON(button),
-		gtk_image_new_from_stock(GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON));
+		gtk_image_new_from_icon_name("view-refresh", GTK_ICON_SIZE_BUTTON));
 
 	return button;
 }
 
+GtkWidget *gtkut_stock_button(const gchar *stock_image)
+{
+	GtkWidget *button;
+	const gchar *name = NULL;
+	const gchar *label = NULL;
+	gint i;
+	
+	cm_return_val_if_fail(stock_image != NULL, NULL);
+
+	button = gtk_button_new_from_icon_name(stock_image, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_use_underline(GTK_BUTTON(button), TRUE);
+	for (i=0;STOCK_BTNS[i].icon_name != NULL;i++) {
+		name = STOCK_BTNS[i].icon_name;
+		label = STOCK_BTNS[i].icon_label;
+		if (!strcmp(stock_image, name)) {
+			gtk_button_set_label(GTK_BUTTON(button), label);
+			return button;
+		}
+	}
+	button = gtk_button_new_with_mnemonic(stock_image);
+	
+	return button;
+};
+
 /**
  * merge some part of code into one function : it creates a frame and add
  *	these into gtk box widget passed in param.
@@ -974,7 +998,7 @@ GtkWidget *gtkut_get_options_frame(GtkWidget *box, GtkWidget **pframe,
 	gtk_box_pack_start(GTK_BOX(box), frame, FALSE, TRUE, 0);
 	gtk_frame_set_label_align(GTK_FRAME(frame), 0.01, 0.5);
 
-	vbox = gtk_vbox_new (FALSE, 4);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show(vbox);
 	gtk_container_add(GTK_CONTAINER (frame), vbox);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
@@ -1087,8 +1111,6 @@ GtkWidget *xface_get_from_header(const gchar *o_xface)
 {
 	static gchar *xpm_xface[XPM_XFACE_HEIGHT];
 	static gboolean xpm_xface_init = TRUE;
-	GdkPixbuf *pixbuf;
-	GtkWidget *ret;
 	gchar xface[2048];
 	
 	if (o_xface == NULL)
@@ -1114,11 +1136,8 @@ GtkWidget *xface_get_from_header(const gchar *o_xface)
 
 	create_xpm_from_xface(xpm_xface, xface);
 
-	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)xpm_xface);
-	ret = gtk_image_new_from_pixbuf(pixbuf);
-	g_object_unref(pixbuf);
-
-	return ret;
+	return gtk_image_new_from_pixbuf(
+		gdk_pixbuf_new_from_xpm_data((const char **)xpm_xface));
 }
 #endif
 
@@ -1177,13 +1196,13 @@ static void link_btn_enter(GtkButton *button, gpointer data)
 	gdkwin = gtk_widget_get_window(window);
 
 	if (!hand_cursor)
-		hand_cursor = gdk_cursor_new(GDK_HAND2);
+		hand_cursor = gdk_cursor_new_for_display(
+				gdk_window_get_display(gdkwin), GDK_HAND2);
 	if (window && gdkwin)
 		gdk_window_set_cursor(gdkwin, hand_cursor);
 
 	gtk_button_set_relief(button, GTK_RELIEF_NONE);
-	gtk_widget_set_state(GTK_WIDGET(button), GTK_STATE_NORMAL);
-	
+	gtk_widget_set_state_flags(GTK_WIDGET(button), GTK_STATE_FLAG_NORMAL, TRUE);
 }
 
 static void link_btn_leave(GtkButton *button, gpointer data)
@@ -1197,26 +1216,26 @@ static void link_btn_leave(GtkButton *button, gpointer data)
 		gdk_window_set_cursor(gdkwin, NULL);
 
 	gtk_button_set_relief(button, GTK_RELIEF_NONE);
-	gtk_widget_set_state(GTK_WIDGET(button), GTK_STATE_NORMAL);
+	gtk_widget_set_state_flags(GTK_WIDGET(button), GTK_STATE_FLAG_NORMAL, TRUE);
 }
 
 static void link_btn_pressed(GtkButton *button, gpointer data)
 {
 	gtk_button_set_relief(button, GTK_RELIEF_NONE);
-	gtk_widget_set_state(GTK_WIDGET(button), GTK_STATE_NORMAL);
+	gtk_widget_set_state_flags(GTK_WIDGET(button), GTK_STATE_FLAG_NORMAL, TRUE);
 }
 
 static void link_btn_released(GtkButton *button, gpointer data)
 {
 	gtk_button_set_relief(button, GTK_RELIEF_NONE);
-	gtk_widget_set_state(GTK_WIDGET(button), GTK_STATE_NORMAL);
+	gtk_widget_set_state_flags(GTK_WIDGET(button), GTK_STATE_FLAG_NORMAL, TRUE);
 }
 
 static void link_btn_clicked(GtkButton *button, gpointer data)
 {
 	gchar *url = (gchar *)data;
 	gtk_button_set_relief(button, GTK_RELIEF_NONE);
-	gtk_widget_set_state(GTK_WIDGET(button), GTK_STATE_NORMAL);
+	gtk_widget_set_state_flags(GTK_WIDGET(button), GTK_STATE_FLAG_NORMAL, TRUE);
 	open_uri(url, prefs_common_get_uri_cmd());
 }
 
@@ -1232,24 +1251,17 @@ GtkWidget *gtkut_get_link_btn(GtkWidget *window, const gchar *url, const gchar *
 {
 	GtkWidget *btn;
 	GtkWidget *btn_label;
-	GdkColormap *cmap;
-	gboolean success[2];
 	GdkColor uri_color[2] = {{0, 0, 0, 0xffff}, {0, 0xffff, 0, 0}};
 	gchar *local_url = NULL;
 	if (!url)
 		return NULL;
 
-	gtkut_convert_int_to_gdk_color(prefs_common.color[COL_URI],
-					       &uri_color[0]);
-	gtkut_convert_int_to_gdk_color(prefs_common.color[COL_URI],
-					       &uri_color[1]);
+	GTKUT_GDKRGBA_TO_GDKCOLOR(prefs_common.color[COL_URI], uri_color[0])
+	GTKUT_GDKRGBA_TO_GDKCOLOR(prefs_common.color[COL_URI], uri_color[1])
 
 	btn = gtk_button_new_with_label(label?label:url);
 	gtk_button_set_relief(GTK_BUTTON(btn), GTK_RELIEF_NONE);
 	btn_label = gtk_bin_get_child(GTK_BIN((btn)));
-	cmap = gdk_drawable_get_colormap(gtk_widget_get_window(window));
-	gdk_colormap_alloc_colors(cmap, uri_color, 2, FALSE, TRUE, success);
-	if (success[0] == TRUE && success[1] == TRUE) {
 		GtkStyle *style;
 		gtk_widget_ensure_style(btn_label);
 		style = gtk_style_copy
@@ -1259,8 +1271,6 @@ GtkWidget *gtkut_get_link_btn(GtkWidget *window, const gchar *url, const gchar *
 		style->fg[GTK_STATE_PRELIGHT] = uri_color[0];
 		gtk_widget_set_style(btn_label, style);
 		g_object_unref(style);
-	} else
-		g_warning("color allocation failed");
 
 	g_signal_connect(G_OBJECT(btn), "enter",
 			 G_CALLBACK(link_btn_enter), window);
@@ -1314,7 +1324,7 @@ GtkWidget *gtkut_sc_combobox_create(GtkWidget *eventbox, gboolean focus_on_click
 
 	if( eventbox != NULL )
 		gtk_container_add(GTK_CONTAINER(eventbox), combobox);
-	gtk_combo_box_set_focus_on_click(GTK_COMBO_BOX(combobox), focus_on_click);
+	gtk_widget_set_focus_on_click(GTK_WIDGET(combobox), focus_on_click);
 
 	gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(combobox),
 			(GtkTreeViewRowSeparatorFunc)_combobox_separator_func, NULL, NULL);
@@ -1994,6 +2004,19 @@ gboolean auto_configure_service_sync(const gchar *service, const gchar *domain,
 }
 #endif
 
+gboolean gtkut_pointer_is_grabbed(GtkWidget *widget)
+{
+	GdkDisplay *display;
+	GdkDevice *pointerdev;
+
+	cm_return_val_if_fail(widget != NULL, FALSE);
+
+	display = gtk_widget_get_display(widget);
+	pointerdev = gdk_seat_get_pointer(gdk_display_get_default_seat(display));
+
+	return gdk_display_device_is_grabbed(display, pointerdev);
+}
+
 gpointer gtkut_tree_view_get_selected_pointer(GtkTreeView *view,
 		gint column, GtkTreeModel **_model, GtkTreeSelection **_selection,
 		GtkTreeIter *_iter)
@@ -2134,3 +2157,37 @@ void gtk_calendar_select_today(GtkCalendar *calendar)
 	gtk_calendar_select_day(calendar, lt->tm_mday);
 	gtk_calendar_select_month(calendar, lt->tm_mon, lt->tm_year + 1900);
 }
+
+
+#define RGBA_ELEMENT_TO_BYTE(x) (int)((gdouble)x * 255)
+gchar *gtkut_gdk_rgba_to_string(GdkRGBA *rgba)
+{
+	gchar *str = g_strdup_printf("#%02x%02x%02x",
+			RGBA_ELEMENT_TO_BYTE(rgba->red),
+			RGBA_ELEMENT_TO_BYTE(rgba->green),
+			RGBA_ELEMENT_TO_BYTE(rgba->blue));
+
+	return str;
+}
+#undef RGBA_ELEMENT_TO_BYTE
+
+void gtkut_set_button_color(GtkWidget *button,
+		GdkRGBA *rgba)
+{
+	gchar *str, *markup;
+	GtkWidget *label;
+
+	cm_return_if_fail(button != NULL);
+	cm_return_if_fail(rgba != NULL);
+
+	label = gtk_bin_get_child(GTK_BIN(button));
+	cm_return_if_fail(label != NULL);
+
+	str = gtkut_gdk_rgba_to_string(rgba);
+
+	markup = g_strdup_printf("<span bgcolor=\"%s\">" GTKUT_COLOR_BUTTON_LABEL "</span>", str);
+	g_free(str);
+
+	gtk_label_set_markup(GTK_LABEL(label), markup);
+	g_free(markup);
+}
