@@ -71,16 +71,16 @@ HeaderView *headerview_create(void)
 	debug_print("Creating header view...\n");
 	headerview = g_new0(HeaderView, 1);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
-	vbox = gtk_vbox_new(FALSE, 2);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox1, FALSE, FALSE, 0);
-	hbox2 = gtk_hbox_new(FALSE, 4);
+	hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, FALSE, 0);
-	hbox3 = gtk_hbox_new(FALSE, 4);
+	hbox3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox3, FALSE, FALSE, 0);
 
 	from_header_label    = gtk_label_new(prefs_common_translated_header_name("From:"));
@@ -117,10 +117,10 @@ HeaderView *headerview_create(void)
 	gtk_box_pack_start(GTK_BOX(hbox3), tags_header_label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox3), tags_body_label, TRUE, TRUE, 0);
 
-	gtk_misc_set_alignment(GTK_MISC(to_body_label), 0, 0.5);
-	gtk_misc_set_alignment(GTK_MISC(ng_body_label), 0, 0.5);
-	gtk_misc_set_alignment(GTK_MISC(subject_body_label), 0, 0.5);
-	gtk_misc_set_alignment(GTK_MISC(tags_body_label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(to_body_label), 0.0);
+	gtk_label_set_xalign(GTK_LABEL(ng_body_label), 0.0);
+	gtk_label_set_xalign(GTK_LABEL(subject_body_label), 0.0);
+	gtk_label_set_xalign(GTK_LABEL(tags_body_label), 0.0);
 	gtk_label_set_ellipsize(GTK_LABEL(to_body_label), PANGO_ELLIPSIZE_END);
 	gtk_label_set_ellipsize(GTK_LABEL(ng_body_label), PANGO_ELLIPSIZE_END);
 	gtk_label_set_ellipsize(GTK_LABEL(subject_body_label), PANGO_ELLIPSIZE_END);
@@ -151,11 +151,11 @@ void headerview_set_font(HeaderView *headerview)
 	
 	normalfont = pango_font_description_from_string(NORMAL_FONT);
 	if (normalfont) {
-		gtk_widget_modify_font(headerview->from_body_label, normalfont);
-		gtk_widget_modify_font(headerview->to_body_label, normalfont);
-		gtk_widget_modify_font(headerview->ng_body_label, normalfont);
-		gtk_widget_modify_font(headerview->subject_body_label, normalfont);
-		gtk_widget_modify_font(headerview->tags_body_label, normalfont);
+		gtk_widget_override_font(headerview->from_body_label, normalfont);
+		gtk_widget_override_font(headerview->to_body_label, normalfont);
+		gtk_widget_override_font(headerview->ng_body_label, normalfont);
+		gtk_widget_override_font(headerview->subject_body_label, normalfont);
+		gtk_widget_override_font(headerview->tags_body_label, normalfont);
 		pango_font_description_free(normalfont);
 	}
 
@@ -166,11 +166,11 @@ void headerview_set_font(HeaderView *headerview)
 		boldfont = pango_font_description_from_string(BOLD_FONT);
 	}
 	if (boldfont) {
-		gtk_widget_modify_font(headerview->from_header_label, boldfont);
-		gtk_widget_modify_font(headerview->to_header_label, boldfont);
-		gtk_widget_modify_font(headerview->ng_header_label, boldfont);
-		gtk_widget_modify_font(headerview->subject_header_label, boldfont);
-		gtk_widget_modify_font(headerview->tags_header_label, boldfont);
+		gtk_widget_override_font(headerview->from_header_label, boldfont);
+		gtk_widget_override_font(headerview->to_header_label, boldfont);
+		gtk_widget_override_font(headerview->ng_header_label, boldfont);
+		gtk_widget_override_font(headerview->subject_header_label, boldfont);
+		gtk_widget_override_font(headerview->tags_header_label, boldfont);
 		pango_font_description_free(boldfont);
 	}
 }
@@ -277,7 +277,7 @@ static void headerview_save_contact_pic (HeaderView *headerview, MsgInfo *msginf
 	if (!is_file_exist(filename)) {
 		gdk_pixbuf_save(picture, filename, "png", &error, NULL);
 		if (error) {
-			g_warning("failed to save image: %s",
+			g_warning("Failed to save image: %s",
 					error->message);
 			g_error_free(error);
 		}
