@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto & the Claws Mail Team
+ * Copyright (C) 1999-2019 the Claws Mail Team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -362,11 +362,11 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 	name = trim_string(item->name, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
 	message = g_markup_printf_escaped
-		(_("All folders and messages under '%s' will be permanently deleted.\n"
+		(_("All folders and messages under '%s' will be permanently deleted. "
 		   "Recovery will not be possible.\n\n"
 		   "Do you really want to delete?"), name);
 	avalue = alertpanel_full(_("Delete folder"), message,
-		 		 GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL, ALERTFOCUS_FIRST, FALSE,
+		 		 _("_Cancel"), _("_Delete"), NULL, ALERTFOCUS_FIRST, FALSE,
 				 NULL, ALERT_WARNING);
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
@@ -512,7 +512,7 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 				G_CALLBACK(chk_update_val), &recurse);
 
 		avalue = alertpanel_full(_("Subscriptions"), message,
-		 			 GTK_STOCK_CANCEL, _("_Search"), NULL, ALERTFOCUS_SECOND,
+		 			 _("_Cancel"), _("_Search"), NULL, ALERTFOCUS_SECOND,
 					 FALSE, rec_chk, ALERT_QUESTION);
 		g_free(message);
 		if (avalue != G_ALERTALTERNATE) return;
@@ -571,7 +571,7 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 			G_CALLBACK(chk_update_val), &recurse);
 
 	avalue = alertpanel_full(_("Subscriptions"), message,
-		 		 GTK_STOCK_CANCEL, action?_("_Subscribe"):_("_Unsubscribe"), NULL,
+		 		 _("_Cancel"), action?_("_Subscribe"):_("_Unsubscribe"), NULL,
 				 ALERTFOCUS_SECOND, FALSE, rec_chk, ALERT_QUESTION);
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
