@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
+ * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,9 +61,7 @@
 #include "hooks.h"
 #include "logwindow.h"
 #include "passwordstore.h"
-#ifdef USE_OAUTH2
 #include "oauth2.h"
-#endif
 
 extern SessionStats session_stats;
 
@@ -419,7 +417,7 @@ void inc_all_account_mail(MainWindow *mainwin, gboolean autocheck,
 			  gboolean check_at_startup, gboolean notify)
 {
 	GList *list, *list2 = NULL;
-	gboolean condition = FALSE;
+	gboolean condition;
 	gboolean hide_dialog = FALSE;
 
 	debug_print("INC: inc_all_account_mail(), autocheck: %s\n",
@@ -462,8 +460,8 @@ static void inc_progress_dialog_size_allocate_cb(GtkWidget *widget,
 {
 	cm_return_if_fail(allocation != NULL);
 
-	prefs_common.receivewin_width = allocation->width;
-	prefs_common.receivewin_height = allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+		&prefs_common.receivewin_width, &prefs_common.receivewin_height);
 }
 
 static IncProgressDialog *inc_progress_dialog_create(gboolean autocheck)
@@ -635,12 +633,11 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 			manage_window_focus_in
 				(inc_dialog->dialog->window,
 				 NULL, NULL);
-#ifdef USE_OAUTH2
+
 		if(pop3_session->ac_prefs->use_pop_auth && 
 		   pop3_session->ac_prefs->pop_auth_type == POPAUTH_OAUTH2)
 		     oauth2_check_passwds (pop3_session->ac_prefs);
-#endif
-
+		
 		if (password_get(pop3_session->user,
 					pop3_session->ac_prefs->recv_server,
 					"pop3", pop3_get_port(pop3_session),
@@ -684,9 +681,9 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 
 		if (pop3_session->pass == NULL) {
 			SET_PIXMAP_AND_TEXT(okpix, _("Cancelled"));
+			inc_session_destroy(session);
 			inc_dialog->queue_list =
 				g_list_remove(inc_dialog->queue_list, session);
-			inc_session_destroy(session);
 			continue;
 		}
 
@@ -841,7 +838,7 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 		gtk_window_set_title(GTK_WINDOW(inc_dialog->dialog->window),
 				     fin_msg);
 		gtk_button_set_label(GTK_BUTTON(inc_dialog->dialog->cancel_btn),
-				     GTK_STOCK_CLOSE);
+				     _("_Close"));
 	}
 
 	g_free(fin_msg);
@@ -883,12 +880,12 @@ static IncState inc_pop3_session_do(IncSession *session)
 	if (ac->ssl_pop != SSL_NONE) {
 		if (alertpanel_full(_("Insecure connection"),
 			_("This connection is configured to be secured "
-			  "using TLS, but TLS is not available "
+			  "using SSL/TLS, but SSL/TLS is not available "
 			  "in this build of Claws Mail. \n\n"
 			  "Do you want to continue connecting to this "
 			  "server? The communication would not be "
 			  "secure."),
-			  GTK_STOCK_CANCEL, _("Con_tinue connecting"), NULL,
+			_("_Cancel"), _("Con_tinue connecting"), NULL,
 				ALERTFOCUS_FIRST, FALSE, NULL, ALERT_WARNING) != G_ALERTALTERNATE)
 			return INC_CANCEL;
 	}
@@ -1489,12 +1486,9 @@ static void inc_notify_cmd(gint new_msgs, gboolean notify)
 
 	ret_str = g_locale_from_utf8(buf, strlen(buf), &by_read, &by_written,
 				     NULL);
-	if (ret_str) {
-		if (by_written) {
-			g_free(buf);
-			buf = ret_str;
-		} else
-			g_free(ret_str);
+	if (ret_str && by_written) {
+		g_free(buf);
+		buf = ret_str;
 	}
 	debug_print("executing new mail notification command: %s\n", buf);
 	execute_command_line(buf, TRUE, NULL);
@@ -1671,7 +1665,7 @@ gboolean inc_offline_should_override(gboolean force_ask, const gchar *msg)
 
 		answer = alertpanel(_("Offline warning"), 
 			       tmp,
-			       GTK_STOCK_NO, GTK_STOCK_YES,
+			       _("_No"), _("_Yes"),
 				!force_ask? _("On_ly once"):NULL, ALERTFOCUS_SECOND);
 		g_free(tmp);
 		if (answer == G_ALERTALTERNATE) {
