@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,10 +51,12 @@
 #include "file_checker.h"
 #include "wizard.h"
 #ifdef HAVE_STARTUP_NOTIFICATION
+#ifdef GDK_WINDOWING_X11
 # define SN_API_NOT_YET_FROZEN
 # include <libsn/sn-launchee.h>
 # include <gdk/gdkx.h>
 #endif
+#endif
 
 #ifdef HAVE_DBUS_GLIB
 #include <dbus/dbus-glib.h>
@@ -154,6 +156,11 @@
 static gboolean went_offline_nm;
 #endif
 
+
+#ifdef HAVE_DBUS_GLIB
+static DBusGProxy *awn_proxy = NULL;
+#endif
+
 gchar *prog_version;
 #if (defined HAVE_LIBSM || defined CRASH_DIALOG)
 gchar *argv0;
@@ -166,9 +173,7 @@ static SnDisplay *sn_display = NULL;
 
 static gint lock_socket = -1;
 static gint lock_socket_tag = 0;
-#ifdef G_OS_UNIX
-static gchar *x_display = NULL;
-#endif
+
 typedef enum 
 {
 	ONLINE_MODE_DONT_CHANGE,
@@ -205,7 +210,6 @@ static struct RemoteCmd {
 	const gchar *target;
 	gboolean debug;
 	const gchar *geometry;
-	const gchar *import_mbox;
 } cmd;
 
 SessionStats session_stats;
@@ -214,7 +218,8 @@ static void reset_statistics(void);
 		
 static void parse_cmd_opt(int argc, char *argv[]);
 
-static gint prohibit_duplicate_launch	(void);
+static gint prohibit_duplicate_launch	(int		*argc,
+					 char		***argv);
 static gchar * get_crashfile_name	(void);
 static gint lock_socket_remove		(void);
 static void lock_socket_input_cb	(gpointer	   data,
@@ -226,10 +231,11 @@ static void open_compose_new		(const gchar	*address,
 
 static void send_queue			(void);
 static void initial_processing		(FolderItem *item, gpointer data);
-#ifndef G_OS_WIN32
 static void quit_signal_handler         (int sig);
-#endif
 static void install_basic_sighandlers   (void);
+#if (defined linux && defined SIGIO)
+static void install_memory_sighandler   (void);
+#endif
 static void exit_claws			(MainWindow *mainwin);
 
 #ifdef HAVE_NETWORKMANAGER_SUPPORT
@@ -374,15 +380,12 @@ static gboolean migrate_old_config(const gchar *old_cfg_dir, const gchar *new_cf
 {
 	gchar *message = g_strdup_printf(_("Configuration for %s found.\n"
 			 "Do you want to migrate this configuration?"), oldversion);
-
-	if (!strcmp(oldversion, "Sylpheed")) {
-		gchar *message2 = g_strdup_printf(_("\n\nYour Sylpheed filtering rules can be converted by a\n"
+	gchar *message2 = g_strdup_printf(_("\n\nYour Sylpheed filtering rules can be converted by a\n"
 			     "script available at %s."), TOOLS_URI);
-		gchar *tmp = g_strconcat(message, message2, NULL);
-		g_free(message2);
-		g_free(message);
-        message = tmp;
-	}
+
+	if (!strcmp(oldversion, "Sylpheed"))
+		message = g_strconcat(message, message2, NULL);
+	g_free(message2);
 
 	gint r = 0;
 	GtkWidget *window = NULL;
@@ -401,7 +404,7 @@ static gboolean migrate_old_config(const gchar *old_cfg_dir, const gchar *new_cf
 			G_CALLBACK(chk_update_val), &backup);
 
 	if (alertpanel_full(_("Migration of configuration"), message,
-		 	GTK_STOCK_NO, GTK_STOCK_YES, NULL, ALERTFOCUS_SECOND, FALSE,
+		 	_("_No"), _("_Yes"), NULL, ALERTFOCUS_SECOND, FALSE,
 			keep_backup_chk, ALERT_QUESTION) != G_ALERTALTERNATE) {
 		return FALSE;
 	}
@@ -655,7 +658,7 @@ static void sc_session_manager_connect(MainWindow *mainwin)
 			g_free(client_id);
 
 		if (error_string_ret[0] || mainwin->smc_conn == NULL)
-			g_warning("while connecting to session manager: %s",
+			g_warning ("While connecting to session manager: %s.",
 				error_string_ret);
 		else {
 			SmPropValue *vals;
@@ -691,59 +694,30 @@ void main_set_show_at_startup(gboolean show)
 }
 
 #ifdef G_OS_WIN32
-static HANDLE win32_debug_log = NULL;
+static FILE* win32_debug_fp=NULL;
 static guint win32_log_handler_app_id;
 static guint win32_log_handler_glib_id;
 static guint win32_log_handler_gtk_id;
 
-static void win32_log_WriteFile(const gchar *string)
-{
-	BOOL ret;
-	DWORD bytes_written;
-
-	ret = WriteFile(win32_debug_log, string, strlen(string), &bytes_written, NULL);
-	if (!ret) {
-		DWORD err = GetLastError();
-		gchar *tmp;
-
-		tmp = g_strdup_printf("Error: WriteFile in failed with error 0x%lx.  Buffer contents:\n%s", err, string);
-		OutputDebugString(tmp);
-		g_free(tmp);
-	}
-}
-
 static void win32_print_stdout(const gchar *string)
 {
-	if (win32_debug_log) {
-		win32_log_WriteFile(string);
+	if (win32_debug_fp) {
+		fprintf(win32_debug_fp, "%s", string);
+		fflush(win32_debug_fp);
 	}
 }
 
-GLogWriterOutput win32_log_writer(GLogLevelFlags log_level, const GLogField *fields, gsize n_fields, gpointer user_data)
+static void win32_print_stderr(const gchar *string)
 {
-	gchar *formatted;
-	gchar *out;
-
-	g_return_val_if_fail(win32_debug_log != NULL, G_LOG_WRITER_UNHANDLED);
-	g_return_val_if_fail(fields != NULL, G_LOG_WRITER_UNHANDLED);
-	g_return_val_if_fail(n_fields > 0, G_LOG_WRITER_UNHANDLED);
-
-	formatted = g_log_writer_format_fields(log_level, fields, n_fields, FALSE);
-	out = g_strdup_printf("%s\n", formatted);
-
-	win32_log_WriteFile(out);
-
-	g_free(formatted);
-	g_free(out);
-
-	return G_LOG_WRITER_HANDLED;
+	if (win32_debug_fp) {
+		fprintf(win32_debug_fp, "%s", string);
+		fflush(win32_debug_fp);
+	}
 }
 
 static void win32_log(const gchar *log_domain, GLogLevelFlags log_level, const gchar* message, gpointer user_data)
 {
-	gchar *out;
-
-	if (win32_debug_log) {
+	if (win32_debug_fp) {
 		const gchar* type;
 
 		switch(log_level & G_LOG_LEVEL_MASK)
@@ -769,15 +743,11 @@ static void win32_log(const gchar *log_domain, GLogLevelFlags log_level, const g
 			default:
 				type="N/A";
 		}
-
 		if (log_domain)
-			out = g_strdup_printf("%s: %s: %s", log_domain, type, message);
+			fprintf(win32_debug_fp, "%s: %s: %s", log_domain, type, message);
 		else
-			out = g_strdup_printf("%s: %s", type, message);
-
-		win32_log_WriteFile(out);
-
-		g_free(out);
+			fprintf(win32_debug_fp, "%s: %s", type, message);
+		fflush(win32_debug_fp);
 	}
 }
 
@@ -790,45 +760,31 @@ static void win32_open_log(void)
 		if (rename_force(logfile, oldlogfile) < 0)
 			FILE_OP_ERROR(logfile, "rename");
 	}
-
-	win32_debug_log = CreateFile(logfile,
-		GENERIC_WRITE,
-		FILE_SHARE_READ,
-		NULL,
-		CREATE_NEW,
-		FILE_ATTRIBUTE_NORMAL,
-		NULL);
-
-	if (win32_debug_log == INVALID_HANDLE_VALUE) {
-		win32_debug_log = NULL;
-	}
-
+	win32_debug_fp = claws_fopen(logfile, "w");
 	g_free(logfile);
 	g_free(oldlogfile);
-
-	if (win32_debug_log) {
+	if (win32_debug_fp)
+	{
 		g_set_print_handler(win32_print_stdout);
 		g_set_printerr_handler(win32_print_stdout);
-
 		win32_log_handler_app_id = g_log_set_handler(NULL, G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL
                      | G_LOG_FLAG_RECURSION, win32_log, NULL);
 		win32_log_handler_glib_id = g_log_set_handler("GLib", G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL
                      | G_LOG_FLAG_RECURSION, win32_log, NULL);
 		win32_log_handler_gtk_id = g_log_set_handler("Gtk", G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL
                      | G_LOG_FLAG_RECURSION, win32_log, NULL);
-
-		g_log_set_writer_func(&win32_log_writer, NULL, NULL);
 	}
 }
 
 static void win32_close_log(void)
 {
-	if (win32_debug_log) {
+	if (win32_debug_fp)
+	{
 		g_log_remove_handler("", win32_log_handler_app_id);
 		g_log_remove_handler("GLib", win32_log_handler_glib_id);
 		g_log_remove_handler("Gtk", win32_log_handler_gtk_id);
-		CloseHandle(win32_debug_log);
-		win32_debug_log = NULL;
+		claws_fclose(win32_debug_fp);
+		win32_debug_fp=NULL;
 	}
 }		
 #endif
@@ -928,6 +884,106 @@ static void main_dump_features_list(gboolean show_debug_only)
 #endif
 }
 
+#ifdef HAVE_DBUS_GLIB
+static gulong dbus_item_hook_id = HOOK_NONE;
+static gulong dbus_folder_hook_id = HOOK_NONE;
+
+static void uninstall_dbus_status_handler(void)
+{
+	if(awn_proxy)
+		g_object_unref(awn_proxy);
+	awn_proxy = NULL;
+	if (dbus_item_hook_id != HOOK_NONE)
+		hooks_unregister_hook(FOLDER_ITEM_UPDATE_HOOKLIST, dbus_item_hook_id);
+	if (dbus_folder_hook_id != HOOK_NONE)
+		hooks_unregister_hook(FOLDER_UPDATE_HOOKLIST, dbus_folder_hook_id);
+}
+
+static void dbus_update(FolderItem *removed_item)
+{
+	guint new, unread, unreadmarked, marked, total;
+	guint replied, forwarded, locked, ignored, watched;
+	gchar *buf;
+	GError *error = NULL;
+
+	folder_count_total_msgs(&new, &unread, &unreadmarked, &marked, &total,
+				&replied, &forwarded, &locked, &ignored,
+				&watched);
+	if (removed_item) {
+		total -= removed_item->total_msgs;
+		new -= removed_item->new_msgs;
+		unread -= removed_item->unread_msgs;
+	}
+
+	if (new > 0) {
+		buf = g_strdup_printf("%d", new);
+		dbus_g_proxy_call(awn_proxy, "SetInfoByName", &error,
+			G_TYPE_STRING, "claws-mail",
+			G_TYPE_STRING, buf,
+			G_TYPE_INVALID, G_TYPE_INVALID);
+		g_free(buf);
+		
+	} else {
+		dbus_g_proxy_call(awn_proxy, "UnsetInfoByName", &error, G_TYPE_STRING,
+			"claws-mail", G_TYPE_INVALID, G_TYPE_INVALID);
+	}
+	if (error) {
+		debug_print("%s\n", error->message);
+		g_error_free(error);
+	}
+}
+
+static gboolean dbus_status_update_folder_hook(gpointer source, gpointer data)
+{
+	FolderUpdateData *hookdata;
+	hookdata = source;
+	if (hookdata->update_flags & FOLDER_REMOVE_FOLDERITEM)
+		dbus_update(hookdata->item);
+	else
+		dbus_update(NULL);
+
+	return FALSE;
+}
+
+static gboolean dbus_status_update_item_hook(gpointer source, gpointer data)
+{
+	dbus_update(NULL);
+
+	return FALSE;
+}
+
+static void install_dbus_status_handler(void)
+{
+	GError *tmp_error = NULL;
+	DBusGConnection *connection = dbus_g_bus_get(DBUS_BUS_SESSION, &tmp_error);
+	
+	if(!connection) {
+		/* If calling code doesn't do error checking, at least print some debug */
+		debug_print("Failed to open connection to session bus: %s\n",
+				 tmp_error->message);
+		g_error_free(tmp_error);
+		return;
+	}
+	awn_proxy = dbus_g_proxy_new_for_name(connection,
+			"com.google.code.Awn",
+			"/com/google/code/Awn",
+			"com.google.code.Awn");
+	dbus_item_hook_id = hooks_register_hook (FOLDER_ITEM_UPDATE_HOOKLIST, dbus_status_update_item_hook, NULL);
+	if (dbus_item_hook_id == HOOK_NONE) {
+		g_warning("Failed to register folder item update hook");
+		uninstall_dbus_status_handler();
+		return;
+	}
+
+	dbus_folder_hook_id = hooks_register_hook (FOLDER_UPDATE_HOOKLIST, dbus_status_update_folder_hook, NULL);
+	if (dbus_folder_hook_id == HOOK_NONE) {
+		g_warning("Failed to register folder update hook");
+		uninstall_dbus_status_handler();
+		return;
+	}
+}
+#endif
+
 static void reset_statistics(void)
 {
 	/* (re-)initialize session statistics */
@@ -935,7 +991,6 @@ static void reset_statistics(void)
 	session_stats.sent = 0;
 	session_stats.replied = 0;
 	session_stats.forwarded = 0;
-	session_stats.spam = 0;
 	session_stats.time_started = time(NULL);
 }
 
@@ -985,11 +1040,15 @@ int main(int argc, char *argv[])
 	sock_init();
 
 	/* check and create unix domain socket for remote operation */
-	lock_socket = prohibit_duplicate_launch();
+	lock_socket = prohibit_duplicate_launch(&argc, &argv);
 	if (lock_socket < 0) {
 #ifdef HAVE_STARTUP_NOTIFICATION
-		if(gtk_init_check(&argc, &argv))
+#ifdef GDK_WINDOWING_X11
+	if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+		if (gtk_init_check(&argc, &argv))
 			startup_notification_complete(TRUE);
+	}
+#endif
 #endif
 		return 0;
 	}
@@ -999,7 +1058,6 @@ int main(int argc, char *argv[])
 
 #ifdef CRASH_DIALOG
 	if (cmd.crash) {
-		gtk_set_locale();
 		gtk_init(&argc, &argv);
 		crash_main(cmd.crash_params);
 #ifdef G_OS_WIN32
@@ -1010,6 +1068,9 @@ int main(int argc, char *argv[])
 	crash_install_handlers();
 #endif
 	install_basic_sighandlers();
+#if (defined linux && defined SIGIO)
+	install_memory_sighandler();
+#endif
 
 	if (cmd.status || cmd.status_full || cmd.search ||
 		cmd.statistics || cmd.reset_statistics || 
@@ -1022,27 +1083,15 @@ int main(int argc, char *argv[])
 	
 	if (cmd.exit)
 		return 0;
+#if !GLIB_CHECK_VERSION(2,32,0)
+	if (!g_thread_supported())
+		g_thread_init(NULL);
+#endif
 
 	reset_statistics();
 	
-	gtk_set_locale();
 	gtk_init(&argc, &argv);
 
-#ifdef G_OS_WIN32
-	gtk_settings_set_string_property(gtk_settings_get_default(),
-			"gtk-theme-name",
-			"MS-Windows",
-			"XProperty");
-	gtk_settings_set_long_property(gtk_settings_get_default(),
-			"gtk-auto-mnemonics",
-			TRUE,
-			"XProperty");
-	gtk_settings_set_long_property(gtk_settings_get_default(),
-			"gtk-button-images",
-			TRUE,
-			"XProperty");
-#endif
-
 #ifdef HAVE_NETWORKMANAGER_SUPPORT
 	went_offline_nm = FALSE;
 	nm_proxy = NULL;
@@ -1068,18 +1117,19 @@ int main(int argc, char *argv[])
 				NULL,NULL);
 		}
 #endif
+		install_dbus_status_handler();
 	}
 #endif
 
-	gtk_widget_set_default_colormap(
-		gdk_screen_get_system_colormap(
-			gdk_screen_get_default()));
-
 	gtkut_create_ui_manager();
 
 	/* Create container for all the menus we will be adding */
 	MENUITEM_ADDUI("/", "Menus", NULL, GTK_UI_MANAGER_MENUBAR);
 
+	if (!g_thread_supported()) {
+		g_error(_("g_thread is not supported by glib.\n"));
+	}
+
 #ifdef G_OS_WIN32
 	CHDIR_EXEC_CODE_RETURN_VAL_IF_FAIL(get_home_dir(), 1, win32_close_log(););
 #else
@@ -1147,12 +1197,6 @@ int main(int argc, char *argv[])
 	g_free(userrc);
 
 	userrc = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, MENU_RC, NULL);
-
-	if (copy_file(userrc, userrc, TRUE) < 0) {
-		g_warning("can't copy %s to %s.bak",
-			  userrc, userrc);
-	}
-
 	gtk_accel_map_load (userrc);
 	g_free(userrc);
 
@@ -1258,7 +1302,7 @@ int main(int argc, char *argv[])
 	}
 #endif
 	gtkut_widget_init();
-	priv_pixbuf_gdk(PRIV_PIXMAP_CLAWS_MAIL_ICON, &icon);
+	stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
 	gtk_window_set_default_icon(icon);
 
 	folderview_initialize();
@@ -1355,6 +1399,9 @@ int main(int argc, char *argv[])
 		}
 		if(!account_get_list()) {
 			exit_claws(mainwin);
+#ifdef G_OS_WIN32
+			win32_close_log();
+#endif
 			exit(1);
 		}
 		never_ran = TRUE;
@@ -1393,7 +1440,7 @@ int main(int argc, char *argv[])
 	}
 	/* make the crash-indicator file */
 	if (str_write_to_file("foo", get_crashfile_name(), FALSE) < 0) {
-		g_warning("can't create the crash-indicator file");
+		g_warning("Can't create the crash-indicator file.");
 	}
 
 	inc_autocheck_timer_init(mainwin);
@@ -1425,7 +1472,7 @@ int main(int argc, char *argv[])
 
 	num_folder_class = g_list_length(folder_get_list());
 
-	plugin_load_all("GTK2");
+	plugin_load_all("GTK3");
 
 	if (g_list_length(folder_get_list()) != num_folder_class) {
 		debug_print("new folders loaded, reloading processing rules\n");
@@ -1503,6 +1550,9 @@ int main(int argc, char *argv[])
 				   "external plugin. Please reinstall the "
 				   "plugin and try again."));
 			exit_claws(mainwin);
+#ifdef G_OS_WIN32
+			win32_close_log();
+#endif
 			exit(1);
 		}
 	}
@@ -1510,7 +1560,10 @@ int main(int argc, char *argv[])
 	static_mainwindow = mainwin;
 
 #ifdef HAVE_STARTUP_NOTIFICATION
-	startup_notification_complete(FALSE);
+#ifdef GDK_WINDOWING_X11
+	if (GDK_IS_X11_DISPLAY(gdk_display_get_default()))
+		startup_notification_complete(FALSE);
+#endif
 #endif
 #ifdef HAVE_LIBSM
 	sc_session_manager_connect(mainwin);
@@ -1520,15 +1573,7 @@ int main(int argc, char *argv[])
 	folderview_thaw(mainwin->folderview);
 	main_window_cursor_normal(mainwin);
 
-	if (cmd.import_mbox) {
-		mainwindow_import_mbox(cmd.import_mbox);
-	}
-
-	if (!cmd.target && prefs_common.goto_folder_on_startup &&
-	    folder_find_item_from_identifier(prefs_common.startup_folder) != NULL &&
-	    !claws_crashed()) {
-		cmd.target = prefs_common.startup_folder;
-	} else if (!cmd.target && prefs_common.goto_last_folder_on_startup &&
+	if (!cmd.target && prefs_common.goto_last_folder_on_startup &&
 	    folder_find_item_from_identifier(prefs_common.last_opened_folder) != NULL &&
 	    !claws_crashed()) {
 		cmd.target = prefs_common.last_opened_folder;
@@ -1591,8 +1636,12 @@ int main(int argc, char *argv[])
 		g_object_unref(nm_proxy);
 #endif
 #ifdef HAVE_DBUS_GLIB
+	uninstall_dbus_status_handler();
 	if(connection)
 		dbus_g_connection_unref(connection);
+#endif
+#ifdef G_OS_WIN32
+	win32_close_log();
 #endif
 	utils_free_regex();
 	exit_claws(mainwin);
@@ -1687,7 +1736,7 @@ static void exit_claws(MainWindow *mainwin)
 
 	main_window_destroy_all();
 	
-	plugin_unload_all("GTK2");
+	plugin_unload_all("GTK3");
 
 	matcher_done();
 	prefs_toolbar_done();
@@ -1718,9 +1767,6 @@ static void exit_claws(MainWindow *mainwin)
 	gtkaspell_checkers_quit();
 #endif
 	plugin_unload_all("Common");
-#ifdef G_OS_WIN32
-	win32_close_log();
-#endif
 	claws_done();
 }
 
@@ -1730,9 +1776,10 @@ static void exit_claws(MainWindow *mainwin)
 		exit(1);	\
 	}
 
-static void parse_cmd_compose_from_file(const gchar *fn, GString *body)
+static GString * parse_cmd_compose_from_file(const gchar *fn)
 {
 	GString *headers = g_string_new(NULL);
+	GString *body = g_string_new(NULL);
 	gchar *to = NULL;
 	gchar *h;
 	gchar *v;
@@ -1789,6 +1836,8 @@ static void parse_cmd_compose_from_file(const gchar *fn, GString *body)
 	/* append the remaining headers */
 	g_string_append(body, headers->str);
 	g_string_free(headers, TRUE);
+
+	return body;
 }
 
 #undef G_PRINT_EXIT
@@ -1805,8 +1854,6 @@ static void parse_cmd_opt_error(char *errstr, char* optstr)
 	exit(1);
 }
 
-static GString mailto; /* used to feed cmd.compose_mailto when --compose-from-file is used */
-
 static void parse_cmd_opt(int argc, char *argv[])
 {
 	AttachInfo *ainfo;
@@ -1825,9 +1872,9 @@ static void parse_cmd_opt(int argc, char *argv[])
 		    if (i+1 < argc) {
 				const gchar *p = argv[i+1];
 
-				parse_cmd_compose_from_file(p, &mailto);
+				GString *mailto = parse_cmd_compose_from_file(p);
 				cmd.compose = TRUE;
-				cmd.compose_mailto = mailto.str;
+				cmd.compose_mailto = mailto->str;
 				i++;
 		    } else {
                 parse_cmd_opt_error(_("Missing file argument for option %s"), argv[i]);
@@ -2013,7 +2060,6 @@ static void parse_cmd_opt(int argc, char *argv[])
  			g_print("%s\n", _("  --reset-statistics     reset session statistics"));
 			g_print("%s\n", _("  --select folder[/msg]  jump to the specified folder/message\n" 
 					  "                         folder is a folder id like 'folder/sub_folder', a file:// uri or an absolute path"));
-			g_print("%s\n", _("  --import-mbox file     import the specified mbox file\n"));
 			g_print("%s\n", _("  --online               switch to online mode"));
 			g_print("%s\n", _("  --offline              switch to offline mode"));
 			g_print("%s\n", _("  --exit --quit -q       exit Claws Mail"));
@@ -2063,13 +2109,6 @@ static void parse_cmd_opt(int argc, char *argv[])
 		    } else {
                 parse_cmd_opt_error(_("Missing folder argument for option %s"), argv[i]);
 			}
-		} else if (!strcmp(argv[i], "--import-mbox")) {
-			if (i+1 < argc) {
-				cmd.import_mbox = argv[i+1];
-				i++;
-			} else {
-				parse_cmd_opt_error(_("Missing file argument for option %s"), argv[i]);
-			}
 		} else if (i == 1 && argc == 2) {
 			/* only one parameter. Do something intelligent about it */
 			if ((strstr(argv[i], "@") || !STRNCMP(argv[i], "mailto:")) && !strstr(argv[i], "://")) {
@@ -2207,7 +2246,7 @@ void app_will_exit(GtkWidget *widget, gpointer data)
 	if (prefs_common.warn_queued_on_exit && procmsg_have_queued_mails_fast()) {
 		if (alertpanel(_("Queued messages"),
 			       _("Some unsent messages are queued. Exit now?"),
-			       GTK_STOCK_CANCEL, GTK_STOCK_OK, NULL, ALERTFOCUS_FIRST)
+			       _("_Cancel"), _("_OK"), NULL, ALERTFOCUS_FIRST)
 		    != G_ALERTALTERNATE) {
 			main_window_popup(mainwin);
 		    	sc_exiting = FALSE;
@@ -2253,8 +2292,8 @@ gchar *claws_get_socket_name(void)
 		gint stat_ok;
 
 		socket_dir = g_strdup_printf("%s%cclaws-mail",
-                                    g_get_user_runtime_dir(), G_DIR_SEPARATOR);
-        stat_ok = g_stat(socket_dir, &st);
+					   g_get_user_runtime_dir(), G_DIR_SEPARATOR);
+		stat_ok = g_stat(socket_dir, &st);
 		if (stat_ok < 0 && errno != ENOENT) {
 			g_print("Error stat'ing socket_dir %s: %s\n",
 				socket_dir, g_strerror(errno));
@@ -2262,7 +2301,6 @@ gchar *claws_get_socket_name(void)
 			/* old versions used a sock in $TMPDIR/claws-mail-$UID */
 			debug_print("Using legacy socket %s\n", socket_dir);
 			filename = g_strdup(socket_dir);
-			g_free(socket_dir);
 			return filename;
 		}
 
@@ -2295,7 +2333,7 @@ static gchar *get_crashfile_name(void)
 	return filename;
 }
 
-static gint prohibit_duplicate_launch(void)
+static gint prohibit_duplicate_launch(int *argc, char ***argv)
 {
 	gint sock;
 	GList *curr;
@@ -2305,9 +2343,6 @@ static gint prohibit_duplicate_launch(void)
 	path = claws_get_socket_name();
 	/* Try to connect to the control socket */
 	sock = fd_connect_unix(path);
-	
-	if (x_display == NULL)
-		x_display = g_strdup(g_getenv("DISPLAY"));
 
 	if (sock < 0) {
 		gint ret;
@@ -2452,7 +2487,7 @@ static gint prohibit_duplicate_launch(void)
 			buf[sizeof(buf) - 1] = '\0';
  			if (!STRNCMP(buf, ".\n")) break;
 			if (claws_fputs(buf, stdout) == EOF) {
-				g_warning("writing to stdout failed");
+				g_warning("writing to stdout failed.");
 				break;
 			}
  		}
@@ -2466,7 +2501,7 @@ static gint prohibit_duplicate_launch(void)
 			buf[sizeof(buf) - 1] = '\0';
  			if (!STRNCMP(buf, ".\n")) break;
 			if (claws_fputs(buf, stdout) == EOF) {
-				g_warning("writing to stdout failed");
+				g_warning("writing to stdout failed.");
 				break;
 			}
  		}
@@ -2476,10 +2511,6 @@ static gint prohibit_duplicate_launch(void)
 		gchar *str = g_strdup_printf("select %s\n", cmd.target);
 		CM_FD_WRITE_ALL(str);
 		g_free(str);
-	} else if (cmd.import_mbox) {
-		gchar *str = g_strdup_printf("import %s\n", cmd.import_mbox);
-		CM_FD_WRITE_ALL(str);
-		g_free(str);
 	} else if (cmd.search) {
 		gchar buf[BUFFSIZE];
 		gchar *str =
@@ -2493,7 +2524,7 @@ static gint prohibit_duplicate_launch(void)
 			buf[sizeof(buf) - 1] = '\0';
 			if (!STRNCMP(buf, ".\n")) break;
 			if (claws_fputs(buf, stdout) == EOF) {
-				g_warning("writing to stdout failed");
+				g_warning("writing to stdout failed.");
 				break;
 			}
 		}
@@ -2504,10 +2535,20 @@ static gint prohibit_duplicate_launch(void)
 		memset(buf, 0, sizeof(buf));
 		fd_gets(sock, buf, sizeof(buf) - 1);
 		buf[sizeof(buf) - 1] = '\0';
-		if (g_strcmp0(buf, x_display)) {
+
+		/* Try to connect to a display; if it is the same one as
+		 * the other Claws instance, then ask it to pop up. */
+		int diff_display = 1;
+		if (gtk_init_check(argc, argv)) {
+			GdkDisplay *display = gdk_display_get_default();
+			diff_display = g_strcmp0(buf, gdk_display_get_name(display));
+		}
+		if (diff_display) {
 			g_print("Claws Mail is already running on display %s.\n",
 				buf);
 		} else {
+			g_print("Claws Mail is already running on this display (%s).\n",
+				buf);
 			fd_close(sock);
 			sock = fd_connect_unix(path);
 			CM_FD_WRITE_ALL("popup\n");
@@ -2538,8 +2579,7 @@ static gint lock_socket_remove(void)
 #ifdef G_OS_UNIX
 	filename = claws_get_socket_name();
 	dirname = g_path_get_dirname(filename);
-	if (claws_unlink(filename) < 0)
-                FILE_OP_ERROR(filename, "claws_unlink");
+	claws_unlink(filename);
 	g_rmdir(dirname);
 	g_free(dirname);
 #endif
@@ -2593,7 +2633,9 @@ static void lock_socket_input_cb(gpointer data,
 		main_window_popup(mainwin);
 #ifdef G_OS_UNIX
 	} else if (!STRNCMP(buf, "get_display")) {
-		CM_FD_WRITE_ALL(x_display);
+		GdkDisplay* display = gtk_widget_get_display(mainwin->window);
+		const gchar *display_name = gdk_display_get_name(display);
+		CM_FD_WRITE_ALL(display_name);
 #endif
 	} else if (!STRNCMP(buf, "receive_all")) {
 		inc_all_account_mail(mainwin, FALSE, FALSE,
@@ -2687,12 +2729,6 @@ static void lock_socket_input_cb(gpointer data,
 				session_stats.received);
  		CM_FD_WRITE_ALL(tmp);
 
-		if (session_stats.spam > 0) {
-			g_snprintf(tmp, sizeof(tmp), _("Spam messages: %d\n"),
-					session_stats.spam);
-			CM_FD_WRITE_ALL(tmp);
-		}
-
  		CM_FD_WRITE_ALL("\n");
 
 		g_snprintf(tmp, sizeof(tmp), _("Outgoing traffic\n"));
@@ -2721,9 +2757,6 @@ static void lock_socket_input_cb(gpointer data,
 	} else if (!STRNCMP(buf, "select ")) {
 		const gchar *target = buf+7;
 		mainwindow_jump_to(target, TRUE);
-	} else if (!STRNCMP(buf, "import ")) {
-		const gchar *mbox_file = buf + 7;
-		mainwindow_import_mbox(mbox_file);
 	} else if (!STRNCMP(buf, "search ")) {
 		FolderItem* folderItem = NULL;
 		GSList *messages = NULL;
@@ -2855,14 +2888,12 @@ static void send_queue(void)
 	}
 }
 
-#ifndef G_OS_WIN32
 static void quit_signal_handler(int sig)
 {
 	debug_print("Quitting on signal %d\n", sig);
 
 	g_timeout_add(0, clean_quit, NULL);
 }
-#endif
 
 static void install_basic_sighandlers()
 {
@@ -2900,6 +2931,57 @@ static void install_basic_sighandlers()
 #endif /* !G_OS_WIN32 */
 }
 
+#if (defined linux && defined SIGIO)
+static int mem_notify_fd = 0;
+
+static gboolean clean_caches(gpointer unused)
+{
+	if (static_mainwindow && static_mainwindow->lock_count > 0)
+		return TRUE;
+	debug_print("/dev/mem_notify: callback: Freeing some memory now!\n");
+	folder_clean_cache_memory_force();
+	return FALSE;
+}
+
+static void memory_signal_handler(int sig)
+{
+	debug_print("/dev/mem_notify: Kernel says we should free up some memory!\n");
+	g_timeout_add(10, clean_caches, NULL); 
+}
+
+static void install_memory_sighandler()
+{
+	sigset_t    mask;
+	struct sigaction act;
+	int flags;
+
+	mem_notify_fd = g_open("/dev/mem_notify", O_RDONLY|O_NONBLOCK, 0);
+	if (mem_notify_fd == -1) {
+		debug_print("/dev/mem_notify not available (%s)\n", 
+			g_strerror(errno));
+		return;
+	}
+	
+	fcntl(mem_notify_fd, F_SETOWN, getpid());
+	flags = fcntl(mem_notify_fd, F_GETFL);
+	fcntl(mem_notify_fd, flags|FASYNC);
+
+	sigemptyset(&mask);
+
+	sigaddset(&mask, SIGIO);
+
+	act.sa_handler = memory_signal_handler;
+	act.sa_mask    = mask;
+	act.sa_flags   = 0;
+
+	sigaction(SIGIO, &act, 0);
+
+	sigprocmask(SIG_UNBLOCK, &mask, 0);
+
+	debug_print("/dev/mem_notify: installed handler\n");
+}
+#endif /* linux && SIGIO */
+
 #ifdef HAVE_NETWORKMANAGER_SUPPORT
 static void networkmanager_state_change_cb(DBusGProxy *proxy, gchar *dev,
 					 gpointer data)
