@@ -43,6 +43,7 @@
 #include "codeconv.h"
 #include "quoted-printable.h"
 #include "claws.h"
+#include <ctype.h>
 #include "prefs_common.h"
 #include "log.h"
 #include "tags.h"
@@ -951,11 +952,11 @@ static gboolean matcherprop_match(MatcherProp *prop,
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message date [ %" CM_TIME_FORMAT " ] is after [ %d ]\n",
+						"message date [ %"G_GSIZE_FORMAT" ] is after [ %d ]\n",
 						info->date_t, prop->value);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message date [ %" CM_TIME_FORMAT " ] is not after [ %d ]\n",
+						"message date [ %ld ] is not after [ %d ]\n",
 						info->date_t, prop->value);
 			}
 		}
@@ -999,11 +1000,11 @@ static gboolean matcherprop_match(MatcherProp *prop,
 				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
 			if (ret) {
 				log_print(LOG_DEBUG_FILTERING,
-						"message date [ %" CM_TIME_FORMAT " ] is before [ %d ]\n",
+						"message date [ %ld ] is before [ %d ]\n",
 						info->date_t, prop->value);
 			} else {
 				log_print(LOG_DEBUG_FILTERING,
-						"message date [ %" CM_TIME_FORMAT " ] is not before [ %d ]\n",
+						"message date [ %ld ] is not before [ %d ]\n",
 						info->date_t, prop->value);
 			}
 		}
@@ -2431,13 +2432,11 @@ static int prefs_filtering_write(FILE *fp, GSList *prefs_filtering)
 		if (prop->enabled) {
 			if (claws_fputs("enabled ", fp) == EOF) {
 				FILE_OP_ERROR("filtering config", "claws_fputs");
-				g_free(filtering_str);
 				return -1;
 			}
 		} else {
 			if (claws_fputs("disabled ", fp) == EOF) {
 				FILE_OP_ERROR("filtering config", "claws_fputs");
-				g_free(filtering_str);
 				return -1;
 			}
 		}
@@ -2477,7 +2476,6 @@ static int prefs_filtering_write(FILE *fp, GSList *prefs_filtering)
 			tmp = g_strdup_printf("account %d ", prop->account_id);
 			if (claws_fputs(tmp, fp) == EOF) {
 				FILE_OP_ERROR("filtering config", "claws_fputs");
-				g_free(filtering_str);
 				g_free(tmp);
 				return -1;
 			}
