@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,6 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,6 +31,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <dirent.h>
 #include <unistd.h>
 #include <time.h>
 #include <libetpan/libetpan.h>
@@ -399,12 +401,12 @@ static Session *news_session_new_for_folder(Folder *folder)
 	if (ac->ssl_nntp != SSL_NONE) {
 		if (alertpanel_full(_("Insecure connection"),
 			_("This connection is configured to be secured "
-			  "using TLS, but TLS is not available "
+			  "using SSL/TLS, but SSL/TLS is not available "
 			  "in this build of Claws Mail. \n\n"
 			  "Do you want to continue connecting to this "
 			  "server? The communication would not be "
 			  "secure."),
-			  GTK_STOCK_CANCEL, _("Con_tinue connecting"), NULL,
+			  _("_Cancel"), _("Con_tinue connecting"), NULL,
 				ALERTFOCUS_FIRST, FALSE, NULL, ALERT_WARNING) != G_ALERTALTERNATE)
 			return NULL;
 	}
@@ -949,7 +951,6 @@ gint news_cancel_article(Folder * folder, MsgInfo * msginfo)
 
 	if ((tmpfp = claws_fopen(tmp, "wb")) == NULL) {
 		FILE_OP_ERROR(tmp, "claws_fopen");
-		g_free(tmp);
 		return -1;
 	}
 	if (change_file_mode_rw(tmpfp, tmp) < 0) {
