@@ -2,7 +2,7 @@
 
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2018 Michael Rasmussen and the Claws Mail Team
+ * Copyright (C) 1999-2019 Michael Rasmussen and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -114,7 +114,7 @@ static void create_progress_dialog(struct ArchivePage* page) {
 				title,
 				GTK_WINDOW(mainwin->window),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_STOCK_CANCEL,
+				_("_Cancel"),
 				GTK_RESPONSE_CANCEL,
 				NULL);
 
@@ -131,11 +131,11 @@ static void create_progress_dialog(struct ArchivePage* page) {
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG(progress->progress_dialog));
 	gtk_container_add(GTK_CONTAINER(content_area), progress->frame);
 
-	progress->vbox1 = gtk_vbox_new (FALSE, 4);
+	progress->vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_container_set_border_width (GTK_CONTAINER (progress->vbox1), 4);
 	gtk_container_add(GTK_CONTAINER(progress->frame), progress->vbox1);
 	
-	progress->hbox1 = gtk_hbox_new(FALSE, 8);
+	progress->hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_container_set_border_width(GTK_CONTAINER(progress->hbox1), 8);
 	gtk_box_pack_start(GTK_BOX(progress->vbox1),
 					progress->hbox1, FALSE, FALSE, 0);
@@ -150,7 +150,7 @@ static void create_progress_dialog(struct ArchivePage* page) {
 	gtk_box_pack_start(GTK_BOX(progress->hbox1),
 					progress->file_label, TRUE, TRUE, 0);
 
-	progress->hbox1 = gtk_hbox_new(FALSE, 8);
+	progress->hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_container_set_border_width(GTK_CONTAINER(progress->hbox1), 8);
 	gtk_box_pack_start(GTK_BOX(progress->vbox1),
 					progress->hbox1, FALSE, FALSE, 0);
@@ -572,7 +572,7 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 			AlertValue aval;
 
 			aval = alertpanel_full(_("Creating archive"), msg,
-				GTK_STOCK_CANCEL, GTK_STOCK_OK, NULL, ALERTFOCUS_FIRST, FALSE,
+				_("_Cancel"), _("_OK"), NULL, ALERTFOCUS_FIRST, FALSE,
 				NULL, ALERT_WARNING);
 			g_free(msg);
 			if (aval != G_ALERTALTERNATE)
@@ -619,7 +619,7 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 				  "\nContinue anyway?"),
 				orig_file, g_slist_length(list));
 		aval = alertpanel_full(_("Creating archive"), msg,
-			GTK_STOCK_CANCEL, GTK_STOCK_OK, NULL, ALERTFOCUS_FIRST, FALSE,
+			_("_Cancel"), _("_OK"), NULL, ALERTFOCUS_FIRST, FALSE,
 			NULL, ALERT_WARNING);
 		g_free(msg);
 		if (aval != G_ALERTALTERNATE) {
@@ -746,7 +746,7 @@ static void show_result(struct ArchivePage* page) {
 			_("Archive result"),
 			GTK_WINDOW(mainwin->window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_OK,
+			_("_OK"),
 			GTK_RESPONSE_NONE,
 			NULL);
 	g_signal_connect_swapped(
@@ -935,22 +935,25 @@ static void filesel_cb(GtkWidget *widget, gpointer data)
 	GtkWidget *dialog;
 	gchar* file;
 	gint newpos = 0;
+	const gchar* homedir;
 	struct ArchivePage* page = (struct ArchivePage *) data;
 
 	dialog = gtk_file_chooser_dialog_new(
 		_("Select file name for archive [suffix should reflect archive like .tgz]"),
 			NULL,
 			GTK_FILE_CHOOSER_ACTION_SAVE,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+			_("_Cancel"), GTK_RESPONSE_CANCEL,
+			_("_Apply"), GTK_RESPONSE_APPLY,
 			NULL);
+	homedir = g_getenv("HOME");
+	if (!homedir)
+		homedir = g_get_home_dir();
 
 	if (archiver_prefs.save_folder)
-		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), 
 						    archiver_prefs.save_folder);
 	else
-		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
-						    get_home_dir());
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), homedir);
 	if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_RESPONSE_APPLY) {
 		file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 		if (file) {
@@ -995,7 +998,7 @@ void set_progress_print_all(guint fraction, guint total, guint step) {
 	}
 }
 
-void archiver_gtk_show(void) {
+void archiver_gtk_show() {
 	GtkWidget* dialog;
 	GtkWidget* frame;
 	GtkWidget* vbox1;
@@ -1040,9 +1043,9 @@ void archiver_gtk_show(void) {
 				_("Create Archive"),
 				GTK_WINDOW(mainwin->window),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_STOCK_CANCEL,
+				_("_Cancel"),
 				GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OK,
+				_("_OK"),
 				GTK_RESPONSE_ACCEPT,
 				NULL);
 
@@ -1058,11 +1061,11 @@ void archiver_gtk_show(void) {
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 	gtk_container_add(GTK_CONTAINER(content_area), frame);
 
-	vbox1 = gtk_vbox_new (FALSE, 4);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), vbox1);
 	
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, FALSE, 0);
 
@@ -1080,7 +1083,7 @@ void archiver_gtk_show(void) {
 	CLAWS_SET_TIP(folder_select,
 			_("Click this button to select a folder which is to be root of the archive"));
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, FALSE, 0);
 
@@ -1102,7 +1105,7 @@ void archiver_gtk_show(void) {
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
 
@@ -1231,7 +1234,7 @@ void archiver_gtk_show(void) {
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
 
@@ -1281,7 +1284,7 @@ void archiver_gtk_show(void) {
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
 
@@ -1320,7 +1323,7 @@ void archiver_gtk_show(void) {
 	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
 
