@@ -27,6 +27,7 @@
 
 #include "defs.h"
 
+#include <glib.h>
 #include <gtk/gtk.h>
 
 #include "gtkutils.h"
@@ -201,15 +202,15 @@ static void create_archiver_prefs_page(PrefsPage * _page,
 	GtkWidget *rename_chkbtn;
         GtkWidget *unlink_chkbtn;
 
-	vbox1 = gtk_vbox_new (FALSE, VSPACING);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 
-	vbox2 = gtk_vbox_new (FALSE, 4);
+	vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show (vbox2);
 	gtk_box_pack_start (GTK_BOX (vbox1), vbox2, FALSE, FALSE, 0);
 
-  	hbox1 = gtk_hbox_new (FALSE, 8);
+  	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);
 
@@ -236,7 +237,7 @@ static void create_archiver_prefs_page(PrefsPage * _page,
 
 	PACK_FRAME (vbox1, frame, _("Default compression"));
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_widget_show(hbox1);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
@@ -361,7 +362,7 @@ static void create_archiver_prefs_page(PrefsPage * _page,
 
 	PACK_FRAME (vbox1, frame, _("Default format"));
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_widget_show(hbox1);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
@@ -407,7 +408,7 @@ static void create_archiver_prefs_page(PrefsPage * _page,
 
 	PACK_FRAME (vbox1, frame, _("Default miscellaneous options"));
 
-	hbox1 = gtk_hbox_new(FALSE, 4);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_widget_show(hbox1);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
 	gtk_container_add(GTK_CONTAINER(frame), hbox1);
@@ -552,7 +553,7 @@ static void save_archiver_prefs(PrefsPage * _page)
           return;
         
         if (prefs_write_param(param, pref_file->fp) < 0) {
-          g_warning("failed to write Archiver plugin configuration");
+          g_warning("failed to write Archiver Plugin configuration");
           prefs_file_close_revert(pref_file);
           return;
         }
