@@ -1,9 +1,11 @@
 /*
  * att_remover -- for Claws Mail
- * Copyright (C) 2005-2024 the Claws Mail Team and Colin Leroy
  *
- * Claws Mail is a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail Team and Hiroyuki Yamamoto
+ * Copyright (C) 2005=2019 Colin Leroy <colin@colino.net>
+ * 	 and the Claws Mail Team
+ *
+ * Sylpheed is a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +39,7 @@
 #include "summaryview.h"
 #include "folder.h"
 #include "version.h"
+#include "summaryview.h"
 #include "procmime.h"
 #include "alertpanel.h"
 #include "inc.h"
@@ -100,8 +103,8 @@ static void size_allocate_cb(GtkWidget *widget, GtkAllocation *allocation)
 {
 	cm_return_if_fail(allocation != NULL);
 
-	AttRemoverData.win_width = allocation->width;
-	AttRemoverData.win_height = allocation->height;
+	gtk_window_get_size(GTK_WINDOW(widget),
+			&AttRemoverData.win_width, &AttRemoverData.win_height);
 }
 
 static gint save_new_message(MsgInfo *oldmsg, MsgInfo *newmsg, MimeInfo *info,
@@ -283,25 +286,25 @@ static void fill_attachment_store(GtkTreeView *list_view, MimeInfo *partinfo)
 	partinfo = procmime_mimeinfo_next(partinfo);
 	if (!partinfo)
 		return;
-
+		
 	while (partinfo) {
 		if (MIMEINFO_NOT_ATTACHMENT(partinfo)) {
     			partinfo = procmime_mimeinfo_next(partinfo);
 			continue;
 		}
-
+			
 		content_type = procmime_get_content_type_str(
 					partinfo->type, partinfo->subtype);
-
-		name = g_markup_escape_text(procmime_mimeinfo_get_parameter(partinfo, "filename"), -1);
+		
+		name = procmime_mimeinfo_get_parameter(partinfo, "filename");
 		if (!name)
-			name = g_markup_escape_text(procmime_mimeinfo_get_parameter(partinfo, "name"), -1);
+			name = procmime_mimeinfo_get_parameter(partinfo, "name");
 		if (!name)
 			name = _("unknown");
-
-		label = g_strconcat("<b>", _("Type"), ":</b> ", content_type, "   <b>",
-			 _("Size"), ":</b> ", to_human_readable((goffset)partinfo->length),
-			"\n", "<b>", _("Filename"), ":</b> ", name, NULL);
+		
+		label = g_strconcat("<b>",_("Type:"), "</b> ", content_type, "   <b>",
+			 _("Size:"), "</b> ", to_human_readable((goffset)partinfo->length),
+			"\n", "<b>", _("Filename:"), "</b> ", name, NULL);
 
 		gtk_list_store_append(list_store, &iter);
 		gtk_list_store_set(list_store, &iter,
@@ -344,7 +347,7 @@ static void remove_attachments_dialog(AttRemover *attremover)
 	g_signal_connect(G_OBJECT(window), "size_allocate",
 			 G_CALLBACK(size_allocate_cb), NULL);
 
-	vbox = gtk_vbox_new(FALSE, VBOX_BORDER);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 
 	model = GTK_TREE_MODEL(gtk_list_store_new(N_ATT_REMOVER_COLUMNS,
@@ -352,11 +355,11 @@ static void remove_attachments_dialog(AttRemover *attremover)
 				  G_TYPE_BOOLEAN,
 				  -1));
 	list_view = GTK_TREE_VIEW(gtk_tree_view_new_with_model(model));
+	g_object_unref(model);	
 	gtk_tree_view_set_rules_hint(list_view, prefs_common_get_prefs()->use_stripes_everywhere);
 	
 	renderer = gtk_cell_renderer_toggle_new();
 	g_signal_connect(renderer, "toggled", G_CALLBACK(remove_toggled_cb), model);
-	g_object_unref(model);	
 	column = gtk_tree_view_column_new_with_attributes
 		(_("Remove"),
 		renderer,
@@ -382,8 +385,8 @@ static void remove_attachments_dialog(AttRemover *attremover)
 	gtk_container_set_border_width(GTK_CONTAINER(scrollwin), 4);
 	gtk_box_pack_start(GTK_BOX(vbox), scrollwin, TRUE, TRUE, 0); 
 
-	gtkut_stock_button_set_create(&hbbox, &cancel_btn, GTK_STOCK_CANCEL,
-				      &ok_btn, GTK_STOCK_OK,
+	gtkut_stock_button_set_create(&hbbox, &cancel_btn, _("_Cancel"),
+				      &ok_btn, _("_OK"),
 				      NULL, NULL);
 	gtk_box_pack_end(GTK_BOX(vbox), hbbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbbox), HSPACING_NARROW);
@@ -401,7 +404,7 @@ static void remove_attachments_dialog(AttRemover *attremover)
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(window), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
-	gtk_widget_set_size_request(window, attremover->win_width,
+	gtk_window_set_default_size(GTK_WINDOW(window), attremover->win_width,
 					attremover->win_height);
 
 	attremover->window = window;
@@ -424,7 +427,7 @@ static void remove_attachments(GSList *msglist)
                   _("Do you really want to remove all attachments from "
                   "the selected messages?\n\n"
 		  "The deleted data will be unrecoverable."), 
-		  GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL, ALERTFOCUS_SECOND,
+		  _("_Cancel"), "edit-delete", NULL, ALERTFOCUS_SECOND,
                   FALSE, NULL, ALERT_QUESTION) != G_ALERTALTERNATE)
 		return;
 
@@ -559,7 +562,7 @@ gboolean plugin_done(void)
         	return TRUE;
         
 	if (prefs_write_param(prefs, pref_file->fp) < 0) {
-		g_warning("failed to write AttRemover plugin configuration");
+		g_warning("failed to write AttRemover Plugin configuration");
 		prefs_file_close_revert(pref_file);
 		return TRUE;
         }
@@ -597,7 +600,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
