@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2006-2022 Ricardo Mones and the Claws Mail Team
+ * Copyright (C) 2006-2019 Ricardo Mones and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ AttachWarnerPrefs attwarnerprefs;
 struct AttachWarnerPrefsPage
 {
 	PrefsPage page;
-
+	
 	GtkWidget *regexp_text;
 	GtkWidget *skip_quotes_checkbox;
 	GtkWidget *skip_forwards_and_redirections;
@@ -63,8 +63,8 @@ static PrefParam param[] = {
 };
 
 static void attwarner_prefs_create_widget_func(PrefsPage * _page,
-				GtkWindow * window,
-				gpointer data)
+					   GtkWindow * window,
+					   gpointer data)
 {
 	struct AttachWarnerPrefsPage *page = (struct AttachWarnerPrefsPage *) _page;
 	GtkWidget *vbox, *vbox1, *vbox2;
@@ -77,17 +77,17 @@ static void attwarner_prefs_create_widget_func(PrefsPage * _page,
 	GtkWidget *skip_signature_checkbox;
 	GtkWidget *case_sensitive_checkbox;
 
-	vbox1 = gtk_vbox_new(FALSE, 6);
-	vbox2 = gtk_vbox_new(FALSE, 6);
-
-	label = gtk_label_new(_("Warn when one of the following regular expressions is matched (one per line)"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_misc_set_padding(GTK_MISC(label), 2, 0);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+	vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+	
+	label = gtk_label_new(_("One of the following regular expressions is matched (one per line)"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
+	gtk_widget_set_margin_start(GTK_WIDGET(label), 2);
+	gtk_widget_set_margin_end(GTK_WIDGET(label), 0);
 
 	case_sensitive_checkbox = gtk_check_button_new_with_label(_("Expressions are case sensitive"));
-	gtk_toggle_button_set_active(
-		GTK_TOGGLE_BUTTON(case_sensitive_checkbox),
-		attwarnerprefs.case_sensitive);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(case_sensitive_checkbox),
+	    	 attwarnerprefs.case_sensitive);
 	gtk_widget_show(case_sensitive_checkbox);
 
 	CLAWS_SET_TIP(case_sensitive_checkbox,
@@ -97,68 +97,65 @@ static void attwarner_prefs_create_widget_func(PrefsPage * _page,
 	page->regexp_text = gtk_text_view_new();
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(page->regexp_text));
 	gtk_text_buffer_set_text(buffer, attwarnerprefs.match_strings, -1);
-
+	
 	scrolledwin = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(
-		GTK_SCROLLED_WINDOW (scrolledwin),
-		GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type(
-		GTK_SCROLLED_WINDOW (scrolledwin), GTK_SHADOW_IN);
+	gtk_scrolled_window_set_policy
+		(GTK_SCROLLED_WINDOW (scrolledwin),
+		 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type
+		(GTK_SCROLLED_WINDOW (scrolledwin), GTK_SHADOW_IN);
 	gtk_container_set_border_width(GTK_CONTAINER(scrolledwin), 3);
 
 	gtk_container_add(GTK_CONTAINER(scrolledwin), page->regexp_text);
-	gtk_widget_set_size_request(scrolledwin, -1, 100);
+	gtk_widget_set_size_request(page->regexp_text, -1, 100);
 
 	gtk_box_pack_start(GTK_BOX(vbox1), label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), scrolledwin, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), case_sensitive_checkbox, FALSE, FALSE, 0);
-
+	
 	skip_quotes_checkbox = gtk_check_button_new_with_label(_("Lines starting with quotation marks"));
-	gtk_toggle_button_set_active(
-		GTK_TOGGLE_BUTTON(skip_quotes_checkbox),
-		attwarnerprefs.skip_quotes);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(skip_quotes_checkbox),
+	    	 attwarnerprefs.skip_quotes);
 	gtk_box_pack_start(GTK_BOX(vbox2), skip_quotes_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(skip_quotes_checkbox);
 
 	CLAWS_SET_TIP(skip_quotes_checkbox,
-		_("Exclude quoted lines from checking for the regular "
-		  "expressions above. Note that handmade quotes cannot "
-		  "be distinguished from quotes generated by replying."));
+			_("Exclude quoted lines from checking for the regular expressions above. Note that handmade quotes cannot be distinguished from quotes generated by replying."));
 	page->skip_quotes_checkbox = skip_quotes_checkbox;
 	
 	skip_fwd_redir_checkbox = gtk_check_button_new_with_label(_("Forwarded or redirected messages"));
-	gtk_toggle_button_set_active(
-		GTK_TOGGLE_BUTTON(skip_fwd_redir_checkbox),
-		attwarnerprefs.skip_forwards_and_redirections);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(skip_fwd_redir_checkbox),
+	    	 attwarnerprefs.skip_forwards_and_redirections);
 	gtk_box_pack_start(GTK_BOX(vbox2), skip_fwd_redir_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(skip_fwd_redir_checkbox);
 
 	CLAWS_SET_TIP(skip_fwd_redir_checkbox,
-		_("Don't check for missing attachments when forwarding or redirecting messages"));
+			_("Don't check for missing attachments when forwarding or redirecting messages"));
 	page->skip_forwards_and_redirections = skip_fwd_redir_checkbox;
 
 	skip_signature_checkbox = gtk_check_button_new_with_label(_("Signatures"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(skip_signature_checkbox),
-		attwarnerprefs.skip_signature);
+	    	 attwarnerprefs.skip_signature);
 	gtk_box_pack_start(GTK_BOX(vbox2), skip_signature_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(skip_signature_checkbox);
 
 	CLAWS_SET_TIP(skip_signature_checkbox,
-		_("Exclude lines from the first signature-separator onwards "
-		  "from checking for the regular expressions above"));
+			_("Exclude lines from the first signature-separator onwards from checking for the regular expressions above"));
 	page->skip_signature = skip_signature_checkbox;
 	
-	vbox = gtk_vbox_new(FALSE, VSPACING);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), VBOX_BORDER);
 
-	gtk_container_add(GTK_CONTAINER(vbox), vbox1);
+	PACK_FRAME (vbox, frame, _("Warn when"));
+	gtk_container_set_border_width(GTK_CONTAINER(vbox1), 6);
+	gtk_container_add(GTK_CONTAINER(frame), vbox1);
 
-	PACK_FRAME (vbox, frame, _("Exclude"));
+	PACK_FRAME (vbox, frame, _("Excluding"));
 	gtk_container_set_border_width(GTK_CONTAINER(vbox2), 6);
 	gtk_container_add(GTK_CONTAINER(frame), vbox2);
 
 	gtk_widget_show_all(vbox);
-
+	
 	page->page.widget = vbox;
 }
 
@@ -184,11 +181,11 @@ static void attwarner_save_config(void)
 		prefs_file_close_revert(pfile);
 		return;
 	}
-	if (fprintf(pfile->fp, "\n") < 0) {
+        if (fprintf(pfile->fp, "\n") < 0) {
 		FILE_OP_ERROR(rcpath, "fprintf");
 		prefs_file_close_revert(pfile);
 	} else
-		prefs_file_close(pfile);
+	        prefs_file_close(pfile);
 }
 
 
@@ -199,25 +196,25 @@ static void attwarner_prefs_save_func(PrefsPage * _page)
 	GtkTextIter start, end;
 	gchar *tmp;
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(page->regexp_text));
-
+	
 	g_free(attwarnerprefs.match_strings);
-
+	
 	gtk_text_buffer_get_start_iter(buffer, &start);
 	gtk_text_buffer_get_end_iter(buffer, &end);
-
+	
 	tmp = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
-
+	
 	attwarnerprefs.match_strings = g_malloc(2*strlen(tmp)+1);
 	pref_get_escaped_pref(attwarnerprefs.match_strings, tmp);
 
-	attwarnerprefs.skip_quotes = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->skip_quotes_checkbox));
-	attwarnerprefs.skip_forwards_and_redirections = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->skip_forwards_and_redirections));
-	attwarnerprefs.skip_signature = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->skip_signature));
-	attwarnerprefs.case_sensitive = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->case_sensitive_checkbox));
+	attwarnerprefs.skip_quotes = gtk_toggle_button_get_active
+			(GTK_TOGGLE_BUTTON(page->skip_quotes_checkbox));
+	attwarnerprefs.skip_forwards_and_redirections = gtk_toggle_button_get_active
+			(GTK_TOGGLE_BUTTON(page->skip_forwards_and_redirections));
+	attwarnerprefs.skip_signature = gtk_toggle_button_get_active
+			(GTK_TOGGLE_BUTTON(page->skip_signature));
+	attwarnerprefs.case_sensitive = gtk_toggle_button_get_active
+			(GTK_TOGGLE_BUTTON(page->case_sensitive_checkbox));
 
 	attwarner_save_config();
 	g_free(attwarnerprefs.match_strings);
@@ -229,9 +226,9 @@ void attachwarner_prefs_init(void)
 	static gchar *path[3];
 	gchar *rcpath;
 	gchar *tmp;
-
+	
 	path[0] = _("Plugins");
-	path[1] = _("AttachWarner");
+	path[1] = _("Attach Warner");
 	path[2] = NULL;
 
 	prefs_set_default(param);
@@ -241,10 +238,10 @@ void attachwarner_prefs_init(void)
 
 	tmp = g_malloc(strlen(attwarnerprefs.match_strings)+1);
 	pref_get_unescaped_pref(tmp, attwarnerprefs.match_strings);
-
+	
 	g_free(attwarnerprefs.match_strings);
 	attwarnerprefs.match_strings = tmp;
-
+	
 	attwarnerprefs_page.page.path = path;
 	attwarnerprefs_page.page.create_widget = attwarner_prefs_create_widget_func;
 	attwarnerprefs_page.page.destroy_widget = attwarner_prefs_destroy_widget_func;
