@@ -1,6 +1,7 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2023 the Claws Mail team and Colin Leroy
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2012 Colin Leroy <colin@colino.net> and 
+ * the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +27,7 @@
 
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <errno.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -45,7 +47,6 @@
 #include "prefs_gtk.h"
 
 #include "bogofilter.h"
-#include "main.h"
 #include "inc.h"
 #include "log.h"
 #include "prefs_common.h"
@@ -85,8 +86,6 @@ static MessageCallback message_callback;
 
 static BogofilterConfig config;
 
-extern SessionStats session_stats;
-
 static PrefParam param[] = {
 	{"process_emails", "TRUE", &config.process_emails, P_BOOL,
 	 NULL, NULL, NULL},
@@ -175,7 +174,7 @@ static void bogofilter_do_filter(BogoFilterData *data)
 	GSList *cur = NULL;
 	int total = 0, curnum = 1;
 	gchar *file = NULL;
-	gchar buf[BUFFSIZE];
+	gchar buf[BUFSIZ];
 
 	total = g_slist_length(data->msglist);
 
@@ -209,7 +208,6 @@ static void bogofilter_do_filter(BogoFilterData *data)
 		for (cur = data->msglist; cur; cur = cur->next) {
 			gboolean whitelisted = FALSE;
 			msginfo = (MsgInfo *)cur->data;
-			ssize_t n_read;
 			debug_print("Filtering message %d (%d/%d)\n", msginfo->msgnum, curnum, total);
 
 			if (message_callback != NULL)
@@ -231,7 +229,7 @@ static void bogofilter_do_filter(BogoFilterData *data)
 				g_free(tmp);
 				memset(buf, 0, sizeof(buf));
 				/* get the result */
-				if ((n_read = read(bogo_stdout, buf, sizeof(buf)-1)) < 0) {
+				if (read(bogo_stdout, buf, sizeof(buf)-1) < 0) {
 					g_warning("bogofilter short read");
 					debug_print("message %d is ham\n", msginfo->msgnum);
 					data->mail_filtering_data->unfiltered = g_slist_prepend(
@@ -240,15 +238,15 @@ static void bogofilter_do_filter(BogoFilterData *data)
 				} else {
 					gchar **parts = NULL;
 
-					buf[n_read] = '\0';
+					buf[sizeof(buf) - 1] = '\0';
 					if (strchr(buf, '/')) {
 						tmp = strrchr(buf, '/')+1;
 					} else {
 						tmp = buf;
 					}
 					parts = g_strsplit(tmp, " ", 0);
-					debug_print("read '%s'\n", g_strchomp(buf));
-
+					debug_print("read %s\n", buf);
+					
 					/* note the result if the header if needed */
 					if (parts && parts[0] && parts[1] && parts[2] && 
 					    FOLDER_TYPE(msginfo->folder->folder) == F_MH &&
@@ -274,7 +272,7 @@ static void bogofilter_do_filter(BogoFilterData *data)
 							if (claws_fwrite(tmpstr, 1, strlen(tmpstr), output) < strlen(tmpstr)) {
 								err = TRUE;
 							} else {
-								while (claws_fgets(tmpbuf, sizeof(tmpbuf), input)) {
+								while (claws_fgets(tmpbuf, sizeof(buf), input)) {
 									if (claws_fputs(tmpbuf, output) == EOF) {
 										err = TRUE;
 										break;
@@ -306,7 +304,7 @@ static void bogofilter_do_filter(BogoFilterData *data)
 								data->mail_filtering_data->filtered, msginfo);
 						}
 						data->new_spams = g_slist_prepend(data->new_spams, msginfo);
-						session_stats.spam++;
+
 					} else if (whitelisted && parts && parts[0] && parts[1] && 
 							(*parts[1] == 'S' || *parts[1] == 'U')) {
 
@@ -733,7 +731,6 @@ int bogofilter_learn(MsgInfo *msginfo, GSList *msglist, gboolean spam)
 		return -1;
 	}
 
-	/* process *either* a msginfo or a msglist */
 	if (msginfo) {
 		file = procmsg_get_message_file(msginfo);
 		if (file == NULL) {
@@ -885,7 +882,7 @@ void bogofilter_save_config(void)
 		return;
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("failed to write Bogofilter configuration to file");
+		g_warning("Failed to write Bogofilter configuration to file");
 		prefs_file_close_revert(pfile);
 		return;
 	}
@@ -1001,7 +998,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
@@ -1028,7 +1025,7 @@ void bogofilter_register_hook(void)
 	if (hook_id == HOOK_NONE)
 		hook_id = hooks_register_hook(MAIL_LISTFILTERING_HOOKLIST, mail_filtering_hook, NULL);
 	if (hook_id == HOOK_NONE) {
-		g_warning("failed to register mail filtering hook");
+		g_warning("Failed to register mail filtering hook");
 		config.process_emails = FALSE;
 	}
 }
