@@ -145,15 +145,15 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	GtkWidget *whitelist_ab_folder_combo;
 	GtkWidget *whitelist_ab_select_btn;
 
-	vbox1 = gtk_vbox_new (FALSE, VSPACING);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 
-	vbox2 = gtk_vbox_new (FALSE, 4);
+	vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show (vbox2);
 	gtk_box_pack_start (GTK_BOX (vbox1), vbox2, FALSE, FALSE, 0);
 
-	hbox_process_emails = gtk_hbox_new(FALSE, 8);
+	hbox_process_emails = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_process_emails);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_process_emails, TRUE, TRUE, 0);
 
@@ -162,7 +162,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	gtk_widget_show(process_emails_checkbtn);
 	gtk_box_pack_start(GTK_BOX(hbox_process_emails), process_emails_checkbtn, TRUE, TRUE, 0);
 
-	hbox_max_size = gtk_hbox_new(FALSE, 8);
+	hbox_max_size = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_max_size);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_max_size, TRUE, TRUE, 0);
 
@@ -178,11 +178,11 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 			_("Messages larger than this will not be checked"));
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(max_size_spinbtn), TRUE);
 
-	max_size_kb_label = gtk_label_new(_("KiB"));
+	max_size_kb_label = gtk_label_new(_("KB"));
 	gtk_widget_show(max_size_kb_label);
 	gtk_box_pack_start(GTK_BOX(hbox_max_size), max_size_kb_label, FALSE, FALSE, 0);
 
-	hbox_save_spam = gtk_hbox_new(FALSE, 8);
+	hbox_save_spam = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_save_spam);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_save_spam, TRUE, TRUE, 0);
 
@@ -200,7 +200,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	gtk_widget_show(spam_handle_combobox);
 	gtk_box_pack_start(GTK_BOX(hbox_save_spam), spam_handle_combobox, FALSE, FALSE, 0);
 
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 8);
+	GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox);
 	gtk_box_pack_start (GTK_BOX (hbox_save_spam), hbox, TRUE, TRUE, 0);
 
@@ -219,7 +219,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	g_signal_connect(G_OBJECT(spam_handle_combobox), "changed",
 			G_CALLBACK(spam_handle_combobox_callback), (gpointer)hbox);
 
-	hbox_save_unsure = gtk_hbox_new(FALSE, 8);
+	hbox_save_unsure = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_save_unsure);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_save_unsure, TRUE, TRUE, 0);
 
@@ -245,7 +245,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	CLAWS_SET_TIP(insert_header_checkbtn,
 			_("Only done for messages in MH folders"));
 
-	hbox_whitelist = gtk_hbox_new(FALSE, 8);
+	hbox_whitelist = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_whitelist);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_whitelist, TRUE, TRUE, 0);
 
@@ -272,7 +272,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	gtk_widget_show(learn_from_whitelist_chkbtn);
 	gtk_box_pack_start (GTK_BOX (vbox2), learn_from_whitelist_chkbtn, TRUE, TRUE, 0);
 
-	hbox_bogopath = gtk_hbox_new(FALSE, 8);
+	hbox_bogopath = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_bogopath);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_bogopath, FALSE, FALSE, 0);
 
@@ -286,7 +286,7 @@ static void bogofilter_create_widget_func(PrefsPage * _page,
 	CLAWS_SET_TIP(bogopath_entry,
 			_("Path to bogofilter executable"));
 
-	hbox_mark_as_read = gtk_hbox_new(FALSE, 8);
+	hbox_mark_as_read = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_mark_as_read);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_mark_as_read, TRUE, TRUE, 0);
 
