@@ -1,7 +1,7 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2023 the Claws Mail team and
- * Colin Leroy <colin@colino.net>
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> and 
+ * the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@
 #ifdef USE_PTHREAD
 #include <pthread.h>
 #endif
+#include <errno.h>
+
+#include <glib.h>
 
 #include "common/claws.h"
 #include "common/version.h"
@@ -48,7 +51,6 @@
 #include "utils.h"
 
 #include "bsfilter.h"
-#include "main.h"
 #include "inc.h"
 #include "log.h"
 #include "prefs_common.h"
@@ -84,8 +86,6 @@ static MessageCallback message_callback;
 
 static BsfilterConfig config;
 
-extern SessionStats session_stats;
-
 static PrefParam param[] = {
 	{"process_emails", "TRUE", &config.process_emails, P_BOOL,
 	 NULL, NULL, NULL},
@@ -175,7 +175,6 @@ static void bsfilter_do_filter(BsFilterData *data)
 #endif
 		status = execute_command_line(classify, FALSE,
 				claws_get_startup_dir());
-		g_free(classify);
 	}
 
 	if (config.whitelist_ab)
@@ -343,7 +342,6 @@ static gboolean mail_filtering_hook(gpointer source, gpointer data)
 	} else {
 		if (!whitelisted || (whitelisted && !config.learn_from_whitelist)) {
 			procmsg_msginfo_set_flags(msginfo, MSG_SPAM, 0);
-			session_stats.spam++;
 			debug_print("flagging spam: %d\n", msginfo->msgnum);
 			filtered = TRUE;
 		}
@@ -463,7 +461,6 @@ int bsfilter_learn(MsgInfo *msginfo, GSList *msglist, gboolean spam)
 	if (msginfo == NULL && msglist == NULL) {
 		return -1;
 	}
-	/* process *either* a msginfo or a msglist */
 	if (msginfo != NULL && msglist == NULL) {
 		msglist = g_slist_append(NULL, msginfo);
 		free_list = TRUE;
@@ -514,7 +511,7 @@ void bsfilter_save_config(void)
 		return;
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("failed to write Bsfilter configuration to file");
+		g_warning("Failed to write Bsfilter configuration to file");
 		prefs_file_close_revert(pfile);
 		return;
 	}
@@ -633,7 +630,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
@@ -660,7 +657,7 @@ void bsfilter_register_hook(void)
 	if (hook_id == HOOK_NONE)
 		hook_id = hooks_register_hook(MAIL_FILTERING_HOOKLIST, mail_filtering_hook, NULL);
 	if (hook_id == HOOK_NONE) {
-		g_warning("failed to register mail filtering hook");
+		g_warning("Failed to register mail filtering hook");
 		config.process_emails = FALSE;
 	}
 }
