@@ -1,7 +1,7 @@
 /*
  * Claws Mail -- A GTK+ based, lightweight, and fast e-mail client
  * == Fancy Plugin ==
- * Copyright(C) 1999-2015 the Claws Mail Team
+ * Copyright(C) 1999-2021 the Claws Mail Team
  * This file Copyright (C) 2009-2014 Salvatore De Paolis
  * <iwkse@claws-mail.org> and the Claws Mail Team
  *
@@ -25,28 +25,26 @@
 #include "claws-features.h"
 #endif
 
+#include "stock_pixmap.h"
+
 #include <fancy_viewer.h>
 #include <fancy_prefs.h>
 #include <alertpanel.h>
 #include <file-utils.h>
-#include <utils.h>
 
 #include <printing.h>
-#include <webkit/webkithittestresult.h>
 
-static void
-load_start_cb (WebKitWebView *view, gint progress, FancyViewer *viewer);
-
-static void
-load_finished_cb (WebKitWebView *view, gint progress, FancyViewer *viewer);
-
-static void
-over_link_cb (WebKitWebView *view, const gchar *wtf, const gchar *link,
-	      FancyViewer *viewer, void *wtfa);
+static void load_changed_cb(WebKitWebView *view,
+		WebKitLoadEvent event,
+		gpointer user_data);
+static void mouse_target_changed_cb (WebKitWebView *view,
+		WebKitHitTestResult *result,
+		guint modifiers,
+		gpointer user_data);
 
 
 static void
-load_progress_cb(WebKitWebView *view, GParamSpec* pspec, FancyViewer *viewer);
+load_progress_cb(WebKitWebView *view, GParamSpec *param, FancyViewer *viewer);
 
 static MimeViewerFactory fancy_viewer_factory;
 
@@ -85,11 +83,9 @@ static void fancy_apply_prefs(FancyViewer *viewer)
 {
 	g_object_set(viewer->settings,
 		"auto-load-images", viewer->override_prefs_images,
-		"enable-scripts", viewer->override_prefs_scripts,
+		"enable-javascript", viewer->override_prefs_scripts,
 		"enable-plugins", viewer->override_prefs_plugins,
-		"enable-java-applet", viewer->override_prefs_java,
-	        "enable-dns-prefetching", viewer->override_prefs_remote_content,
-	        "user-stylesheet-uri", viewer->override_stylesheet,
+		"enable-java", viewer->override_prefs_java,
 #ifdef G_OS_WIN32
 		"default-font-family", "Arial",
 		"cursive-font-family", "Comic Sans MS",
@@ -100,17 +96,43 @@ static void fancy_apply_prefs(FancyViewer *viewer)
 #endif
 		NULL);
 	if (fancy_prefs.stylesheet == NULL || strlen(fancy_prefs.stylesheet) == 0) {
-		gchar **msg_font_params = g_strsplit(prefs_common_get_prefs()->textfont, " ", 0);
+		gchar **msg_font_params = g_strsplit(prefs_common.textfont, " ", 0);
 		guint params_len = g_strv_length(msg_font_params);
 
 		if (params_len > 0) {
 			gint msg_font_size = g_ascii_strtoll(msg_font_params[params_len - 1], NULL, 10);
-			g_object_set(viewer->settings,
-				"default-font-size", msg_font_size, NULL);
+			g_object_set(viewer->settings, "default-font-size",
+				     webkit_settings_font_size_to_pixels(msg_font_size), NULL);
 		}
 		g_strfreev(msg_font_params);
 	}
 	webkit_web_view_set_settings(viewer->view, viewer->settings);
+	if (viewer->override_prefs_remote_content)
+		webkit_web_context_set_network_proxy_settings(webkit_web_context_get_default(), WEBKIT_NETWORK_PROXY_MODE_DEFAULT, NULL);
+	else
+		webkit_web_context_set_network_proxy_settings(webkit_web_context_get_default(), WEBKIT_NETWORK_PROXY_MODE_CUSTOM, viewer->no_remote_content_proxy_settings);
+
+	if (viewer->override_stylesheet) {
+		/* copied from vimb */
+		gchar *stylesheet;
+
+		if (g_file_get_contents(viewer->override_stylesheet, &stylesheet, NULL, NULL)) {
+			WebKitUserContentManager *ucm;
+			WebKitUserStyleSheet *style;
+
+            ucm = webkit_web_view_get_user_content_manager(viewer->view);
+			style = webkit_user_style_sheet_new(
+						stylesheet, WEBKIT_USER_CONTENT_INJECT_ALL_FRAMES,
+						WEBKIT_USER_STYLE_LEVEL_USER, NULL, NULL);
+
+			webkit_user_content_manager_remove_all_style_sheets(ucm);
+			webkit_user_content_manager_add_style_sheet(ucm, style);
+			webkit_user_style_sheet_unref(style);
+			g_free(stylesheet);
+		} else {
+			debug_print("Could not read style file: %s", viewer->override_stylesheet);
+		}
+	}
 }
 
 static void fancy_auto_load_images_activated(GtkCheckMenuItem *item, FancyViewer *viewer) {
@@ -158,24 +180,25 @@ static void fancy_set_defaults(FancyViewer *viewer)
 	viewer->override_prefs_java = fancy_prefs.enable_java;
 
 	gchar *tmp;
+
 #ifdef G_OS_WIN32
 	/* Replace backslashes with forward slashes, since we'll be
 	 * using this string in an URI. */
 	gchar *tmp2 = g_strdup(fancy_prefs.stylesheet);
 	subst_char(tmp2, '\\', '/');
 
-	/* Escape string for use in an URI, keeping dir separators
+	 /* Escape string for use in an URI, keeping dir separators
 	 * and colon for Windows drive name ("C:") intact. */
 	tmp = g_uri_escape_string(tmp2, "/:", TRUE);
 	g_free(tmp2);
 #else
-	/* Escape string for use in an URI, keeping dir separators
+	 /* Escape string for use in an URI, keeping dir separators
 	 * intact. */
 	tmp = g_uri_escape_string(fancy_prefs.stylesheet, "/", TRUE);
 #endif
-	viewer->override_stylesheet = g_strconcat("file://", tmp, NULL);
+	viewer->override_stylesheet = g_strdup(tmp);
 	g_free(tmp);
-	debug_print("Passing '%s' as stylesheet URI to Webkit\n",
+	debug_print("Using '%s' as stylesheet\n",
 			viewer->override_stylesheet);
 
 	g_signal_handlers_block_by_func(G_OBJECT(viewer->enable_images),
@@ -258,6 +281,8 @@ static gboolean fancy_set_contents(FancyViewer *viewer, gboolean use_defaults)
 	else {
 		const gchar *charset = NULL;
 		gchar *contents = NULL;
+        gdouble zoom_level;
+        zoom_level = (double) fancy_prefs.zoom_level / 100;
 		if (messageview && messageview->forced_charset)
 			charset = ((MimeViewer *)viewer)->mimeview->messageview->forced_charset;
 		else
@@ -265,20 +290,19 @@ static gboolean fancy_set_contents(FancyViewer *viewer, gboolean use_defaults)
 		if (!charset)
 			charset = conv_get_locale_charset_str();
 		debug_print("using %s charset\n", charset);
-		g_object_set(viewer->settings, "default-encoding", charset, NULL);
+		g_object_set(viewer->settings, "default-charset", charset, NULL);
 		
 		if (use_defaults) {
-			debug_print("zoom_level: %i\n", fancy_prefs.zoom_level);
-			webkit_web_view_set_zoom_level(viewer->view, (fancy_prefs.zoom_level / 100.0));
+			debug_print("zoom_level: %f\n", zoom_level);
+
+			webkit_web_view_set_zoom_level(viewer->view, zoom_level);
 
 			fancy_set_defaults(viewer);
 		}
 
 		contents = file_read_to_str_no_recode(viewer->filename);
-		webkit_web_view_load_string(viewer->view,
+		webkit_web_view_load_html(viewer->view,
 					    contents,
-					    "text/html",
-					    charset,
 					    NULL);
 		g_free(contents);
 	}
@@ -313,46 +337,64 @@ static void fancy_show_mimepart(MimeViewer *_viewer, const gchar *infile,
 	g_timeout_add(5, (GSourceFunc)fancy_show_mimepart_prepare, viewer);
 }
 
+static void fancy_print_fail_cb(WebKitPrintOperation *print_operation,
+                               GError               *error,
+                               gpointer              user_data) {
+    /* avoid warning for unused variable
+    FancyViewer *viewer = (FancyViewer *) user_data;
+    */
+
+    debug_print("Error printing message: %s\n",
+                            error ? error->message : "no details");
+}
+
 static void fancy_print(MimeViewer *_viewer)
 {
 	FancyViewer *viewer = (FancyViewer *) _viewer;
-	GtkPrintOperationResult res;
-	GError *error = NULL;
-	GtkPrintOperation *op;
+	WebKitPrintOperationResponse res;
+	WebKitPrintOperation *printoperation;
+	GtkPrintSettings *printsettings;
+	GtkPageSetup *pagesetup;
 
 	gtk_widget_realize(GTK_WIDGET(viewer->view));
 
 	while (viewer->loading)
 		claws_do_idle();
 
-	op = gtk_print_operation_new();
+	printoperation = webkit_print_operation_new(viewer->view);
+	g_signal_connect(G_OBJECT(printoperation), "failed",
+			 G_CALLBACK(fancy_print_fail_cb), viewer);
 
-	/* Config for printing */
-	gtk_print_operation_set_print_settings(op, printing_get_settings());
-	gtk_print_operation_set_default_page_setup(op, printing_get_page_setup());
-        /* enable Page Size and Orientation in the print dialog */
-	gtk_print_operation_set_embed_page_setup(op, TRUE);
-
-	/* Start printing process */
-	res = webkit_web_frame_print_full(webkit_web_view_get_main_frame(viewer->view),
-					  op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
-					  &error);
-
-	if (res == GTK_PRINT_OPERATION_RESULT_ERROR) {
-		gtk_print_operation_get_error(op, &error);
-		debug_print("Error printing message: %s\n",
-			    error ? error->message : "no details");
-	} else if (res == GTK_PRINT_OPERATION_RESULT_APPLY) {
-		/* store settings for next printing session */
-		printing_store_settings(gtk_print_operation_get_print_settings(op));
+	printsettings = webkit_print_operation_get_print_settings(printoperation);
+	if (!printsettings) {
+	    printsettings = printing_get_settings();
+	    webkit_print_operation_set_print_settings(printoperation, printsettings);
 	}
+	pagesetup = webkit_print_operation_get_page_setup(printoperation);
+	if (!pagesetup) {
+	    pagesetup = printing_get_page_setup();
+	    webkit_print_operation_set_page_setup(printoperation, pagesetup);
+	}
+
+	MainWindow *mainwin = mainwindow_get_mainwindow();
+	res = webkit_print_operation_run_dialog(
+	    printoperation,
+	    mainwin ? GTK_WINDOW(mainwin->window):NULL);
+
+	if (res == WEBKIT_PRINT_OPERATION_RESPONSE_PRINT) {
+	    // store settings for next printing session
+	    printing_store_settings(
+		webkit_print_operation_get_print_settings(printoperation));
+	}
+
+	g_free(printoperation);
 }
 
-static gchar *fancy_get_selection (MimeViewer *_viewer)
+/*static gchar *fancy_get_selection (MimeViewer *_viewer)
 {
 	debug_print("fancy_get_selection\n");
 	FancyViewer *viewer = (FancyViewer *) _viewer;
-	viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
+	viewer->doc = webkit_web_page_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
 	viewer->window = webkit_dom_document_get_default_view (viewer->doc);
 	viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
 	if (viewer->selection == NULL)
@@ -366,7 +408,7 @@ static gchar *fancy_get_selection (MimeViewer *_viewer)
 		return NULL;
 	}
 	return sel;
-}
+}*/
 
 static void fancy_clear_viewer(MimeViewer *_viewer)
 {
@@ -378,7 +420,7 @@ static void fancy_clear_viewer(MimeViewer *_viewer)
 	webkit_web_view_load_uri(viewer->view, "about:blank");
 
 	debug_print("fancy_clear_viewer\n");
-	fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
+	fancy_prefs.zoom_level = (int) webkit_web_view_get_zoom_level(viewer->view) * 100;
 	viewer->to_load = NULL;
 	vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
 	gtk_adjustment_set_value(vadj, 0.0);
@@ -388,51 +430,87 @@ static void fancy_clear_viewer(MimeViewer *_viewer)
 static void fancy_destroy_viewer(MimeViewer *_viewer)
 {
 	FancyViewer *viewer = (FancyViewer *) _viewer;
-	fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
+	fancy_prefs.zoom_level = (int) webkit_web_view_get_zoom_level(viewer->view) * 100;
 	debug_print("fancy_destroy_viewer\n");
 	g_free(viewer->filename);
 	g_free(viewer);
 }
 
 static gboolean
-navigation_policy_cb (WebKitWebView             *web_view,
-		      WebKitWebFrame            *frame,
-		      WebKitNetworkRequest      *request,
-		      WebKitWebNavigationAction *navigation_action,
-		      WebKitWebPolicyDecision   *policy_decision,
+navigation_policy_cb (WebKitWebView    *web_view,
+		      WebKitPolicyDecision *policy_decision,
+		      WebKitPolicyDecisionType policy_decision_type,
 		      FancyViewer		*viewer)
 {
-	const gchar *uri = webkit_network_request_get_uri(request);
+        if (policy_decision_type == WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION || policy_decision_type == WEBKIT_POLICY_DECISION_TYPE_NEW_WINDOW_ACTION) {
+	        WebKitNavigationPolicyDecision *navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(policy_decision);
+                WebKitNavigationAction *navigation_action = webkit_navigation_policy_decision_get_navigation_action(navigation_decision);
+                viewer->cur_link = webkit_uri_request_get_uri(webkit_navigation_action_get_request(navigation_action));
 
-	debug_print("navigation requested to %s\n", uri);
+                debug_print("navigation requested to %s\n", viewer->cur_link);
 
-	if (!strncmp(uri, "mailto:", 7)) {
-		debug_print("Opening message window\n");
-		compose_new(NULL, uri + 7, NULL);
-		webkit_web_policy_decision_ignore(policy_decision);
-	} else if (!strncmp(uri, "file://", 7) || !strcmp(uri, "about:blank")) {
-		debug_print("local navigation request ACCEPTED\n");
-		webkit_web_policy_decision_use(policy_decision);
-	} else if (viewer->override_prefs_remote_content) {
-		debug_print("remote navigation request ACCEPTED\n");
-		webkit_web_policy_decision_use(policy_decision);
-	} else {
-		debug_print("remote navigation request IGNORED\n");
-		fancy_show_notice(viewer, _("Remote content loading is disabled."));
-		webkit_web_policy_decision_ignore(policy_decision);
+                if (viewer->cur_link) {
+                        if (!strncmp(viewer->cur_link, "mailto:", 7)) {
+                                debug_print("Opening message window\n");
+                                compose_new(NULL, viewer->cur_link + 7, NULL);
+                                webkit_policy_decision_ignore(policy_decision);
+                        } else if (!strncmp(viewer->cur_link, "file://", 7) || !strcmp(viewer->cur_link, "about:blank")) {
+                                debug_print("local navigation request ACCEPTED\n");
+                                webkit_policy_decision_use(policy_decision);
+                        } else if (viewer->override_prefs_external && webkit_navigation_action_get_navigation_type(navigation_action) == WEBKIT_NAVIGATION_TYPE_LINK_CLICKED) {
+                                debug_print("remote navigation request OPENED\n");
+                                open_uri(viewer->cur_link, prefs_common_get_uri_cmd());
+                                webkit_policy_decision_ignore(policy_decision);
+                        } else if (viewer->override_prefs_remote_content) {
+                                debug_print("remote navigation request ACCEPTED\n");
+                                webkit_policy_decision_use(policy_decision);
+                        } else {
+                                debug_print("remote navigation request IGNORED\n");
+                                fancy_show_notice(viewer, _("Remote content loading is disabled."));
+                                webkit_policy_decision_ignore(policy_decision);
+                        }
+                }
+                return true;
+        } else {
+                return false;
+        }
+}
+
+static void load_content_cb(WebKitURISchemeRequest *request, gpointer viewer)
+{
+	gchar *image;
+	MimeInfo *partinfo = ((FancyViewer *)viewer)->to_load;
+	gchar *mimetype;
+	GInputStream *stream;
+	GError *error;
+
+	image = g_strconcat("<", webkit_uri_scheme_request_get_path(request), ">", NULL);
+	while ((partinfo = procmime_mimeinfo_next(partinfo)) != NULL) {
+		if (partinfo->id && !g_ascii_strcasecmp(image, partinfo->id)) {
+			mimetype = procmime_get_content_type_str(partinfo->type, partinfo->subtype);
+			stream = procmime_get_part_as_inputstream(partinfo);
+			webkit_uri_scheme_request_finish(request, stream, partinfo->length,
+					mimetype);
+			g_object_unref(stream);
+			g_free(mimetype);
+			g_free(image);
+			return;
+		}
 	}
 
-	return TRUE;
+	error = g_error_new(0, 0, _("Couldn't save the part of multipart message: %s"), image);
+	webkit_uri_scheme_request_finish_error(request, error);
+	g_error_free(error);
+	g_free(image);
 }
 
 static void resource_request_starting_cb(WebKitWebView		*view,
-					 WebKitWebFrame		*frame,
 					 WebKitWebResource	*resource,
-					 WebKitNetworkRequest	*request,
-					 WebKitNetworkResponse	*response,
+					 WebKitURIRequest	*request,
+					 WebKitURIResponse	*response,
 					 FancyViewer		*viewer)
 {
-	const gchar *uri = webkit_network_request_get_uri(request);
+	const gchar *uri = webkit_uri_request_get_uri(request);
 	gchar *filename;
 	gchar *image;
 	gint err;
@@ -452,7 +530,7 @@ static void resource_request_starting_cb(WebKitWebView		*view,
 					alertpanel_error(_("Couldn't save the part of multipart message: %s"),
 										g_strerror(-err));
 				gchar *file_uri = g_filename_to_uri(filename, NULL, NULL);
-				webkit_network_request_set_uri(request, file_uri);
+				webkit_uri_request_set_uri(request, file_uri);
 				g_free(file_uri);
 				g_free(filename);
 				break;
@@ -462,28 +540,28 @@ static void resource_request_starting_cb(WebKitWebView		*view,
 	}
 	
 	/* refresh URI that may have changed */
-	uri = webkit_network_request_get_uri(request);
+	uri = webkit_uri_request_get_uri(request);
 	if (!viewer->override_prefs_remote_content
 	    && strncmp(uri, "file://", 7) && strncmp(uri, "data:", 5)) {
 		debug_print("Preventing load of %s\n", uri);
-		webkit_network_request_set_uri(request, "about:blank");
+		webkit_uri_request_set_uri(request, "about:blank");
 	}
 	else
 		debug_print("Starting request of %"G_GSIZE_FORMAT" %s\n", strlen(uri), uri);
 }
 
-static gboolean fancy_text_search(MimeViewer *_viewer, gboolean backward,
+/*static gboolean fancy_text_search(MimeViewer *_viewer, gboolean backward,
 				  const gchar *str, gboolean case_sens)
 {
 	return webkit_web_view_search_text(((FancyViewer*)_viewer)->view, str,
 					   case_sens, !backward, TRUE);
-}
+}*/
 
 static gboolean fancy_prefs_cb(GtkWidget *widget, GdkEventButton *ev, FancyViewer *viewer)
 {
 	if ((ev->button == 1) && (ev->type == GDK_BUTTON_PRESS)) {
-		gtk_menu_popup(GTK_MENU(viewer->fancy_prefs_menu), NULL, NULL, NULL, NULL,
-				ev->button, ev->time);
+		gtk_menu_popup_at_widget(GTK_MENU(viewer->fancy_prefs_menu),
+				widget, GDK_GRAVITY_CENTER, GDK_GRAVITY_SOUTH_WEST, NULL);
 		return TRUE;
 	}
 	return FALSE;
@@ -568,55 +646,72 @@ static void fancy_scroll_one_line(MimeViewer *_viewer, gboolean up)
 	gtkutils_scroll_one_line(GTK_WIDGET(viewer->view), vadj, up);
 }
 
-static void load_start_cb(WebKitWebView *view, gint progress,
-                          FancyViewer *viewer)
+static void load_changed_cb(WebKitWebView *view,
+		WebKitLoadEvent event,
+		gpointer user_data)
 {
-	gtk_widget_show(viewer->progress);
-	gtk_widget_show(viewer->ev_stop_loading);
+	FancyViewer *viewer = (FancyViewer *)user_data;
+
+	switch (event) {
+		case WEBKIT_LOAD_STARTED:
+			gtk_widget_show(viewer->progress);
+			gtk_widget_show(viewer->ev_stop_loading);
+			break;
+
+		case WEBKIT_LOAD_FINISHED:
+			gtk_widget_hide(viewer->progress);
+			gtk_widget_hide(viewer->ev_stop_loading);
+			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(viewer->progress),
+					(gdouble) 0.0);
+			gtk_progress_bar_set_text(GTK_PROGRESS_BAR(viewer->progress), "");
+			break;
+		default:
+			break;
+	}
 }
 
-static void load_finished_cb(WebKitWebView *view, gint progress,
+static void mouse_target_changed_cb(WebKitWebView *view,
+		WebKitHitTestResult *result,
+		guint modifiers,
+		gpointer user_data)
+{
+	FancyViewer *viewer = (FancyViewer *)user_data;
+
+	cm_return_if_fail(result != NULL);
+
+	/* Display the link in the bottom statusbar, or erase it
+	 * if the cursor left the link. */
+	if (!webkit_hit_test_result_context_is_link(result)) {
+		gtk_label_set_text(GTK_LABEL(viewer->l_link), NULL);
+		return;
+	}
+
+	gtk_label_set_text(GTK_LABEL(viewer->l_link),
+			webkit_hit_test_result_get_link_uri(result));
+}
+
+static void load_progress_cb(WebKitWebView *view, GParamSpec *param,
 			     FancyViewer *viewer)
 {
-	gtk_widget_hide(viewer->progress);
-	gtk_widget_hide(viewer->ev_stop_loading);
-	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(viewer->progress),
-				      (gdouble) 0.0);
-	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(viewer->progress), "");
-}
+//	WebKitLoadEvent status = webkit_web_view_get_load_status(viewer->view);
+//	gdouble pbar = webkit_web_view_get_progress(viewer->view);
+//	const gchar *uri = webkit_web_view_get_uri(viewer->view);
 
-static void over_link_cb(WebKitWebView *view, const gchar *wtf,
-		const gchar *link, FancyViewer *viewer, void *wtfa)
-{
-	/* Display the link in the bottom statusbar. */
-	gtk_label_set_text(GTK_LABEL(viewer->l_link), link);
-}
-
-static void load_progress_cb(WebKitWebView *view, GParamSpec* pspec,
-			     FancyViewer *viewer)
-{
-	WebKitLoadStatus status = webkit_web_view_get_load_status(viewer->view);
-	gdouble pbar = webkit_web_view_get_progress(viewer->view);
-	const gchar *uri = webkit_web_view_get_uri(viewer->view);
-
-	gchar *label = g_strdup_printf("%d%% Loading...", (gint)(pbar * 100));
-	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(viewer->progress), pbar);
+	gdouble progress = webkit_web_view_get_estimated_load_progress(view);
+	gchar *label = g_strdup_printf("%d%% Loading...", (gint)(progress * 100));
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(viewer->progress), progress);
+	gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(viewer->progress), TRUE);
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(viewer->progress),
 				  (const gchar*)label);
 	g_free(label);
 
-	switch (status) {
-		case WEBKIT_LOAD_PROVISIONAL:
+/*	switch (status) {
 		case WEBKIT_LOAD_COMMITTED:
-		case WEBKIT_LOAD_FIRST_VISUALLY_NON_EMPTY_LAYOUT:
-			break;
-		case WEBKIT_LOAD_FAILED:
-			debug_print("Load failed: %s\n", uri);
 			break;
 		case WEBKIT_LOAD_FINISHED:
 			debug_print("Load finished: %s\n", uri);
 			break;
-	}
+	}*/
 }
 
 static void stop_loading_cb(GtkWidget *widget, GdkEvent *ev,
@@ -626,7 +721,7 @@ static void stop_loading_cb(GtkWidget *widget, GdkEvent *ev,
 	gtk_widget_hide(viewer->progress);
 	gtk_widget_hide(viewer->ev_stop_loading);
 }
-
+/*
 static void search_the_web_cb(GtkWidget *widget, FancyViewer *viewer)
 {
 	debug_print("Clicked on Search on Web\n");
@@ -643,7 +738,7 @@ static void search_the_web_cb(GtkWidget *widget, FancyViewer *viewer)
 		g_free(search);
 		g_free(tmp);
 	}
-}
+}*/
 
 static void open_in_browser_cb(GtkWidget *widget, FancyViewer *viewer)
 {
@@ -678,9 +773,6 @@ static void *download_file_curl (void *data)
 		curl_easy_setopt(curl, CURLOPT_WRITEDATA, viewer);
 		curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
 		curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
-#ifdef G_OS_WIN32
-		curl_easy_setopt(curl, CURLOPT_CAINFO, claws_ssl_get_cert_file());
-#endif
 		res = curl_easy_perform(curl);
 		curl_easy_cleanup(curl);
 
@@ -702,9 +794,9 @@ static void download_file_cb(GtkWidget *widget, FancyViewer *viewer)
 	pthread_t curljob;
 	gint result;
 #endif
-	const gchar *link = viewer->cur_link;
+	const gchar *link = (const gchar *)viewer->cur_link;
 	gchar *filename = g_utf8_strchr(link, -1, g_utf8_get_char("/"));
-	filename = g_strconcat(get_home_dir(), filename, NULL);
+	filename = g_strconcat(g_get_home_dir(), filename, NULL);
 	gchar *fname = filesel_select_file_save(_("Save as"), filename);
 	if (!fname) {
 		g_free(filename);
@@ -758,10 +850,10 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
 				"Search the Web")) {
 			gtk_label_set_text(GTK_LABEL(menul), _("Search the Web"));
 			viewer->cur_link = NULL;
-			GtkImageMenuItem *m_search = GTK_IMAGE_MENU_ITEM(menuitem);
+/*			GtkImageMenuItem *m_search = GTK_IMAGE_MENU_ITEM(menuitem);
 			g_signal_connect(G_OBJECT(m_search), "activate",
 					 G_CALLBACK(search_the_web_cb),
-					 (gpointer *) viewer);
+					 (gpointer *) viewer);*/
 		}
 
 		if (!g_ascii_strcasecmp(gtk_label_get_text(GTK_LABEL(menul)),
@@ -830,29 +922,27 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
 	}
 }
 
-static gboolean context_menu_cb (WebKitWebView *view, GtkWidget *menu,
-		WebKitHitTestResult *hit_test_result,
-		gboolean triggered_with_keyboard,
-		gpointer user_data)
+static gboolean context_menu_cb (WebKitWebView *view, WebKitContextMenu *menu,
+                                 GdkEvent *event, WebKitHitTestResult *hit_test_result,
+                                 gpointer user_data)
 {
 	FancyViewer *viewer = (FancyViewer *)user_data;
 	Plugin *plugin = plugin_get_loaded_by_name("RSSyl");
 	WebKitHitTestResultContext context;
-	gchar *link_uri = NULL;
+	const gchar *link_uri = NULL;
 
-	g_object_get(G_OBJECT(hit_test_result),
-			"context", &context,
-			"link-uri", &link_uri,
-			NULL);
+    context = webkit_hit_test_result_get_context(hit_test_result);
+
+    link_uri = webkit_hit_test_result_get_link_uri(hit_test_result);
 
 	debug_print("context %d, link-uri '%s'\n", context,
 			(link_uri != NULL ? link_uri : "(null)"));
 	if (context & WEBKIT_HIT_TEST_RESULT_CONTEXT_LINK &&
 			link_uri != NULL) {
-		if (viewer->cur_link != NULL)
-			g_free(viewer->cur_link);
-		/* g_object_get() already made a copy, no need to strdup() here */
-		viewer->cur_link = link_uri;
+		if (viewer != NULL && viewer->cur_link != NULL) {
+            /* g_object_get() already made a copy, no need to strdup() here */
+            viewer->cur_link = (gchar*)link_uri;
+        }
 	}
 
 	gtk_container_foreach(GTK_CONTAINER(menu),
@@ -861,8 +951,6 @@ static gboolean context_menu_cb (WebKitWebView *view, GtkWidget *menu,
 
 	if (plugin) {
 		GtkWidget *rssyl = gtk_image_menu_item_new_with_label(_("Import feed"));
-		GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
-		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(rssyl), img);
 		gtk_widget_show(GTK_WIDGET(rssyl));
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), rssyl);
 		g_signal_connect(G_OBJECT(rssyl), "activate",
@@ -892,8 +980,7 @@ static gint keypress_events_cb (GtkWidget *widget, GdkEventKey *event,
 	return FALSE;
 }
 
-static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
-				   FancyViewer *viewer)
+/*static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev, FancyViewer *viewer)
 {
 	if (ev->button.button == 1 && viewer->cur_link && viewer->override_prefs_external) {
 		gint x, y;
@@ -903,9 +990,9 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 				"x", &x, "y", &y,
 				NULL);
 
-		/* If this button release is end of a drag or selection event
+		*//* If this button release is end of a drag or selection event
 		 * (button press happened on different coordinates), we do not
-		 * want to open the link. */
+		 * want to open the link. *//*
 		if ((x != viewer->click_x || y != viewer->click_y))
 			return FALSE;
 
@@ -940,7 +1027,7 @@ static gboolean press_button_cb (WebKitWebView *view, GdkEvent *ev,
 	}
 	if (link != NULL) {
 		debug_print("press on %s\n", link);
-		viewer->cur_link = link; /* g_context returned a newly-allocated string */
+		viewer->cur_link = link;i*/ /* g_context returned a newly-allocated string 
 	}
 
 	viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
@@ -949,7 +1036,7 @@ static gboolean press_button_cb (WebKitWebView *view, GdkEvent *ev,
 	if (viewer->selection != NULL)
 		webkit_dom_dom_selection_empty(viewer->selection);
 	return FALSE;
-}
+}*/
 
 static void zoom_100_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 {
@@ -960,16 +1047,22 @@ static void zoom_100_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 static void zoom_in_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 {
 	gtk_widget_grab_focus(widget);
-	webkit_web_view_zoom_in(viewer->view);
+    fancy_prefs.zoom_level += 10;
+    gdouble zoom_level;
+    zoom_level = (double) fancy_prefs.zoom_level / 100;
+    webkit_web_view_set_zoom_level(viewer->view, zoom_level);
 }
 static void zoom_out_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 {
+    gdouble zoom_level;
 	gtk_widget_grab_focus(widget);
-	webkit_web_view_zoom_out(viewer->view);
+    fancy_prefs.zoom_level -= 10;
+    zoom_level = (double) fancy_prefs.zoom_level / 100;
+    if (fancy_prefs.zoom_level)
+        webkit_web_view_set_zoom_level(viewer->view, zoom_level);
 }
 
 static void resource_load_failed_cb(WebKitWebView     *web_view,
-				    WebKitWebFrame    *web_frame,
 				    WebKitWebResource *web_resource,
 				    GError            *error,
 				    FancyViewer	      *viewer)
@@ -987,19 +1080,22 @@ static MimeViewer *fancy_viewer_create(void)
 	viewer = g_new0(FancyViewer, 1);
 	viewer->mimeviewer.factory = &fancy_viewer_factory;
 	viewer->mimeviewer.get_widget = fancy_get_widget;
-	viewer->mimeviewer.get_selection = fancy_get_selection;
+//	viewer->mimeviewer.get_selection = fancy_get_selection;
 	viewer->mimeviewer.show_mimepart = fancy_show_mimepart;
 	viewer->mimeviewer.print = fancy_print;
 	viewer->mimeviewer.clear_viewer = fancy_clear_viewer;
 	viewer->mimeviewer.destroy_viewer = fancy_destroy_viewer;
-	viewer->mimeviewer.text_search = fancy_text_search;
+//	viewer->mimeviewer.text_search = fancy_text_search;
 	viewer->mimeviewer.scroll_page = fancy_scroll_page;
 	viewer->mimeviewer.scroll_one_line = fancy_scroll_one_line;
 	viewer->view = WEBKIT_WEB_VIEW(webkit_web_view_new());
 
-#ifdef HAVE_LIBSOUP_GNOME
+/*#ifdef HAVE_LIBSOUP_GNOME
+  TODO webkit_get_default_session() missing 
+   *     enum WebKitNetworkProxySettings
+   * */
  /* Use GNOME proxy settings through libproxy */
-	if (fancy_prefs.enable_gnome_proxy) {
+/*	if (fancy_prefs.enable_gnome_proxy) {
 		SoupSession *session = webkit_get_default_session();
 		soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
 	}
@@ -1010,8 +1106,11 @@ static MimeViewer *fancy_viewer_create(void)
 		SoupURI* pURI = soup_uri_new(fancy_prefs.proxy_str);
 		g_object_set(session, "proxy-uri", pURI, NULL);
 	}
-
-	viewer->settings = webkit_web_settings_new();
+*/
+	viewer->settings = webkit_settings_new();
+	// Proxy "" makes libsoup backend think that there is no way
+	// to connect, which is ideal.
+	viewer->no_remote_content_proxy_settings = webkit_network_proxy_settings_new("", NULL);
 	g_object_set(viewer->settings, "user-agent", "Fancy Viewer", NULL);
 	viewer->scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(viewer->scrollwin),
@@ -1021,14 +1120,15 @@ static MimeViewer *fancy_viewer_create(void)
 	gtk_container_add(GTK_CONTAINER(viewer->scrollwin),
 			  GTK_WIDGET(viewer->view));
 
-	viewer->vbox = gtk_vbox_new(FALSE, 0);
-	hbox = gtk_hbox_new(FALSE, 0);
+	viewer->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	viewer->progress = gtk_progress_bar_new();
+	gtk_widget_set_size_request(GTK_WIDGET(viewer->progress), 120, -1);
 	/* Zoom Widgets */
-	viewer->zoom_100 = gtk_image_new_from_stock(GTK_STOCK_ZOOM_100, GTK_ICON_SIZE_MENU);
-	viewer->zoom_in = gtk_image_new_from_stock(GTK_STOCK_ZOOM_IN, GTK_ICON_SIZE_MENU);
-	viewer->zoom_out = gtk_image_new_from_stock(GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_MENU);
-	viewer->stop_loading = gtk_image_new_from_stock(GTK_STOCK_CANCEL, GTK_ICON_SIZE_MENU);
+	viewer->zoom_100 = stock_pixmap_widget(STOCK_PIXMAP_ZOOM_FIT);
+	viewer->zoom_in = stock_pixmap_widget(STOCK_PIXMAP_ZOOM_IN);
+	viewer->zoom_out = stock_pixmap_widget(STOCK_PIXMAP_ZOOM_OUT);
+	viewer->stop_loading = stock_pixmap_widget(STOCK_PIXMAP_CANCEL);
 	/* Event Widgets for the Zoom Widgets  */
 	viewer->ev_zoom_100 = gtk_event_box_new();
 	viewer->ev_zoom_in = gtk_event_box_new();
@@ -1037,9 +1137,10 @@ static MimeViewer *fancy_viewer_create(void)
 
 	/* Link Label */
 	viewer->l_link = gtk_label_new("");
+    gtk_label_set_ellipsize(GTK_LABEL(viewer->l_link), PANGO_ALIGN_RIGHT);
 
 	/* Preferences Widgets to override preferences on the fly  */
-	viewer->fancy_prefs = gtk_image_new_from_stock(GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU);
+	viewer->fancy_prefs = stock_pixmap_widget(STOCK_PIXMAP_PREFERENCES);
 	viewer->ev_fancy_prefs = gtk_event_box_new();
 
 	/* Popup Menu for preferences  */
@@ -1087,29 +1188,25 @@ static MimeViewer *fancy_viewer_create(void)
 	gtk_widget_show(hbox);
 	gtk_widget_show(GTK_WIDGET(viewer->view));
 
-	g_signal_connect(G_OBJECT(viewer->view), "load-started",
-			 G_CALLBACK(load_start_cb), viewer);
-	g_signal_connect(G_OBJECT(viewer->view), "load-finished",
-			 G_CALLBACK(load_finished_cb), viewer);
-	g_signal_connect(G_OBJECT(viewer->view), "hovering-over-link",
-			G_CALLBACK(over_link_cb), viewer);
+	g_signal_connect(G_OBJECT(viewer->view), "load-changed",
+			 G_CALLBACK(load_changed_cb), viewer);
+	g_signal_connect(G_OBJECT(viewer->view), "mouse-target-changed",
+			G_CALLBACK(mouse_target_changed_cb), viewer);
 
-	g_signal_connect(G_OBJECT(viewer->view), "notify::progress",
-			 G_CALLBACK(load_progress_cb), viewer);
-	g_signal_connect(G_OBJECT(viewer->view), "notify::load-status",
+	g_signal_connect(G_OBJECT(viewer->view), "notify::estimated-load-progress",
 			 G_CALLBACK(load_progress_cb), viewer);
 
-	g_signal_connect(G_OBJECT(viewer->view), "navigation-policy-decision-requested",
+	g_signal_connect(G_OBJECT(viewer->view), "decide-policy",
 			 G_CALLBACK(navigation_policy_cb), viewer);
 
 	g_signal_connect(G_OBJECT(viewer->view), "resource-request-starting",
 			G_CALLBACK(resource_request_starting_cb), viewer);
 	g_signal_connect(G_OBJECT(viewer->view), "context-menu",
 			G_CALLBACK(context_menu_cb), viewer);
-	g_signal_connect(G_OBJECT(viewer->view), "button-press-event",
+/*	g_signal_connect(G_OBJECT(viewer->view), "button-press-event",
 			 G_CALLBACK(press_button_cb), viewer);
 	g_signal_connect(G_OBJECT(viewer->view), "button-release-event",
-			 G_CALLBACK(release_button_cb), viewer);
+			 G_CALLBACK(release_button_cb), viewer);*/
 	g_signal_connect(G_OBJECT(viewer->ev_zoom_100), "button-press-event",
 			 G_CALLBACK(zoom_100_cb), (gpointer*)viewer);
 	g_signal_connect(G_OBJECT(viewer->ev_zoom_in), "button-press-event",
@@ -1126,6 +1223,9 @@ static MimeViewer *fancy_viewer_create(void)
 	g_signal_connect(G_OBJECT(viewer->view), "resource-load-failed",
 			 G_CALLBACK(resource_load_failed_cb), viewer);
 
+	webkit_web_context_register_uri_scheme(webkit_web_context_get_default(),
+			"cid", load_content_cb, viewer, NULL);
+
 	viewer->filename = NULL;
 	return (MimeViewer *) viewer;
 }
@@ -1141,7 +1241,7 @@ static MimeViewerFactory fancy_viewer_factory =
 
 gint plugin_init(gchar **error)
 {
-	if (!check_plugin_version(MAKE_NUMERIC_VERSION(2,9,2,72),
+	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,0,0,0),
 				  VERSION_NUMERIC, _("Fancy"), error))
 		return -1;
 	gchar *directory = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
@@ -1169,7 +1269,7 @@ gboolean plugin_done(void)
 
 const gchar *plugin_name(void)
 {
-	/* TRANSLATORS: 'Fancy' here is name of the plugin, not the english word. */
+	/* i18n: 'Fancy' here is name of the plugin, not the english word. */
 	return _("Fancy HTML Viewer");
 }
 
@@ -1185,7 +1285,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
