@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2021 the Claws Mail Team
+ * Copyright (C) 1999-2015 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include "quoted-printable.h"
 /* parse headers */
 #include "procheader.h"
+#include "plugin.h"
 
 static gulong mail_receive_hook_id = HOOK_NONE;
 
@@ -162,7 +163,7 @@ gint plugin_init(gchar **error)
 
 	mail_receive_hook_id = hooks_register_hook(MAIL_RECEIVE_HOOKLIST, mail_receive_hook, NULL);
 	if (mail_receive_hook_id == HOOK_NONE) {
-		/* TRANSLATORS: Possible error message during plugin load */
+		/* i18n: Possible error message during plugin load */
 		*error = g_strdup(_("Failed to register mail receive hook"));
 		return -1;
 	}
@@ -195,7 +196,7 @@ const gchar *plugin_name(void)
 
 const gchar *plugin_desc(void)
 {
-	/* TRANSLATORS: Description seen in plugins dialog.
+	/* i18n: Description seen in plugins dialog.
 	 * Translation of "Plugins" part of preferences path should to be
 	 * the same as translation of "Plugins" string in Claws Mail message
 	 * catalog. */
@@ -209,7 +210,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
@@ -225,7 +226,7 @@ const gchar *plugin_version(void)
 struct PluginFeature *plugin_provides(void)
 {
 	static struct PluginFeature features[] = 
-		/* TRANSLATORS: Description of functionality added by this plugin */
+		/* i18n: Description of functionality added by this plugin */
 		{ {PLUGIN_UTILITY, N_("Mail marking")},
 		  {PLUGIN_NOTHING, NULL}};
 	return features;
