@@ -73,7 +73,7 @@ static void cm_gdata_save_config(void)
 
   if (prefs_write_param(cm_gdata_param, pfile->fp) < 0) {
     debug_print("failed!\n");
-    g_warning("GData plugin: failed to write plugin configuration to file");
+    g_warning("GData Plugin: Failed to write plugin configuration to file");
     prefs_file_close_revert(pfile);
     return;
   }
@@ -177,7 +177,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-  return "GTK2";
+  return "GTK3";
 }
 
 const gchar *plugin_licence(void)
