@@ -41,7 +41,11 @@ extern "C" {
 const gchar *prefs_common_get_uri_cmd(void);
 }
 
-static gboolean expose_event_cb(GtkWidget *widget, GdkEvent *event,
+char master_css[] = {
+#include "css.inc"
+};
+
+static gboolean draw_cb(GtkWidget *widget, cairo_t *cr,
 		gpointer user_data);
 static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event,
 		gpointer user_data);
@@ -56,9 +60,6 @@ lh_widget::lh_widget()
 {
 	GtkWidget *item;
 
-	m_force_render = false;
-	m_blank = false;
-
 	/* scrolled window */
 	m_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(m_scrolled_window),
@@ -74,8 +75,8 @@ lh_widget::lh_widget()
 	/* drawing area */
 	m_drawing_area = gtk_drawing_area_new();
 	gtk_container_add(GTK_CONTAINER(m_viewport), m_drawing_area);
-	g_signal_connect(m_drawing_area, "expose-event",
-			G_CALLBACK(expose_event_cb), this);
+	g_signal_connect(m_drawing_area, "draw",
+			G_CALLBACK(draw_cb), this);
 	g_signal_connect(m_drawing_area, "motion_notify_event",
 			G_CALLBACK(motion_notify_event), this);
 	g_signal_connect(m_drawing_area, "button_press_event",
@@ -98,6 +99,7 @@ lh_widget::lh_widget()
 
 	m_html = NULL;
 	m_rendered_width = 0;
+	m_context.load_master_stylesheet(master_css);
 
 	m_font_name = NULL;
 	m_font_size = 0;
@@ -106,6 +108,8 @@ lh_widget::lh_widget()
 
 	m_showing_url = FALSE;
 
+	m_cairo_context = NULL;
+
 	gtk_widget_set_events(m_drawing_area,
 			        GDK_BUTTON_RELEASE_MASK
 			      | GDK_BUTTON_PRESS_MASK
@@ -127,25 +131,21 @@ GtkWidget *lh_widget::get_widget() const
 	return m_scrolled_window;
 }
 
-void lh_widget::set_caption(const char *caption)
+void lh_widget::set_caption(const litehtml::tchar_t* caption)
 {
 	debug_print("lh_widget set_caption\n");
 	return;
 }
 
-void lh_widget::set_base_url(const char *base_url)
+void lh_widget::set_base_url(const litehtml::tchar_t* base_url)
 {
 	debug_print("lh_widget set_base_url '%s'\n",
 			(base_url ? base_url : "(null)"));
-	if (base_url)
-		m_base_url = base_url;
-	else
-		m_base_url.clear();
-
+	m_base_url = base_url;
 	return;
 }
 
-void lh_widget::on_anchor_click(const char *url, const litehtml::element::ptr& el)
+void lh_widget::on_anchor_click(const litehtml::tchar_t* url, const litehtml::element::ptr& el)
 {
 	debug_print("lh_widget on_anchor_click. url -> %s\n", url);
 
@@ -153,9 +153,10 @@ void lh_widget::on_anchor_click(const char *url, const litehtml::element::ptr& e
 	return;
 }
 
-void lh_widget::import_css(litehtml::string& text, const litehtml::string& url, litehtml::string& baseurl)
+void lh_widget::import_css(litehtml::tstring& text, const litehtml::tstring& url, litehtml::tstring& baseurl)
 {
-	debug_print("lh_widget import_css. url=\"%s\" baseurl=\"%s\"\n", url.c_str(), baseurl.c_str());
+	debug_print("lh_widget import_css\n");
+	baseurl = master_css;
 }
 
 void lh_widget::get_client_rect(litehtml::position& client) const
@@ -182,7 +183,7 @@ void lh_widget::open_html(const gchar *contents)
 	update_font();
 
 	lh_widget_statusbar_push("Loading HTML part ...");
-	m_html = litehtml::document::createFromString(contents, this);
+	m_html = litehtml::document::createFromString(contents, this, &m_context);
 	m_rendered_width = 0;
 	if (m_html != NULL) {
 		debug_print("lh_widget::open_html created document\n");
@@ -192,18 +193,11 @@ void lh_widget::open_html(const gchar *contents)
 		adj = gtk_scrolled_window_get_vadjustment(
 				GTK_SCROLLED_WINDOW(m_scrolled_window));
 		gtk_adjustment_set_value(adj, 0.0);
-		m_blank = false;
-		gtk_widget_queue_draw(m_drawing_area);
+		redraw(false);
 	}
 	lh_widget_statusbar_pop();
 }
 
-void lh_widget::rerender()
-{
-	m_force_render = true;
-	gtk_widget_queue_draw(m_drawing_area);
-}
-
 void lh_widget::draw(cairo_t *cr)
 {
 	double x1, x2, y1, y2;
@@ -226,23 +220,27 @@ void lh_widget::draw(cairo_t *cr)
 	m_html->draw((litehtml::uint_ptr)cr, 0, 0, &pos);
 }
 
-void lh_widget::redraw()
+void lh_widget::redraw(gboolean force_render)
 {
 	GtkAllocation rect;
 	gint width;
 	GdkWindow *gdkwin;
 	cairo_t *cr;
+	cairo_region_t *creg;
+	GdkDrawingContext *gdkctx;
+
+	paint_white();
 
 	if (m_html == NULL)
 		return;
 
 	/* Get width of the viewport. */
-	gtk_widget_get_allocation(GTK_WIDGET(m_viewport), &rect);
-	width = rect.width;
-	m_height = rect.height;
+	gdkwin = gtk_viewport_get_view_window(GTK_VIEWPORT(m_viewport));
+	width = gdk_window_get_width(gdkwin);
+	m_height = gdk_window_get_height(gdkwin);
 
 	/* If the available width has changed, rerender the HTML content. */
-	if (m_rendered_width != width || std::atomic_exchange(&m_force_render, false)) {
+	if (m_rendered_width != width || force_render) {
 		debug_print("lh_widget::redraw: width changed: %d != %d\n",
 				m_rendered_width, width);
 
@@ -261,36 +259,72 @@ void lh_widget::redraw()
 				m_html->width(), m_html->height());
 	}
 
-	/* Paint the rendered HTML. */
-	gdkwin = gtk_widget_get_window(m_drawing_area);
-	if (gdkwin == NULL) {
-		g_warning("lh_widget::redraw: No GdkWindow to draw on!");
-		return;
-	}
-	cr = gdk_cairo_create(GDK_DRAWABLE(gdkwin));
-	if(!std::atomic_exchange(&m_blank, false)) {
-		draw(cr);
+	/* Use provided cairo context, if any. Otherwise create our own. */
+	if (m_cairo_context != NULL) {
+		cr = m_cairo_context;
 	} else {
-		cairo_rectangle(cr, rect.x, rect.y, rect.width, rect.height);
-		cairo_set_source_rgb(cr, 255, 255, 255);
-		cairo_fill(cr);
+		gdkwin = gtk_widget_get_window(m_drawing_area);
+		if (gdkwin == NULL) {
+			g_warning("lh_widget::redraw: No GdkWindow to draw on!");
+			return;
+		}
+		creg = gdk_window_get_clip_region(gdkwin);
+		gdkctx = gdk_window_begin_draw_frame(gdkwin, creg);
+		cr = gdk_drawing_context_get_cairo_context(gdkctx);
 	}
 
-	cairo_destroy(cr);
+	draw(cr);
+
+	/* Only destroy the used cairo context if we created it earlier. */
+	if (m_cairo_context == NULL) {
+		gdk_window_end_draw_frame(gdkwin, gdkctx);
+		cairo_region_destroy(creg);
+	}
+}
+
+void lh_widget::paint_white()
+{
+	GdkWindow *gdkwin = gtk_widget_get_window(m_drawing_area);
+	cairo_region_t *creg;
+	cairo_t *cr;
+	GdkDrawingContext *gdkctx;
+
+	if (gdkwin == NULL) {
+		g_warning("lh_widget::clear: No GdkWindow to draw on!");
+		return;
+	}
+
+	creg = gdk_window_get_clip_region(gdkwin);
+	gdkctx = gdk_window_begin_draw_frame(gdkwin, creg);
+	cr = gdk_drawing_context_get_cairo_context(gdkctx);
+
+	/* Paint white background. */
+	gint width, height;
+	width = gdk_window_get_width(gdkwin);
+	height = gdk_window_get_height(gdkwin);
+	cairo_rectangle(cr, 0, 0,
+			gdk_window_get_width(gdkwin),
+			gdk_window_get_height(gdkwin));
+	cairo_set_source_rgb(cr, 255, 255, 255);
+	cairo_fill(cr);
+
+	gdk_window_end_draw_frame(gdkwin, gdkctx);
+	cairo_region_destroy(creg);
 }
 
 void lh_widget::clear()
 {
 	m_html = nullptr;
-	m_blank = true;
+	paint_white();
 	m_rendered_width = 0;
 	m_base_url.clear();
 	m_clicked_url.clear();
 }
 
-void lh_widget::set_cursor(const char *cursor)
+void lh_widget::set_cursor(const litehtml::tchar_t* cursor)
 {
-	litehtml::element::const_ptr over_el = m_html->get_over_element();
+	litehtml::element::ptr over_el = m_html->over_element();
+	gint x, y;
 
 	if (m_showing_url &&
 			(over_el == NULL || over_el != m_over_element)) {
@@ -304,10 +338,10 @@ void lh_widget::set_cursor(const char *cursor)
 	}
 }
 
-void lh_widget::update_cursor(const char *cursor)
+void lh_widget::update_cursor(const litehtml::tchar_t* cursor)
 {
 	GdkCursorType cursType = GDK_ARROW;
-	const char *href = get_href_at(m_over_element);
+	const litehtml::tchar_t *href = get_href_at(m_over_element);
 
 	/* If there is a href, and litehtml is okay with showing a pointer
 	 * cursor ("pointer" or "auto"), set it, otherwise keep the
@@ -320,7 +354,9 @@ void lh_widget::update_cursor(const char *cursor)
 	if (cursType == GDK_ARROW) {
 		gdk_window_set_cursor(gtk_widget_get_window(m_drawing_area), NULL);
 	} else {
-		gdk_window_set_cursor(gtk_widget_get_window(m_drawing_area), gdk_cursor_new(cursType));
+		gdk_window_set_cursor(gtk_widget_get_window(m_drawing_area),
+				gdk_cursor_new_for_display(gtk_widget_get_display(m_drawing_area),
+					cursType));
 	}
 
 	/* If there is a href, show it in statusbar */
@@ -330,9 +366,9 @@ void lh_widget::update_cursor(const char *cursor)
 	}
 }
 
-const char *lh_widget::get_href_at(litehtml::element::const_ptr element)
+const litehtml::tchar_t *lh_widget::get_href_at(litehtml::element::ptr element) const
 {
-	litehtml::element::const_ptr el;
+	litehtml::element::ptr el;
 
 	if (element == NULL)
 		return NULL;
@@ -354,7 +390,21 @@ const char *lh_widget::get_href_at(litehtml::element::const_ptr element)
 
 	/* At this point, over_el is pointing at an anchor tag, so let's
 	 * grab its href attribute. */
-	return el->get_attr("href");
+	return el->get_attr(_t("href"));
+}
+
+const litehtml::tchar_t *lh_widget::get_href_at(const gint x, const gint y) const
+{
+	litehtml::element::ptr over_el, el;
+
+	if (m_html == NULL)
+		return NULL;
+
+	over_el = m_html->root()->get_element_by_point(x, y, x, y);
+	if (over_el == NULL)
+		return NULL;
+
+	return get_href_at(over_el);
 }
 
 void lh_widget::print()
@@ -363,7 +413,7 @@ void lh_widget::print()
     gtk_widget_realize(GTK_WIDGET(m_drawing_area));
 }
 
-void lh_widget::popup_context_menu(const char *url,
+void lh_widget::popup_context_menu(const litehtml::tchar_t *url,
 		GdkEventButton *event)
 {
 	cm_return_if_fail(url != NULL);
@@ -373,8 +423,7 @@ void lh_widget::popup_context_menu(const char *url,
 
 	m_clicked_url = url;
 	gtk_widget_show_all(m_context_menu);
-	gtk_menu_popup(GTK_MENU(m_context_menu), NULL, NULL, NULL, NULL,
-			event->button, event->time);
+	gtk_menu_popup_at_pointer(GTK_MENU(m_context_menu), (GdkEvent *)event);
 }
 
 void lh_widget::update_font()
@@ -395,12 +444,12 @@ void lh_widget::update_font()
 	debug_print("Font set to '%s', size %d\n", m_font_name, m_font_size);
 }
 
-const litehtml::string lh_widget::fullurl(const char *url) const
+const litehtml::tstring lh_widget::fullurl(const litehtml::tchar_t *url) const
 {
 	if (*url == '#' && !m_base_url.empty())
 		return m_base_url + url;
 
-	return url;
+	return _t(url);
 }
 
 void lh_widget::set_partinfo(MimeInfo *partinfo)
@@ -408,7 +457,7 @@ void lh_widget::set_partinfo(MimeInfo *partinfo)
 	m_partinfo = partinfo;
 }
 
-GdkPixbuf *lh_widget::get_local_image(const litehtml::string url) const
+GdkPixbuf *lh_widget::get_local_image(const litehtml::tstring url) const
 {
 	GdkPixbuf *pixbuf;
 	const gchar *name;
@@ -434,7 +483,7 @@ GdkPixbuf *lh_widget::get_local_image(const litehtml::string url) const
 
 			pixbuf = procmime_get_part_as_pixbuf(p, &error);
 			if (error != NULL) {
-				g_warning("couldn't load image: %s", error->message);
+				g_warning("Couldn't load image: %s\n", error->message);
 				g_error_free(error);
 				return NULL;
 			}
@@ -447,12 +496,20 @@ GdkPixbuf *lh_widget::get_local_image(const litehtml::string url) const
 	return NULL;
 }
 
+void lh_widget::set_cairo_context(cairo_t *cr)
+{
+	m_cairo_context = cr;
+}
+
+
 ////////////////////////////////////////////////
-static gboolean expose_event_cb(GtkWidget *widget, GdkEvent *event,
+static gboolean draw_cb(GtkWidget *widget, cairo_t *cr,
 		gpointer user_data)
 {
 	lh_widget *w = (lh_widget *)user_data;
-	w->redraw();
+	w->set_cairo_context(cr);
+	w->redraw(false);
+	w->set_cairo_context(NULL);
 	return FALSE;
 }
 
@@ -463,22 +520,22 @@ static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event,
 	lh_widget *w = (lh_widget *)user_data;
 
 	if (w->m_html == NULL)
-		return FALSE;
+		return false;
 
 	//debug_print("lh_widget on_button_press_event\n");
 
 	if (event->type == GDK_2BUTTON_PRESS ||
 			event->type == GDK_3BUTTON_PRESS)
-		return TRUE;
+		return true;
 
 	/* Right-click */
 	if (event->button == 3) {
-		const char *url = w->get_href_at(w->m_html->get_over_element());
+		const litehtml::tchar_t *url = w->get_href_at((gint)event->x, (gint)event->y);
 
 		if (url != NULL)
 			w->popup_context_menu(url, event);
 
-		return TRUE;
+		return true;
 	}
 
 	if(w->m_html->on_lbutton_down((int) event->x, (int) event->y,
@@ -489,7 +546,7 @@ static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event,
 		}
 	}
 	
-	return TRUE;
+	return true;
 }
 
 static gboolean motion_notify_event(GtkWidget *widget, GdkEventButton *event,
@@ -512,7 +569,7 @@ static gboolean motion_notify_event(GtkWidget *widget, GdkEventButton *event,
         }
 	}
 	
-	return TRUE;
+	return true;
 }
 
 static gboolean button_release_event(GtkWidget *widget, GdkEventButton *event,
@@ -520,19 +577,20 @@ static gboolean button_release_event(GtkWidget *widget, GdkEventButton *event,
 {
     litehtml::position::vector redraw_boxes;
     lh_widget *w = (lh_widget *)user_data;
+    GError* error = NULL;
 
 	if (w->m_html == NULL)
-		return FALSE;
+		return false;
 
 	//debug_print("lh_widget on_button_release_event\n");
 
 	if (event->type == GDK_2BUTTON_PRESS ||
 			event->type == GDK_3BUTTON_PRESS)
-		return TRUE;
+		return true;
 
 	/* Right-click */
 	if (event->button == 3)
-		return TRUE;
+		return true;
 
 	w->m_clicked_url.clear();
 
@@ -551,7 +609,7 @@ static gboolean button_release_event(GtkWidget *widget, GdkEventButton *event,
             open_uri(w->m_clicked_url.c_str(), prefs_common_get_uri_cmd());
     }
 
-	return TRUE;
+	return true;
 }
 
 static void open_link_cb(GtkMenuItem *item, gpointer user_data)
