@@ -33,6 +33,11 @@
  * $Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#include "claws-features.h"
+#endif
+
 #include "mailmbox.h"
 
 #include <sys/file.h>
@@ -53,6 +58,7 @@
 #include "mmapstring.h"
 #include "mailmbox_parse.h"
 #include "maillock.h"
+#include "file-utils.h"
 #include "utils.h"
 
 /*
@@ -1257,7 +1263,7 @@ int claws_mailmbox_expunge_no_lock(struct claws_mailmbox_folder * folder)
     return MAILMBOX_NO_ERROR;
   }
 
-  snprintf(tmpfile, PATH_MAX, "%sXXXXXX", folder->mb_filename);
+  snprintf(tmpfile, sizeof(tmpfile), "%sXXXXXX", folder->mb_filename);
   dest_fd = g_mkstemp(tmpfile);
 
   if (dest_fd < 0) {
