@@ -54,7 +54,7 @@ static PrefParam prefs[] = {
 
 #define PACK_HBOX(hbox, vbox) \
 { \
-	hbox = gtk_hbox_new (FALSE, 5); \
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5); \
 	gtk_widget_show (hbox); \
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0); \
 }
@@ -140,7 +140,7 @@ static void sieve_prefs_account_create_widget_func(PrefsPage *_page,
 	GtkListStore *menu;
 	GtkTreeIter iter;
 
-	page_vbox = gtk_vbox_new (FALSE, VSPACING);
+	page_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (page_vbox);
 	gtk_container_set_border_width (GTK_CONTAINER (page_vbox), VBOX_BORDER);
 
@@ -148,7 +148,7 @@ static void sieve_prefs_account_create_widget_func(PrefsPage *_page,
 	PACK_CHECK_BUTTON (page_vbox, enable_checkbtn,
 			   _("Enable Sieve"));
 
-	sieve_vbox = gtk_vbox_new (FALSE, VSPACING);
+	sieve_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (sieve_vbox);
 	gtk_box_pack_start (GTK_BOX (page_vbox), sieve_vbox, FALSE, FALSE, 0);
 
@@ -212,23 +212,23 @@ static void sieve_prefs_account_create_widget_func(PrefsPage *_page,
 
 	/* Custom Auth Settings */
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (auth_vbox), hbox, FALSE, FALSE, 0);
 
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (hbox_spc);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 
-	auth_custom_vbox = gtk_vbox_new (FALSE, VSPACING/2);
+	auth_custom_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING/2);
 	gtk_widget_show (auth_custom_vbox);
 	gtk_container_set_border_width (GTK_CONTAINER (auth_custom_vbox), 0);
 	gtk_box_pack_start (GTK_BOX (hbox), auth_custom_vbox, TRUE, TRUE, 0);
 
 	/* User ID + Password */
 
-	hbox = gtk_hbox_new (FALSE, 8);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (auth_custom_vbox), hbox, FALSE, FALSE, 0);
 
@@ -255,7 +255,7 @@ static void sieve_prefs_account_create_widget_func(PrefsPage *_page,
 
 	/* Authentication method */
 
-	auth_method_hbox = gtk_hbox_new (FALSE, 8);
+	auth_method_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (auth_method_hbox);
 	gtk_box_pack_start (GTK_BOX (auth_vbox), auth_method_hbox, FALSE, FALSE, 0);
 
@@ -455,7 +455,7 @@ void sieve_prefs_done(void)
 		return;
 
 	if (prefs_write_param(prefs, pref_file->fp) < 0) {
-		g_warning("failed to write ManageSieve plugin configuration");
+		g_warning("failed to write ManageSieve Plugin configuration");
 		prefs_file_close_revert(pref_file);
 		return;
 	}
@@ -477,8 +477,8 @@ struct SieveAccountConfig *sieve_prefs_account_get_config(
 	guchar tls_type, auth, auth_type;
 	gsize len;
 	gint num;
-#if defined(G_OS_WIN32) || defined(__DragonFly__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__FreeBSD__)
-	/* Some libc variants lack support for the ISO C extension %ms, so we
+#if defined(G_OS_WIN32) || defined(__OpenBSD__) || defined(__FreeBSD__)
+	/* Non-GNU sscanf() does not understand the %ms format, so we
 	 * have to do the allocation of target buffer ourselves before
 	 * calling sscanf(), and copy the host string to config->host.
 	 */
@@ -503,13 +503,13 @@ struct SieveAccountConfig *sieve_prefs_account_get_config(
 
 	enc_userid[0] = '\0';
 	enc_passwd[0] = '\0';
-#if defined(G_OS_WIN32) || defined(__DragonFly__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__FreeBSD__)
+#if defined(G_OS_WIN32) || defined(__OpenBSD__) || defined(__FreeBSD__)
 	if ((num = sscanf(confstr, "%c%c %255s %c%hu %hhu %hhu %hhu %255s %255s",
 #else
 	if ((num = sscanf(confstr, "%c%c %ms %c%hu %hhu %hhu %hhu %255s %255s",
 #endif
 			&enable, &use_host,
-#if defined(G_OS_WIN32) || defined(__DragonFly__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__FreeBSD__)
+#if defined(G_OS_WIN32) || defined(__OpenBSD__) || defined(__FreeBSD__)
 			tmphost,
 #else
 			&config->host,
@@ -539,7 +539,7 @@ struct SieveAccountConfig *sieve_prefs_account_get_config(
 	config->auth = auth;
 	config->auth_type = auth_type;
 
-#if defined(G_OS_WIN32) || defined(__DragonFly__) || defined (__NetBSD__) || defined (__OpenBSD__) || defined (__FreeBSD__)
+#if defined(G_OS_WIN32) || defined(__OpenBSD__) || defined(__FreeBSD__)
 	config->host = g_strndup(tmphost, 255);
 #endif
 
@@ -586,9 +586,9 @@ void sieve_prefs_account_set_config(
 			config->host && config->host[0] ? config->host : "!",
 			config->use_port ? 'y' : 'n',
 			config->port,
-			(unsigned short)config->tls_type,
-			(unsigned short)config->auth,
-			(unsigned short)config->auth_type,
+			config->tls_type,
+			config->auth,
+			config->auth_type,
 			enc_userid ? enc_userid : "");
 
 	if (enc_userid)
