@@ -1,6 +1,6 @@
 
 /* Notification plugin for Claws Mail
- * Copyright (C) 2005-2007 Holger Berndt
+ * Copyright (C) 2005-2019 Holger Berndt and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -239,7 +239,7 @@ void notification_foldercheck_write_array(void)
 
   path = foldercheck_get_array_path();
   if((pfile = prefs_write_open(path)) == NULL) {
-    debug_print("Notification plugin error: cannot open "
+    debug_print("Notification Plugin Error: Cannot open "
 		"file " FOLDERCHECK_ARRAY " for writing\n");
     return;
   }
@@ -290,7 +290,7 @@ void notification_foldercheck_write_array(void)
   xml_write_tree(rootnode, pfile->fp);
 
   if(prefs_file_close(pfile) < 0) {
-    debug_print("Notification plugin error: failed to write "
+    debug_print("Notification Plugin Error: Failed to write "
 		"file " FOLDERCHECK_ARRAY "\n");
   }
 
@@ -361,7 +361,7 @@ gboolean notification_foldercheck_read_array(void)
       }
     }
     if((list == NULL) || (entry == NULL)) {
-      g_warning("did not find attribute \"name\" in tag \"branch\"");
+      g_warning("Did not find attribute \"name\" in tag \"branch\"");
       continue; /* with next branch */
     }
 
@@ -371,8 +371,8 @@ gboolean notification_foldercheck_read_array(void)
 
       /* These should all be leaves. */
       if(!G_NODE_IS_LEAF(node))
-	g_warning("subnodes in \"branch\" nodes should all be leaves, "
-		  "ignoring deeper subnodes");
+	g_warning("Subnodes in \"branch\" nodes should all be leaves. "
+		  "Ignoring deeper subnodes.");
 
       /* Check if tag is "folderitem" */
       xmlnode = node->data;
@@ -393,7 +393,7 @@ gboolean notification_foldercheck_read_array(void)
 	}
       }
       if((list == NULL) || (item == NULL)) {
-	g_warning("did not find attribute \"identifier\" in tag "
+	g_warning("Did not find attribute \"identifier\" in tag "
 		  "\"folderitem\"");
 	continue; /* with next leaf node */
       }
@@ -490,7 +490,7 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
   MANAGE_WINDOW_SIGNALS_CONNECT(entry->window);
 
   /* vbox */
-  vbox = gtk_vbox_new(FALSE, 4);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
   gtk_container_add(GTK_CONTAINER(entry->window), vbox);
 
   /* scrolled window */
@@ -587,8 +587,8 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
   gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 10);
 
   gtkut_stock_button_set_create(&confirm_area,
-				&cancel_button, GTK_STOCK_CANCEL,
-				&ok_button,     GTK_STOCK_OK,
+				&cancel_button, _("_Cancel"),
+				&ok_button,     _("_OK"),
 				NULL,           NULL);
   gtk_box_pack_end(GTK_BOX(vbox), confirm_area, FALSE, FALSE, 0);
   gtk_widget_grab_default(ok_button);
