@@ -286,9 +286,9 @@ static gboolean notification_libnotify_create(MsgInfo *msginfo,
   NotificationPopup *ppopup;
   gchar *summary = NULL;
   gchar *text = NULL;
-  gchar *utf8_str;
-  gchar *subj;
-  gchar *from;
+  gchar *utf8_str = NULL;
+  gchar *subj = NULL;
+  gchar *from = NULL;
   gchar *foldname = NULL;
   GList *caps = NULL;
   gboolean support_actions = FALSE;
@@ -322,10 +322,10 @@ static gboolean notification_libnotify_create(MsgInfo *msginfo,
 
     /* Make sure text is valid UTF8 */
     utf8_str = notification_validate_utf8_str(text);
-
     g_free(text);
-    g_free(from);
-    g_free(subj);
+
+    if(from) g_free(from);
+    if(subj) g_free(subj);
     if(foldname) g_free(foldname);
     break;
   case F_TYPE_NEWS:
@@ -614,7 +614,7 @@ static gboolean notification_popup_create(MsgInfo *msginfo)
   gtk_container_add(GTK_CONTAINER(ppopup->event_box), ppopup->frame);
 
   /* Vbox with labels */
-  ppopup->vbox = gtk_vbox_new(FALSE, 2);
+  ppopup->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
   gtk_container_set_border_width(GTK_CONTAINER(ppopup->vbox), 5);
   ppopup->label1 = gtk_label_new(msginfo->from ?
                                  msginfo->from : _("(No From)"));
@@ -629,8 +629,8 @@ static gboolean notification_popup_create(MsgInfo *msginfo)
 
   /* Color */
   if(notify_config.popup_enable_colors) {
-    gtkut_convert_int_to_gdk_color(notify_config.popup_color_bg,&bg);
-    gtkut_convert_int_to_gdk_color(notify_config.popup_color_fg,&fg);
+    GTKUT_GDKRGBA_TO_GDKCOLOR(notify_config.popup_color_bg,bg);
+    GTKUT_GDKRGBA_TO_GDKCOLOR(notify_config.popup_color_fg,fg);
     gtk_widget_modify_bg(ppopup->event_box,GTK_STATE_NORMAL,&bg);
     gtk_widget_modify_fg(ppopup->label1,GTK_STATE_NORMAL,&fg);
     gtk_widget_modify_fg(ppopup->label2,GTK_STATE_NORMAL,&fg);
