@@ -1,5 +1,5 @@
 /* Notification plugin for Claws Mail
- * Copyright (C) 2005-2007 Holger Berndt and the Claws Mail Team.
+ * Copyright (C) 2005-2019 Holger Berndt and the Claws Mail Team.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -474,8 +474,7 @@ static void notification_trayicon_on_popup_menu(GtkStatusIcon *status_icon,
 
   updating_menu = FALSE;
 
-  gtk_menu_popup(GTK_MENU(traymenu_popup), NULL, NULL, NULL, NULL,
-		 button, activate_time);
+  gtk_menu_popup_at_pointer(GTK_MENU(traymenu_popup), NULL);
 }
 
 static gboolean notification_trayicon_on_size_changed(GtkStatusIcon *icon,
@@ -548,7 +547,7 @@ static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
 {
   if(prefs_common_get_prefs()->confirm_on_exit) {
     if(alertpanel(_("Exit"), _("Exit Claws Mail?"),
-		  GTK_STOCK_CANCEL, GTK_STOCK_OK,
+		  _("_Cancel"), _("_OK"),
 		  NULL, ALERTFOCUS_FIRST) != G_ALERTALTERNATE) {
       return;
     }
@@ -897,10 +896,10 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
 
       /* Make sure text is valid UTF8 */
       utf8_str = notification_validate_utf8_str(text);
-
       g_free(text);
-      g_free(from);
-      g_free(subj);
+
+      if(from) g_free(from);
+      if(subj) g_free(subj);
 	  if(foldname) g_free(foldname);
     }
     else if(popup.num_calendar) {
