@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail Team and Salvatore De Paolis
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 Salvatore De Paolis & the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -651,14 +651,18 @@ static char * pdf_viewer_get_document_format_data(GTime utime)
 
 #define ADD_TO_TABLE(LABEL, VALUE) \
 	label = gtk_label_new(LABEL); \
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5); \
-	gtk_misc_set_padding(GTK_MISC(label), 4, 0); \
-	gtk_table_attach(viewer->table_doc_info, label, 0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0); \
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0); \
+	gtk_widget_set_margin_start(GTK_WIDGET(label), 4); \
+	gtk_widget_set_margin_end(GTK_WIDGET(label), 0); \
+	gtk_grid_attach(GTK_GRID(viewer->table_doc_info), label, 0, row, 1, 1); \
 	\
 	label = gtk_label_new(VALUE); \
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5); \
-	gtk_misc_set_padding(GTK_MISC(label), 4, 0); \
-	gtk_table_attach(viewer->table_doc_info, label, 1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0); \
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0); \
+	gtk_widget_set_margin_start(GTK_WIDGET(label), 4); \
+	gtk_widget_set_margin_end(GTK_WIDGET(label), 0); \
+	gtk_grid_attach(GTK_GRID(viewer->table_doc_info), label, 1, row, 1, 1); \
+	gtk_widget_set_hexpand(label, TRUE); \
+	gtk_widget_set_halign(label, GTK_ALIGN_FILL); \
 	row++;
 
 
@@ -696,7 +700,7 @@ static GtkTable * pdf_viewer_fill_info_table(PdfViewer *viewer)
 				"viewer-preferences", &view_prefs,
 				NULL);
 
-	viewer->table_doc_info = GTK_TABLE(gtk_table_new(13, 2, FALSE));
+	viewer->table_doc_info = gtk_grid_new();
 
 	ADD_TO_TABLE(_("Filename:"), viewer->target_filename)
 	ADD_TO_TABLE(_("Size:"), to_human_readable(viewer->to_load->length))
@@ -822,7 +826,8 @@ static void pdf_viewer_button_press_events_cb(GtkWidget *widget, GdkEventButton
 	#endif
 	static GdkCursor *hand_cur = NULL;
 
-	if (!hand_cur) hand_cur = gdk_cursor_new(GDK_FLEUR);
+	if (!hand_cur) hand_cur = gdk_cursor_new_for_display(
+			gtk_widget_get_display(widget), GDK_FLEUR);
 
 	/* Execute Poppler Links */
 	if (event->button == 1 && viewer->in_link) {
@@ -856,7 +861,7 @@ static void pdf_viewer_button_press_events_cb(GtkWidget *widget, GdkEventButton
 			dest = poppler_document_find_dest(
 					viewer->pdf_doc, viewer->link_action->goto_remote.dest->named_dest);
 			if (dest->type != POPPLER_DEST_XYZ) {
-				g_warning("couldn't figure out link");
+				g_warning ("couldn't figure out link");
 				poppler_dest_free(dest);
 				break;
 			}
@@ -1021,7 +1026,8 @@ static void pdf_viewer_move_events_cb(GtkWidget *widget, GdkEventMotion *event,
 	viewer->pdf_view_vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
 	viewer->pdf_view_hadj = gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
 
-	if (!link_cur) link_cur = gdk_cursor_new(GDK_HAND2);
+	if (!link_cur) link_cur = gdk_cursor_new_for_display(
+			gtk_widget_get_display(viewer->scrollwin), GDK_HAND2);
 
 	ccur = FALSE;
 	viewer->in_link = FALSE;	
@@ -1034,7 +1040,7 @@ static void pdf_viewer_move_events_cb(GtkWidget *widget, GdkEventMotion *event,
 		y1 = lmapping->area.y1;
 		x2 = lmapping->area.x2;
 		y2 = lmapping->area.y2;
-		gtk_widget_size_request(viewer->pdf_view, &size);
+		gtk_widget_get_preferred_size(viewer->pdf_view, &size, NULL);
 
 		upper = gtk_adjustment_get_upper(viewer->pdf_view_hadj);
 		switch (viewer->rotate) {
@@ -1219,7 +1225,7 @@ static void pdf_viewer_button_print_cb(GtkButton *button, PdfViewer *viewer)
 
 static void pdf_viewer_button_document_info_cb(GtkButton *button, PdfViewer *viewer)
 {
-	alertpanel_full(_("PDF properties"), NULL, GTK_STOCK_CLOSE, NULL, NULL,
+	alertpanel_full(_("PDF properties"), NULL, _("_Close"), NULL, NULL,
 			ALERTFOCUS_FIRST, FALSE,
 			GTK_WIDGET(pdf_viewer_fill_info_table(viewer)), 
 			ALERT_NOTICE);
@@ -1333,7 +1339,7 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 				tmpfile = get_tmp_file();
 				cmdline = g_strdup_printf(
 					"gs -dSAFER -dCompatibilityLevel=1.2 -q -dNOPAUSE -dBATCH "
-					  "-sDEVICE=pdfwrite -sOutputFile=%s -f \"%s\"",
+					  "-sDEVICE=pdfwrite -sOutputFile=%s -c .setpdfwrite -f \"%s\"",
 					tmpfile, viewer->filename);
 				result = execute_command_line(cmdline, FALSE, NULL);
 				if (result == 0) {
@@ -1445,7 +1451,7 @@ static void pdf_viewer_update(MimeViewer *_viewer, gboolean reload_file, int pag
 		viewer->pdf_page = poppler_document_get_page(viewer->pdf_doc, page_num - 1);
 
 		if (viewer->pdf_page == NULL) {
-			g_warning("page not found");
+			g_warning("Page not found");
 			return;
 		}   
 
@@ -1635,22 +1641,22 @@ static void pdf_viewer_scroll_one_line(MimeViewer *_viewer, gboolean up)
 	widget = gtk_button_new(); \
 	img = stock_pixmap_widget(stock_image); \
 	gtk_button_set_image(GTK_BUTTON(widget), img); \
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(widget), \
-				col, col+1, 0, 1, 0, 0, BUTTON_H_PADDING, 0); \
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(widget), \
+			col, 0, 1, 1); \
 	col++;
 #define ADD_TOGGLE_BUTTON_TO_TABLE(widget, stock_image) \
 	widget = gtk_toggle_button_new(); \
 	img = stock_pixmap_widget(stock_image); \
 	gtk_button_set_image(GTK_BUTTON(widget), img); \
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(widget), \
-				col, col+1, 0, 1, 0, 0, BUTTON_H_PADDING, 0); \
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(widget), \
+			col, 0, 1, 1); \
 	col++;
 
 #define ADD_SEP_TO_TABLE \
 	sep = gtk_label_new(""); \
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(sep), \
-					col, col+1, 0, 1, 0, 0, 0, 0); \
-	gtk_table_set_col_spacing(GTK_TABLE(viewer->widgets_table), col, 3*BUTTON_H_PADDING); \
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(sep), \
+			col, 0, 1, 1); \
+	gtk_grid_set_column_spacing(GTK_GRID(viewer->widgets_table), 3); \
 	col++;
 
 #if POPPLER_HAS_CAIRO
@@ -1771,9 +1777,9 @@ static MimeViewer *pdf_viewer_create(void)
 
 	viewer->doc_label = gtk_label_new("");
 
-	viewer->widgets_table = gtk_table_new(1, 1, FALSE);
+	viewer->widgets_table = gtk_grid_new();
 
-	viewer->doc_index_pane = gtk_hpaned_new();
+	viewer->doc_index_pane = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
 
 	viewer->frame_index = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type(GTK_FRAME(viewer->frame_index), GTK_SHADOW_IN);
@@ -1789,17 +1795,12 @@ static MimeViewer *pdf_viewer_create(void)
 	viewer->zoom = 1.0;
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(viewer->cur_page), TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(viewer->zoom_scroll), TRUE);
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(viewer->cur_page),
-					col, col+1, 
-					0, 1, 0, 0, 
-					BUTTON_H_PADDING, 
-					0);
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(viewer->cur_page),
+			col, 0, 1, 1);
+
 	col++;
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(viewer->doc_label),
-					col, col+1, 
-					0, 1, 0, 0, 
-					BUTTON_H_PADDING, 
-					0);
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(viewer->doc_label),
+			col, 0, 1, 1);
 	col++;
 
 	ADD_BUTTON_TO_TABLE(viewer->next_page, STOCK_PIXMAP_RIGHT_ARROW)
@@ -1807,11 +1808,8 @@ static MimeViewer *pdf_viewer_create(void)
 	ADD_SEP_TO_TABLE
 	ADD_BUTTON_TO_TABLE(viewer->zoom_fit, STOCK_PIXMAP_ZOOM_FIT)
 	ADD_BUTTON_TO_TABLE(viewer->zoom_in, STOCK_PIXMAP_ZOOM_IN)
-	gtk_table_attach(GTK_TABLE(viewer->widgets_table), GTK_WIDGET(viewer->zoom_scroll),
-					col, col+1, 
-					0, 1, 0, 0, 
-					BUTTON_H_PADDING, 
-					0);
+	gtk_grid_attach(GTK_GRID(viewer->widgets_table), GTK_WIDGET(viewer->zoom_scroll),
+			col, 0, 1, 1);
 	col++;
 	ADD_BUTTON_TO_TABLE(viewer->zoom_out, STOCK_PIXMAP_ZOOM_OUT)
 	ADD_BUTTON_TO_TABLE(viewer->zoom_width, STOCK_PIXMAP_ZOOM_WIDTH)
@@ -1831,12 +1829,12 @@ static MimeViewer *pdf_viewer_create(void)
 			GTK_SCROLLED_WINDOW(viewer->scrollwin),
 			GTK_SHADOW_IN);
 
-	gtk_scrolled_window_add_with_viewport(
-			GTK_SCROLLED_WINDOW(viewer->scrollwin),
+	gtk_container_add(
+			GTK_CONTAINER(viewer->scrollwin),
 			viewer->pdf_view_ebox);
 
-	viewer->vbox = gtk_vbox_new(FALSE, 4);
-	viewer->hbox = gtk_hbox_new(FALSE, 4);
+	viewer->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
+	viewer->hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 
     /* treeview */
 	tree_store = gtk_tree_store_new(N_INDEX_COLUMNS,
@@ -1845,6 +1843,7 @@ static MimeViewer *pdf_viewer_create(void)
 					G_TYPE_DOUBLE);
 
 	viewer->index_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(tree_store));
+	g_object_unref(tree_store);
 
 	renderer = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes(_("Name"),  renderer, "text", 0,  NULL);
@@ -1852,7 +1851,6 @@ static MimeViewer *pdf_viewer_create(void)
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(viewer->index_list), FALSE);
 
 	viewer->index_model = GTK_TREE_MODEL(tree_store);
-	g_object_unref(tree_store);
 
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(viewer->index_list)), 
 								GTK_SELECTION_SINGLE);
@@ -1869,8 +1867,8 @@ static MimeViewer *pdf_viewer_create(void)
 			GTK_SCROLLED_WINDOW(viewer->scrollwin_index),
 			GTK_SHADOW_IN);
 
-	gtk_scrolled_window_add_with_viewport(
-			GTK_SCROLLED_WINDOW(viewer->scrollwin_index),
+	gtk_container_add(
+			GTK_CONTAINER(viewer->scrollwin_index),
 			viewer->index_list);
 
 	/* end treeview */
@@ -2154,7 +2152,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
