@@ -178,7 +178,7 @@ static void pgpview_show_mime_part(TextView *textview, MimeInfo *partinfo)
 		if (!prefs_common_get_prefs()->work_offline) {
 			val = alertpanel(_("Key import"),
 				_("This key is not in your keyring. Do you want "
-				  "Claws Mail to try to import it?"),
+				  "Claws Mail to try and import it?"),
 				  _("_No"), _("from keyserver"), _("from Web Key Directory"),
 				  ALERTFOCUS_SECOND);
 			GTK_EVENTS_FLUSH();
@@ -304,11 +304,10 @@ static void pgpview_show_mime_part(TextView *textview, MimeInfo *partinfo)
 
 		TEXTVIEW_INSERT(":\n\n");
 		TEXTVIEW_INSERT(_("   This key is in your keyring.\n"));
-		gpgme_key_unref(key);
 	}
 	gpgme_data_release(sigdata);
 	gpgme_release(ctx);
-	textview_show_icon(textview, GTK_STOCK_DIALOG_AUTHENTICATION);
+	textview_show_icon(textview, "dialog-password");
 }
 
 
