@@ -15,6 +15,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "clawsmailmodule.h"
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #include "claws-features.h"
@@ -23,7 +25,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include "clawsmailmodule.h"
 #include "nodetype.h"
 #include "composewindowtype.h"
 #include "folderpropertiestype.h"
@@ -34,8 +35,6 @@
 
 #define NO_IMPORT_PYGOBJECT
 #include <pygobject.h>
-#define NO_IMPORT_PYGTK
-#include <pygtk/pygtk.h>
 
 #include "main.h"
 #include "mainwindow.h"
@@ -46,6 +45,7 @@
 #include "common/tags.h"
 #include "account.h"
 
+#include <glib.h>
 
 static PyObject *cm_module = NULL;
 
@@ -323,9 +323,9 @@ static PyObject* get_folder_tree(PyObject *self, PyObject *args)
   if(PyTuple_Size(args) == 0) {
     result = get_folder_tree_from_account_name(NULL);
   }
-  else if(PyString_Check(arg)){
+  else if(PyBytes_Check(arg)){
     const char *str;
-    str = PyString_AsString(arg);
+    str = PyBytes_AsString(arg);
     if(!str)
       return NULL;
 
@@ -902,21 +902,33 @@ static gboolean add_miscstuff(PyObject *module)
 }
 
 
+static struct PyModuleDef moduledef = {
+  PyModuleDef_HEAD_INIT,
+  "clawsmail",
+  "This module can be used to access some of Claws Mail's data structures\n"
+  "in order to extend or modify the user interface or automate repetitive tasks.\n"
+  "\n"
+  "Whenever possible, the interface works with standard GTK+ widgets\n"
+  "via the PyGTK bindings, so you can refer to the GTK+ / PyGTK documentation\n"
+  "to find out about all possible options.\n"
+  "\n"
+  "The interface to Claws Mail in this module is extended on a 'as-needed' basis.\n"
+  "If you're missing something specific, try contacting the author.",
+  0,
+  ClawsMailMethods,
+  NULL,
+  NULL,
+  NULL,
+  NULL
+};
+
 PyMODINIT_FUNC initclawsmail(void)
 {
   gboolean ok = TRUE;
 
   /* create module */
-  cm_module = Py_InitModule3("clawsmail", ClawsMailMethods,
-      "This module can be used to access some of Claws Mail's data structures\n"
-      "in order to extend or modify the user interface or automate repetitive tasks.\n"
-      "\n"
-      "Whenever possible, the interface works with standard GTK+ widgets\n"
-      "via the PyGTK bindings, so you can refer to the GTK+ / PyGTK documentation\n"
-      "to find out about all possible options.\n"
-      "\n"
-      "The interface to Claws Mail in this module is extended on a 'as-needed' basis.\n"
-      "If you're missing something specific, try contacting the author.");
+
+  cm_module = PyModule_Create(&moduledef);
 
   /* add module member "compose_window" set to None */
   Py_INCREF(Py_None);
@@ -935,6 +947,11 @@ PyMODINIT_FUNC initclawsmail(void)
   /* initialize misc things */
   if(ok)
     add_miscstuff(cm_module);
+
+  /* initialize pygobject */
+  pygobject_init(-1, -1, -1);
+
+  return cm_module;
 }
 
 
