@@ -1,7 +1,7 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2004 Hiroyuki Yamamoto
- * This file (C) 2005-2021 Andrej Kacian <andrej@kacian.sk> and the
+ * This file (C) 2005-2019 Andrej Kacian <andrej@kacian.sk> and the
  * Claws Mail team
  *
  * - callback handler functions for folderview rssyl context menu items
@@ -54,7 +54,6 @@ void rssyl_new_feed_cb(GtkAction *action,
 	FolderView *folderview = (FolderView*)data;
 	FolderItem *item;
 	gchar *url;
-	gchar *clip_text = NULL, *str = NULL;
 
 	debug_print("RSSyl: new_feed_cb\n");
 
@@ -64,45 +63,9 @@ void rssyl_new_feed_cb(GtkAction *action,
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
-	clip_text = gtk_clipboard_wait_for_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD));
-
-	if (clip_text) {
-		str = clip_text;
-#if GLIB_CHECK_VERSION(2,66,0)
-		GError *error = NULL;
-		GUri *uri = NULL;
-
-		/* skip any leading white-space */
-		while (str && *str && g_ascii_isspace(*str))
-			str++;
-		uri = g_uri_parse(str, G_URI_FLAGS_PARSE_RELAXED, &error);
-		if (error) {
-			g_warning("could not parse clipboard text for URI: '%s'", error->message);
-			g_error_free(error);
-		}
-		if (uri) {
-			gchar* newstr = g_uri_to_string(uri);
-
-			debug_print("URI: '%s' -> '%s'\n", str, newstr ? newstr : "N/A");
-			if (newstr)
-				g_free(newstr);
-			g_uri_unref(uri);
-		} else {
-#else
-		if (!is_uri_string(str)) {
-#endif
-			/* if no URL, ignore clipboard text */
-			str = NULL;
-		}
-	}
-
 	url = input_dialog(_("Subscribe feed"),
 			_("Input the URL of the news feed you wish to subscribe:"),
-			str ? str : "");
-
-	if (clip_text)
-		g_free(clip_text);
-
+			"");
 	if( url == NULL )	/* User cancelled */
 		return;
 
@@ -187,11 +150,11 @@ void rssyl_remove_folder_cb(GtkAction *action,
 	name = trim_string(item->name, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
 	message = g_strdup_printf
-		(_("All folders and messages under '%s' will be permanently deleted.\n"
+		(_("All folders and messages under '%s' will be permanently deleted. "
 		   "Recovery will not be possible.\n\n"
 		   "Do you really want to delete?"), name);
 	avalue = alertpanel_full(_("Delete folder"), message,
-				 GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL, ALERTFOCUS_FIRST, FALSE,
+				 _("_Cancel"), "edit-delete", NULL, ALERTFOCUS_FIRST, FALSE,
 				 NULL, ALERT_WARNING);
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
@@ -357,7 +320,7 @@ void rssyl_remove_mailbox_cb(GtkAction *action, gpointer data)
 	n = trim_string(item->folder->name, 32);
 	message = g_strdup_printf(_("Really remove the feed tree `%s' ?\n"), n);
 	avalue = alertpanel_full(_("Remove feed tree"), message,
-				 GTK_STOCK_CANCEL, _("_Remove"), NULL, ALERTFOCUS_FIRST, FALSE,
+				 _("_Cancel"), _("_Remove"), NULL, ALERTFOCUS_FIRST, FALSE,
 				 NULL, ALERT_WARNING);
 	g_free(message);
 	g_free(n);
@@ -402,7 +365,7 @@ void rssyl_import_feed_list_cb(GtkAction *action, gpointer data)
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
-	ctx = g_malloc( sizeof(OPMLImportCtx) );
+	ctx = malloc( sizeof(OPMLImportCtx) );
 	ctx->failures = 0;
 	ctx->depth = rssyl_folder_depth(item) + 1;
 	ctx->current = NULL;
