@@ -203,16 +203,12 @@ gboolean rssyl_parse_feed(RFolderItem *ritem, Feed *feed)
 	rssyl_folder_read_existing(ritem);
 
 	if( claws_is_exiting() ) {
-		debug_print("RSSyl: Claws-Mail is exiting, bailing out\n");
+		debug_print("RSSyl: Claws Mail is exiting, bailing out\n");
 		log_print(LOG_PROTOCOL, RSSYL_LOG_ABORTED_EXITING, ritem->url);
 		folder_item_update_thaw();
 		return TRUE;
 	}
 
-	/* Populate the ->deleted_items list so that we can check it when
-	 * adding each item. */
-	ritem->deleted_items = rssyl_deleted_update(ritem);
-
 	/* Parse each item in the feed, adding or updating existing items if
 	 * necessary */
 	if( feed_n_items(feed) > 0 )
@@ -223,8 +219,6 @@ gboolean rssyl_parse_feed(RFolderItem *ritem, Feed *feed)
 		rssyl_expire_items(ritem, feed);
 	}
 
-	rssyl_deleted_free(ritem->deleted_items);
-
 	folder_item_scan(&ritem->item);
 	folder_item_update_thaw();
 
