@@ -42,6 +42,7 @@
 #include "procmsg.h"
 #include "log.h"
 #include "inc.h"
+#include "plugin.h"
 #include "menu.h"
 #include "defs.h"
 #include "procheader.h"
@@ -239,9 +240,6 @@ static void report_spam(gint id, ReportInterface *intf, MsgInfo *msginfo, gchar
 			curl_easy_setopt(curl, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
 			curl_easy_setopt(curl, CURLOPT_USERAGENT,
                 		SPAM_REPORT_USERAGENT "(" PLUGINS_URI ")");
-#ifdef G_OS_WIN32
-			curl_easy_setopt(curl, CURLOPT_CAINFO, claws_ssl_get_cert_file());
-#endif
 			res = curl_easy_perform(curl);
 			if (res != CURLE_OK)
 				debug_print("curl_easy_perfom failed: %s", curl_easy_strerror(res));
@@ -260,22 +258,19 @@ static void report_spam(gint id, ReportInterface *intf, MsgInfo *msginfo, gchar
 		}
 		break;
 	case INTF_HTTP_GET:
-		curl = curl_easy_init();
-		curl_easy_setopt(curl, CURLOPT_URL, geturl);
+	        curl = curl_easy_init();
+        	curl_easy_setopt(curl, CURLOPT_URL, geturl);
 		curl_easy_setopt(curl, CURLOPT_USERAGENT,
                 		SPAM_REPORT_USERAGENT "(" PLUGINS_URI ")");
-		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, curl_writefunction_cb);
-		curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void *)&chunk);
-#ifdef G_OS_WIN32
-		curl_easy_setopt(curl, CURLOPT_CAINFO, claws_ssl_get_cert_file());
-#endif
+        	curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, curl_writefunction_cb);
+	        curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void *)&chunk);
 		res = curl_easy_perform(curl);
 		if (res != CURLE_OK)
 			debug_print("curl_easy_perfom failed: %s", curl_easy_strerror(res));
 		curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &response);
-		curl_easy_cleanup(curl);
+	        curl_easy_cleanup(curl);
 		spamreport_http_response_log(geturl, response);
-		/* On success the page should return "OK: nominated <msgid>" */
+        	/* On success the page should return "OK: nominated <msgid>" */
 		if (chunk.size < 13 || strstr(chunk.data, "OK: nominated") == NULL) {
 			if (chunk.size > 0) {
 				log_error(LOG_PROTOCOL, "%s: response was %s\n", geturl, chunk.data);
@@ -286,7 +281,7 @@ static void report_spam(gint id, ReportInterface *intf, MsgInfo *msginfo, gchar
 		}
 		break;
 	default:
-		g_warning("unknown method");
+		g_warning("Unknown method");
 	}
 	g_free(reqbody);
 	g_free(geturl);
@@ -407,7 +402,7 @@ const gchar *plugin_desc(void)
 
 const gchar *plugin_type(void)
 {
-	return "GTK2";
+	return "GTK3";
 }
 
 const gchar *plugin_licence(void)
