@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2023 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,7 @@
 #include "folder.h"
 #include "socket.h"
 #include "filesel.h"
+#include "folderview.h"
 #include "stock_pixmap.h"
 #include "prefswindow.h"
 #include "colorlabel.h"
@@ -464,8 +465,6 @@ static PrefParam param[] = {
 
 	 {"bold_unread", "TRUE", &prefs_common.bold_unread, P_BOOL,
 	 NULL, NULL, NULL},
-	 {"bold_marked", "FALSE", &prefs_common.bold_marked, P_BOOL,
-	 NULL, NULL, NULL},
 
 #ifndef GENERIC_UMPC
 	{"toolbar_style", "3", &prefs_common.toolbar_style, P_ENUM,
@@ -474,8 +473,6 @@ static PrefParam param[] = {
 	{"toolbar_style", "1", &prefs_common.toolbar_style, P_ENUM,
 	 NULL, NULL, NULL},
 #endif
-	{"toolbar_detachable", "FALSE", &prefs_common.toolbar_detachable, P_BOOL,
-	 NULL, NULL, NULL},
 	{"show_col_headers", "TRUE", &prefs_common.show_col_headers, P_BOOL,
 	 NULL, NULL, NULL},
 #ifndef GENERIC_UMPC
@@ -900,8 +897,6 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 #endif
 
-	{"run_processingrules_before_mark_all", "FALSE", &prefs_common.run_processingrules_before_mark_all, P_BOOL,
-	 NULL, NULL, NULL},
 	{"ask_mark_all_read", "TRUE", &prefs_common.ask_mark_all_read, P_BOOL,
 	 NULL, NULL, NULL},
 	{"ask_override_colorlabel", "TRUE", &prefs_common.ask_override_colorlabel, P_BOOL,
@@ -1027,8 +1022,6 @@ static PrefParam param[] = {
 	{"filtering_debug_log_length", "500", &prefs_common.filtering_debug_loglength, P_INT,
 	 NULL, NULL, NULL},
 
-	{"gtk_can_change_accels", "FALSE", &prefs_common.gtk_can_change_accels, P_BOOL,
-	 NULL, NULL, NULL},
 	{"gtk_enable_accels", "TRUE", &prefs_common.gtk_enable_accels, P_BOOL,
 	 NULL, NULL, NULL},
 
@@ -1174,11 +1167,7 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"warn_dnd", "1", &prefs_common.warn_dnd, P_INT,
 	 NULL, NULL, NULL},
-	{"show_save_all_success", "1", &prefs_common.show_save_all_success, P_INT,
-	 NULL, NULL, NULL},
-	{"show_save_all_failure", "1", &prefs_common.show_save_all_failure, P_INT,
-	 NULL, NULL, NULL},
-	{"utf8_instead_of_locale_for_broken_mail", "0",
+	{"utf8_instead_of_locale_for_broken_mail", "0", 
 	 &prefs_common.broken_are_utf8, P_INT,
 	 NULL, NULL, NULL},
 	{"enable_swap_from", "FALSE", &prefs_common.swap_from, P_BOOL,
@@ -1216,10 +1205,6 @@ static PrefParam param[] = {
 	P_STRING, NULL, NULL, NULL },
 	{"goto_last_folder_on_startup", "FALSE", &prefs_common.goto_last_folder_on_startup,
 	P_BOOL, NULL, NULL, NULL },
-	{"startup_folder", "", &prefs_common.startup_folder,
-	P_STRING, NULL, NULL, NULL },
-	{"goto_folder_on_startup", "FALSE", &prefs_common.goto_folder_on_startup,
-	P_BOOL, NULL, NULL, NULL },
 	{"summary_quicksearch_sticky", "1", &prefs_common.summary_quicksearch_sticky, P_INT,
 	 NULL, NULL, NULL},
 	{"summary_quicksearch_dynamic", "0", &prefs_common.summary_quicksearch_dynamic, P_INT,
@@ -1304,10 +1289,10 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"enable_avatars", "3", &prefs_common.enable_avatars, P_INT, NULL, NULL, NULL},
 #ifndef PASSWORD_CRYPTO_OLD
-	{"use_master_passphrase", FALSE, &prefs_common.use_primary_passphrase, P_BOOL, NULL, NULL, NULL },
-	{"master_passphrase", "", &prefs_common.primary_passphrase, P_STRING, NULL, NULL, NULL },
-	{"master_passphrase_salt", "", &prefs_common.primary_passphrase_salt, P_STRING, NULL, NULL, NULL },
-	{"master_passphrase_pbkdf2_rounds", "50000", &prefs_common.primary_passphrase_pbkdf2_rounds, P_INT, NULL, NULL, NULL},
+	{"use_master_passphrase", FALSE, &prefs_common.use_master_passphrase, P_BOOL, NULL, NULL, NULL },
+	{"master_passphrase", "", &prefs_common.master_passphrase, P_STRING, NULL, NULL, NULL },
+	{"master_passphrase_salt", "", &prefs_common.master_passphrase_salt, P_STRING, NULL, NULL, NULL },
+	{"master_passphrase_pbkdf2_rounds", "50000", &prefs_common.master_passphrase_pbkdf2_rounds, P_INT, NULL, NULL, NULL},
 #endif
 
 	{"use_proxy", "FALSE", &prefs_common.use_proxy, P_BOOL, NULL, NULL, NULL},
@@ -1318,9 +1303,6 @@ static PrefParam param[] = {
 	{"proxy_name", "", &prefs_common.proxy_info.proxy_name, P_STRING, NULL, NULL, NULL},
 	{"proxy_pass", NULL, &prefs_common.proxy_info.proxy_pass, P_STRING, NULL, NULL, NULL},
 
-	{"qs_press_timeout", "500", &prefs_common.qs_press_timeout, P_INT,
-	 NULL, NULL, NULL},
-
 	{NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL}
 };
 
@@ -1749,7 +1731,7 @@ const gchar *prefs_common_get_ext_editor_cmd(void)
 	
 	g_free(tmp);
 	return "xdg-open %s";
-#endif 
+#endif /* 0 */
 }
 
 gboolean prefs_common_get_use_shred(void)
