@@ -49,6 +49,14 @@
 	 (CL(c.green) << (gulong)  8) | \
 	 (CL(c.blue)))
 
+/* Kept for backwards compatibility */
+#define INTCOLOR_TO_GDKRGBA(intcolor, rgba) \
+	rgba.red   = (gdouble)(((intcolor >> 16UL) & 0xFFUL) << 8UL) / 65535; \
+	rgba.green = (gdouble)(((intcolor >>  8UL) & 0xFFUL) << 8UL) / 65535; \
+	rgba.blue  = (gdouble)(((intcolor        ) & 0xFFUL) << 8UL) / 65535; \
+	rgba.alpha = 1;
+
+
 typedef enum
 {
 	DUMMY_PARAM
@@ -74,7 +82,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	cm_return_if_fail(rcfile != NULL);
 
 	if (encoding != NULL)
-		g_warning("encoding is ignored");
+		g_warning("Encoding is ignored");
 
 	debug_print("Reading configuration...\n");
 
@@ -143,7 +151,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 	gint i;
 	gint name_len;
 	const gchar *value;
-	GdkColor color;
+	GdkRGBA color;
 
 	for (i = 0; param[i].name != NULL; i++) {
 		name_len = strlen(param[i].name);
@@ -172,7 +180,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 				tmp = g_strdup("");
 			}
 			if (!tmp) {
-				g_warning("failed to convert character set");
+				g_warning("Failed to convert character set.");
 				tmp = g_strdup(value);
 			}
 			g_free(*((gchar **)param[i].data));
@@ -197,12 +205,11 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 				(gushort)atoi(value);
 			break;
 		case P_COLOR:
-			if (gdk_color_parse(value, &color)) {
-				*((gulong *)param[i].data) = RGB_FROM_GDK_COLOR(color); 
-			}
-			else 
+			if (!gdk_rgba_parse(&color, value)) {
 				/* be compatible and accept ints */
-				*((gulong *)param[i].data) = strtoul(value, 0, 10); 
+				INTCOLOR_TO_GDKRGBA(strtoul(value, 0, 10), color);
+			}
+			*((GdkRGBA *)param[i].data) = color;
 			break;
 		default:
 			break;
@@ -213,7 +220,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 #define TRY(func) \
 if (!(func)) \
 { \
-	g_warning("failed to write configuration to file"); \
+	g_warning("Failed to write configuration to file"); \
 	if (orig_fp) claws_fclose(orig_fp); \
 	prefs_file_close_revert(pfile); \
 	g_free(rcpath); \
@@ -241,7 +248,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 	}
 
 	if ((pfile = prefs_write_open(rcpath)) == NULL) {
-		g_warning("failed to write configuration to file");
+		g_warning("Failed to write configuration to file");
 		if (orig_fp) claws_fclose(orig_fp);
 		g_free(rcpath);
 		return;
@@ -297,7 +304,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 
 	if (orig_fp) claws_fclose(orig_fp);
 	if (prefs_file_close(pfile) < 0)
-		g_warning("failed to write configuration to file");
+		g_warning("Failed to write configuration to file");
 	g_free(rcpath);
 
 	debug_print("Configuration is saved.\n");
@@ -307,6 +314,7 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 {
 	gint i;
 	gchar buf[PREFSBUFSIZE] = "";
+	gchar *tmp;
 
 	for (i = 0; param[i].name != NULL; i++) {
 		switch (param[i].type) {
@@ -352,8 +360,9 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 				   *((gushort *)param[i].data));
 			break;
 		case P_COLOR:
-			g_snprintf(buf, sizeof buf,  "%s=#%6.6lx\n", param[i].name,
-				   *((gulong *) param[i].data));
+			tmp = gtkut_gdk_rgba_to_string((GdkRGBA *)param[i].data);
+			g_snprintf(buf, sizeof buf,  "%s=%s\n", param[i].name, tmp);
+			g_free(tmp);
 			break;
 		default:
 			/* unrecognized, fail */
@@ -375,7 +384,7 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 void prefs_set_default(PrefParam *param)
 {
 	gint i;
-	GdkColor color;
+	GdkRGBA color;
 
 	cm_return_if_fail(param != NULL);
 
@@ -397,7 +406,7 @@ void prefs_set_default(PrefParam *param)
 								    CS_INTERNAL)
 						: g_strdup("");
 					if (!tmp) {
-						g_warning("failed to convert character set");
+						g_warning("Failed to convert character set.");
 						tmp = g_strdup(envstr);
 					}
 					*((gchar **)param[i].data) = tmp;
@@ -455,13 +464,19 @@ void prefs_set_default(PrefParam *param)
 				*((gushort *)param[i].data) = 0;
 			break;
 		case P_COLOR:
-			if (param[i].defval != NULL && gdk_color_parse(param[i].defval, &color))
-				*((gulong *)param[i].data) = RGB_FROM_GDK_COLOR(color);
-			else if (param[i].defval)
+			if (param[i].defval != NULL && gdk_rgba_parse(&color, param[i].defval)) {
+				color.alpha = 1;
+				*((GdkRGBA *)param[i].data) = color;
+			} else if (param[i].defval) {
 				/* be compatible and accept ints */
-				*((gulong *)param[i].data) = strtoul(param[i].defval, 0, 10); 
-			else
-				*((gulong *)param[i].data) = 0; 
+				INTCOLOR_TO_GDKRGBA(strtoul(param[i].defval, 0, 10), color);
+				*((GdkRGBA *)param[i].data) = color;
+			} else {
+				/* set to black as fallback */
+				color.red = color.green = color.blue = 0;
+				color.alpha = 1;
+				*((GdkRGBA *)param[i].data) = color;
+			}
 			break;
 		default:
 			break;
@@ -625,7 +640,7 @@ void prefs_set_data_from_entry(PrefParam *pparam)
 		*((gint *)pparam->data) = atoi(entry_str);
 		break;
 	default:
-		g_warning("invalid PrefType for GtkEntry widget: %d",
+		g_warning("Invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -643,7 +658,7 @@ void prefs_set_escaped_data_from_entry(PrefParam *pparam)
 		*str = pref_get_pref_from_entry(GTK_ENTRY(*pparam->widget));
 		break;
 	default:
-		g_warning("invalid escaped PrefType for GtkEntry widget: %d",
+		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -668,7 +683,7 @@ void prefs_set_entry(PrefParam *pparam)
 				   itos(*((gushort *)pparam->data)));
 		break;
 	default:
-		g_warning("invalid PrefType for GtkEntry widget: %d",
+		g_warning("Invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -686,7 +701,7 @@ void prefs_set_entry_from_escaped(PrefParam *pparam)
 				   *str ? *str : "");
 		break;
 	default:
-		g_warning("invalid escaped PrefType for GtkEntry widget: %d",
+		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -738,7 +753,7 @@ void prefs_set_data_from_text(PrefParam *pparam)
 		g_free(text);
 		break;
 	default:
-		g_warning("invalid PrefType for GtkText widget: %d",
+		g_warning("Invalid PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -756,7 +771,7 @@ void prefs_set_escaped_data_from_text(PrefParam *pparam)
 		*str = pref_get_pref_from_textview(GTK_TEXT_VIEW(*pparam->widget));
 		break;
 	default:
-		g_warning("invalid escaped PrefType for GtkText widget: %d",
+		g_warning("Invalid escaped PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -798,7 +813,7 @@ void prefs_set_text(PrefParam *pparam)
 		gtk_text_buffer_insert(buffer, &iter, buf, -1);
 		break;
 	default:
-		g_warning("invalid PrefType for GtkTextView widget: %d",
+		g_warning("Invalid PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -816,7 +831,7 @@ void prefs_set_text_from_escaped(PrefParam *pparam)
 				 *str ? *str : "");
 		break;
 	default:
-		g_warning("invalid escaped PrefType for GtkTextView widget: %d",
+		g_warning("Invalid escaped PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -855,7 +870,7 @@ void prefs_set_data_from_spinbtn(PrefParam *pparam)
 			(GTK_SPIN_BUTTON(*pparam->widget));
 		break;
 	default:
-		g_warning("invalid PrefType for GtkSpinButton widget: %d",
+		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
@@ -874,7 +889,7 @@ void prefs_set_spinbtn(PrefParam *pparam)
 					  (gfloat)*((gushort *)pparam->data));
 		break;
 	default:
-		g_warning("invalid PrefType for GtkSpinButton widget: %d",
+		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
@@ -1044,7 +1059,7 @@ static gboolean prefs_read_config_from_cache(PrefParam *param, const gchar *labe
 	sections_table = g_hash_table_lookup(whole_cache, rcfile);
 	
 	if (sections_table == NULL) {
-		g_warning("can't find %s in the whole cache", rcfile?rcfile:"(null)");
+		g_warning("Can't find %s in the whole cache", rcfile?rcfile:"(null)");
 		return FALSE;
 	}
 	values_table = g_hash_table_lookup(sections_table, label);
