@@ -78,8 +78,6 @@ static void quote_colors_set_dialog_cancel	(GtkWidget	*widget,
 static gboolean quote_colors_set_dialog_key_pressed	(GtkWidget	*widget,
 						 GdkEventKey	*event,
 						 gpointer	 data);
-static void set_button_bg_color			(GtkWidget	*widget,
-						 gint		 color);
 static void prefs_msg_colors_reset_custom_colors(GtkWidget *widget,
 						 gpointer	 data);
 
@@ -146,7 +144,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	notebook = gtk_notebook_new();
 	gtk_widget_show(notebook);
 	
-	vbox1 = gtk_vbox_new (FALSE, VBOX_BORDER);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox1,
@@ -154,18 +152,18 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	vbox2 = gtkut_get_options_frame(vbox1, &frame_msg, _("Message view"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, TRUE, 0);
 	PACK_CHECK_BUTTON (hbox, checkbtn_enable_colors,
 			   _("Enable coloration of message text"));	
 
-	hbox_quote = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox_quote = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox_quote);
-	vbox_quotefg = gtk_vbox_new(FALSE, VBOX_BORDER);
+	vbox_quotefg = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_widget_show (vbox_quotefg);
-	vbox_quotebg = gtk_vbox_new(FALSE, VBOX_BORDER);
+	vbox_quotebg = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_widget_show (vbox_quotebg);
 	vbox3 = gtkut_get_options_frame(vbox2, &frame_quote, _("Quote"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, frame_quote);
@@ -174,7 +172,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_box_pack_start (GTK_BOX (hbox_quote), vbox_quotefg, FALSE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox_quote), vbox_quotebg, FALSE, TRUE, 0);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotefg), hbox, FALSE, TRUE, 0);
 
@@ -185,7 +183,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	CLAWS_SET_TIP(checkbtn_recycle_colors,
 			     _("If there are more than 3 quote levels, the colors will be reused"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotefg), hbox, FALSE, TRUE, 0);
 
@@ -203,7 +201,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors,
 			       color_buttons.color[COL_QUOTE_LEVEL1]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotefg), hbox, FALSE, TRUE, 0);
 
@@ -221,7 +219,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors,
 			       color_buttons.color[COL_QUOTE_LEVEL2]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotefg), hbox, FALSE, TRUE, 0);
 
@@ -239,7 +237,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors,
 			       color_buttons.color[COL_QUOTE_LEVEL3]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotebg), hbox, FALSE, TRUE, 0);
 
@@ -247,7 +245,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 			   _("Enable coloration of text background"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, checkbtn_enable_bgcolors);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotebg), hbox, FALSE, TRUE, 0);
@@ -260,7 +258,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	COLOR_LABEL_PACK_START(hbox, COL_QUOTE_LEVEL1_BG, _("Background"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_bgcolors, label[COL_QUOTE_LEVEL1_BG]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotebg), hbox, FALSE, TRUE, 0);
@@ -273,7 +271,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	COLOR_LABEL_PACK_START(hbox, COL_QUOTE_LEVEL2_BG, _("Background"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_bgcolors, label[COL_QUOTE_LEVEL2_BG]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, hbox);
 	gtk_box_pack_start (GTK_BOX (vbox_quotebg), hbox, FALSE, TRUE, 0);
@@ -286,7 +284,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	COLOR_LABEL_PACK_START(hbox, COL_QUOTE_LEVEL3_BG, _("Background"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_bgcolors, label[COL_QUOTE_LEVEL3_BG]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, TRUE, 0);
 
@@ -298,7 +296,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	COLOR_LABEL_PACK_START(hbox, COL_URI, _("URI link"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, label[COL_URI]);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, TRUE, 0);
 
@@ -316,7 +314,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 			_("Patch messages and attachments"));
 	SET_TOGGLE_SENSITIVITY(checkbtn_enable_colors, frame_diff);
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox4), hbox, FALSE, TRUE, 0);
 
@@ -325,7 +323,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	COLOR_LABEL_PACK_START(hbox, COL_DIFF_ADDED, _("Inserted lines"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox4), hbox, FALSE, FALSE, 0);
 
@@ -335,13 +333,13 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	COLOR_LABEL_PACK_START(hbox, COL_DIFF_DELETED,
 			       _("Removed lines"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox4), hbox, FALSE, FALSE, 0);
 
 	COLOR_BUTTON_PACK_START(hbox, COL_DIFF_HUNK,
 	/* TRANSLATORS: A hunk is a section of the patch indicating how the files differ */
-				C_("Tooltip", "Pick color for hunk lines"));
+				C_("Tooltip.", "Pick color for hunk lines"));
 
 	COLOR_LABEL_PACK_START(hbox, COL_DIFF_HUNK,
 	/* TRANSLATORS: A hunk is a section of the patch indicating how the files differ */
@@ -349,7 +347,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	vbox2 = gtkut_get_options_frame(vbox1, &frame_folder, _("Folder list"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, TRUE, 0);
 
@@ -361,7 +359,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	COLOR_LABEL_PACK_START(hbox, COL_TGT_FOLDER, _("Target folder"));
 
-	hbox = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
 
@@ -373,22 +371,22 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 			       _("Folder containing new messages"));
 
 	/* custom colors */
-	vbox_custom_colors = gtk_vbox_new (FALSE, VSPACING_NARROW);
+	vbox_custom_colors = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_widget_show (vbox_custom_colors);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_custom_colors), VBOX_BORDER);
 	gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook), vbox_custom_colors,
 				 gtk_label_new(_("Color labels")));
 
-	hbox_custom_colors = gtk_hbox_new(FALSE, 8);
+	hbox_custom_colors = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show(hbox_custom_colors);
 	gtk_box_pack_start(GTK_BOX (vbox_custom_colors), hbox_custom_colors,
 				   FALSE, TRUE, 0);
 
-	vbox_custom_colors1 = gtk_vbox_new (FALSE, VSPACING_NARROW);
+	vbox_custom_colors1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_widget_show (vbox_custom_colors1);
 	gtk_box_pack_start (GTK_BOX (hbox_custom_colors), vbox_custom_colors1, FALSE, FALSE, 0);
 
-	vbox_custom_colors2 = gtk_vbox_new (FALSE, VSPACING_NARROW);
+	vbox_custom_colors2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_widget_show (vbox_custom_colors2);
 	gtk_box_pack_start (GTK_BOX (hbox_custom_colors), vbox_custom_colors2, FALSE, FALSE, 0);
 
@@ -401,12 +399,12 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 		   rule name and should not be translated */
 		tooltip_entry_text = g_strdup_printf(_("Set label for 'color %d'"), c+1);
 
-		hbox_custom_color[c] = gtk_hbox_new(FALSE, 8);
+		hbox_custom_color[c] = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show(hbox_custom_color[c]);
 		gtk_box_pack_start(GTK_BOX (vbox_custom_colors1), hbox_custom_color[c],
 				   FALSE, TRUE, 0);
 
-		color_buttons.custom_color[c] = GTKUT_COLOR_BUTTON();
+		color_buttons.custom_color[c] = gtk_button_new_with_label("");
 		gtk_widget_show(color_buttons.custom_color[c]);
   		gtk_box_pack_start(GTK_BOX (hbox_custom_color[c]), color_buttons.custom_color[c],
 				   FALSE, FALSE, 0);
@@ -433,12 +431,12 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 		   rule name and should not be translated */
 		tooltip_entry_text = g_strdup_printf(_("Set label for 'color %d'"), c+1);
 
-		hbox_custom_color[c] = gtk_hbox_new(FALSE, 8);
+		hbox_custom_color[c] = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show(hbox_custom_color[c]);
 		gtk_box_pack_start(GTK_BOX (vbox_custom_colors2), hbox_custom_color[c],
 				   FALSE, TRUE, 0);
 
-		color_buttons.custom_color[c] = GTKUT_COLOR_BUTTON();
+		color_buttons.custom_color[c] = gtk_button_new_with_label("");
 		gtk_widget_show(color_buttons.custom_color[c]);
   		gtk_box_pack_start(GTK_BOX (hbox_custom_color[c]), color_buttons.custom_color[c],
 				   FALSE, FALSE, 0);
@@ -456,7 +454,7 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 		g_free(tooltip_entry_text);
 	}
 
-	hbox_reset_custom_colors = gtk_hbox_new(FALSE, VBOX_BORDER);
+	hbox_reset_custom_colors = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VBOX_BORDER);
 	gtk_widget_show (hbox_reset_custom_colors);
 	gtk_box_pack_start(GTK_BOX (vbox_custom_colors), hbox_reset_custom_colors,
 			   FALSE, FALSE, 0);
@@ -487,14 +485,14 @@ static void prefs_msg_colors_create_widget(PrefsPage *_page, GtkWindow *window,
 	/* program colors */
 	for (c = 0; c < COL_LAST_COLOR_INDEX; c++) {
 		if (color_buttons.color[c] != NULL) {
-			set_button_bg_color(color_buttons.color[c],
-					    prefs_common.color[c]);
+			gtkut_set_button_color(color_buttons.color[c],
+					    &prefs_common.color[c]);
 		}
 	}
 	/* custom colors */
 	for (c = 0; c < COLORLABELS; c++) {
-		set_button_bg_color(color_buttons.custom_color[c],
-				    prefs_common.custom_colorlabel[c].color);
+		gtkut_set_button_color(color_buttons.custom_color[c],
+				    &prefs_common.custom_colorlabel[c].color);
 		gtk_entry_set_text(GTK_ENTRY (entry_custom_colorlabel[c]), 
 				   gettext(SAFE_STRING (prefs_common.custom_colorlabel[c].label)));
 	}
@@ -560,7 +558,7 @@ static void quote_color_set_dialog(GtkWidget *widget, gpointer data)
 	gchar *type = (gchar *)data;
 	gchar *title = NULL;
 	GdkColor color;
-	gint rgbvalue = 0;
+	GdkRGBA rgba;
 	GtkColorSelectionDialog *dialog;
 	GtkWidget *button_ok;
 	GtkWidget *button_cancel;
@@ -574,7 +572,7 @@ static void quote_color_set_dialog(GtkWidget *widget, gpointer data)
 			/* TRANSLATORS: 'color %d' refers to the filtering/processing 
 			   rule name and should not be translated */
 			title = g_strdup_printf(C_("Dialog title", "Pick color for 'color %d'"), c+1);
-			rgbvalue = prefs_common.custom_colorlabel[c].color;
+			rgba = prefs_common.custom_colorlabel[c].color;
 			break;
 		}
 	}
@@ -586,9 +584,9 @@ static void quote_color_set_dialog(GtkWidget *widget, gpointer data)
 		ctype -= COLORLABELS;
 		if (ctype < COL_LAST_COLOR_INDEX) {
 			title = g_strdup(color_dialog_title[ctype]);
-			rgbvalue = prefs_common.color[ctype];
+			rgba = prefs_common.color[ctype];
 		} else {
-			g_warning("unrecognized datatype '%s' in quote_color_set_dialog", type);
+			g_warning("Unrecognized datatype '%s' in quote_color_set_dialog", type);
 			return;
 		}
 	}
@@ -613,7 +611,7 @@ static void quote_color_set_dialog(GtkWidget *widget, gpointer data)
 
 	/* preselect the previous color in the color selection dialog */
 
-	gtkut_convert_int_to_gdk_color(rgbvalue, &color);
+	GTKUT_GDKRGBA_TO_GDKCOLOR(rgba, color);
 
 	dialog = GTK_COLOR_SELECTION_DIALOG(color_dialog);
 	gtk_color_selection_set_current_color
@@ -628,19 +626,19 @@ static void quote_colors_set_dialog_ok(GtkWidget *widget, gpointer data)
 		gtk_color_selection_dialog_get_color_selection
 						((GtkColorSelectionDialog *)color_dialog));
 	GdkColor color;
-	gint rgbvalue;
+	GdkRGBA rgba;
 	gchar *type = (gchar *)data;
 	gint c, ctype;
 
 	gtk_color_selection_get_current_color(colorsel, &color);
-	rgbvalue = gtkut_convert_gdk_color_to_int(&color);
+	GTKUT_GDKCOLOR_TO_GDKRGBA(color, rgba);
 
 	ctype = GPOINTER_TO_INT(type);
 	/* custom colors */
 	for (c = 0; c < COLORLABELS; c++) {
 		if (ctype == c) {
-			prefs_common.custom_colorlabel[c].color = rgbvalue;
-			set_button_bg_color(color_buttons.custom_color[c], rgbvalue);
+			prefs_common.custom_colorlabel[c].color = rgba;
+			gtkut_set_button_color(color_buttons.custom_color[c], &rgba);
 			break;
 		}
 	}
@@ -648,13 +646,13 @@ static void quote_colors_set_dialog_ok(GtkWidget *widget, gpointer data)
 	if (c == COLORLABELS) {
 		ctype -= COLORLABELS;
 		if (ctype < COL_LAST_COLOR_INDEX) {
-			prefs_common.color[ctype] = rgbvalue;
-			set_button_bg_color(color_buttons.color[ctype], rgbvalue);
+			prefs_common.color[ctype] = rgba;
+			gtkut_set_button_color(color_buttons.color[ctype], &rgba);
 			if (ctype == COL_TGT_FOLDER) {
 				folderview_set_target_folder_color(prefs_common.color[ctype]);
 			}
 		} else {
-			g_warning("unrecognized datatype '%s' in quote_color_set_dialog_ok", type);
+			g_warning("Unrecognized datatype '%s' in quote_color_set_dialog_ok", type);
 		}
 	}
 
@@ -699,21 +697,6 @@ static gboolean quote_colors_set_dialog_key_pressed(GtkWidget *widget,
 	return FALSE;
 }
 
-static void set_button_bg_color(GtkWidget *widget, gint rgbvalue)
-{
-	GtkStyle *newstyle;
-	GdkColor color;
-
-	gtkut_convert_int_to_gdk_color(rgbvalue, &color);
-	newstyle = gtk_style_copy(gtk_widget_get_default_style());
-	newstyle->bg[GTK_STATE_NORMAL]   = color;
-	newstyle->bg[GTK_STATE_PRELIGHT] = color;
-	newstyle->bg[GTK_STATE_ACTIVE]   = color;
-
-	gtk_widget_set_style(GTK_WIDGET(widget), newstyle);
-	g_object_unref(newstyle);
-}
-
 static void prefs_msg_colors_save(PrefsPage *_page)
 {
 	MsgColorsPage *page = (MsgColorsPage *) _page;
@@ -740,26 +723,19 @@ static void prefs_msg_colors_save(PrefsPage *_page)
 
 static void prefs_msg_colors_reset_custom_colors(GtkWidget *widget, gpointer data)
 {
-#define CL(x)		(((gulong) (x) >> (gulong) 8) & 0xFFUL)	
-#define CR(r, g, b)	((CL(r) << (gulong) 16) | \
-			 (CL(g) << (gulong)  8) | \
-			 (CL(b)))
 	MsgColorsPage *page = (MsgColorsPage *) data;
-	GdkColor color;
+	GdkRGBA rgba;
 	gint c;
 
 	for (c = 0; c < COLORLABELS; c++) {
-		color = colorlabel_get_default_color(c);
-		prefs_common.custom_colorlabel[c].color =
-							(gint)CR(color.red, color.green, color.blue);
-		set_button_bg_color(color_buttons.custom_color[c],
-							prefs_common.custom_colorlabel[c].color);
+		rgba = colorlabel_get_default_color(c);
+		prefs_common.custom_colorlabel[c].color = rgba;
+		gtkut_set_button_color(color_buttons.custom_color[c],
+							&prefs_common.custom_colorlabel[c].color);
 		gtk_entry_set_text(GTK_ENTRY (page->entry_custom_colorlabel[c]),
 							gettext(SAFE_STRING (colorlabel_get_color_default_text(c))));
 	}
 
-#undef CR
-#undef CL
 }
 
 static void prefs_msg_colors_destroy_widget(PrefsPage *_page)
