@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2023 the Claws Mail Team and Colin Leroy
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 2005-2019 Colin Leroy and The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "foldersel.h"
+#ifdef G_OS_WIN32
+#  include <w32lib.h>
+#endif
+
 #include "prefs_common.h"
 #include "prefs_gtk.h"
 #include "prefs_summary_open.h"
@@ -60,9 +63,6 @@ typedef struct _SummariesPage
 	GtkWidget *entry_datefmt;
 
 	GtkWidget *checkbtn_reopen_last_folder;
-	GtkWidget *checkbtn_startup_folder;
-	GtkWidget *startup_folder_entry;
-	GtkWidget *startup_folder_select;
 	GtkWidget *checkbtn_always_show_msg;
 	GtkWidget *checkbtn_show_on_folder_open;
 	GtkWidget *checkbtn_show_on_search_results;
@@ -73,7 +73,6 @@ typedef struct _SummariesPage
 	GtkWidget *spinbtn_mark_as_read_delay;
 	GtkWidget *checkbtn_immedexec;
 	GtkWidget *checkbtn_ask_mark_all_read;
-	GtkWidget *checkbtn_run_processingrules_mark_all_read;
 	GtkWidget *checkbtn_ask_override_colorlabel;
   	GtkWidget *optmenu_sort_key;
   	GtkWidget *optmenu_sort_type;
@@ -115,41 +114,6 @@ static void mark_as_read_toggled		(GtkToggleButton *button,
 static void always_show_msg_toggled		(GtkToggleButton *button,
 						 gpointer user_data);
 
-static void reopen_last_folder_toggled(GtkToggleButton *toggle_btn, GtkWidget *widget)
-{
-	gboolean is_active;
-
-	is_active = gtk_toggle_button_get_active(toggle_btn);
-	gtk_widget_set_sensitive(widget, !is_active);
-	if (is_active)
-		prefs_common.goto_folder_on_startup = FALSE;
-}
-
-static void startup_folder_toggled(GtkToggleButton *toggle_btn, GtkWidget *widget)
-{
-	gboolean is_active;
-
-	is_active = gtk_toggle_button_get_active(toggle_btn);
-	gtk_widget_set_sensitive(widget, !is_active);
-	if (is_active)
-		prefs_common.goto_last_folder_on_startup = FALSE;
-}
-
-static void foldersel_cb(GtkWidget *widget, gpointer data)
-{
-	GtkWidget *entry = (GtkWidget *) data;
-	FolderItem *item;
-	gchar *item_id;
-	gint newpos = 0;
-	
-	item = foldersel_folder_sel(NULL, FOLDER_SEL_ALL, NULL, FALSE, NULL);
-	if (item && (item_id = folder_item_get_identifier(item)) != NULL) {
-		gtk_editable_delete_text(GTK_EDITABLE(entry), 0, -1);
-		gtk_editable_insert_text(GTK_EDITABLE(entry), item_id, strlen(item_id), &newpos);
-		g_free(item_id);
-	}
-}
-
 static GtkWidget *date_format_create(GtkButton *button, void *data)
 {
 	static GtkWidget *datefmt_win = NULL;
@@ -244,7 +208,7 @@ static GtkWidget *date_format_create(GtkButton *button, void *data)
 	gtk_window_set_type_hint(GTK_WINDOW(datefmt_win), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_widget_set_size_request(datefmt_win, 440, 280);
 
-	vbox1 = gtk_vbox_new(FALSE, 10);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
 	gtk_widget_show(vbox1);
 	gtk_container_add(GTK_CONTAINER(datefmt_win), vbox1);
 
@@ -282,24 +246,24 @@ static GtkWidget *date_format_create(GtkButton *button, void *data)
 			 G_CALLBACK(date_format_select_row),
 			 datefmt_win);
 	
-	table = gtk_table_new(2, 2, FALSE);
+	table = gtk_grid_new();
 	gtk_widget_show(table);
 	gtk_box_pack_start(GTK_BOX(vbox1), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 4);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 
 	label1 = gtk_label_new(_("Date format"));
 	gtk_widget_show(label1);
-	gtk_table_attach(GTK_TABLE(table), label1, 0, 1, 0, 1,
-			 GTK_FILL, 0, 0, 0);
 	gtk_label_set_justify(GTK_LABEL(label1), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment(GTK_MISC(label1), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label1), 0.0);
+	gtk_grid_attach(GTK_GRID(table), label1, 0, 0, 1, 1);
 
 	datefmt_entry = gtk_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(datefmt_entry), 256);
 	gtk_widget_show(datefmt_entry);
-	gtk_table_attach(GTK_TABLE(table), datefmt_entry, 1, 2, 0, 1,
-			 (GTK_EXPAND | GTK_FILL), 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), datefmt_entry, 1, 0, 1, 1);
+	gtk_widget_set_hexpand(datefmt_entry, TRUE);
+	gtk_widget_set_halign(datefmt_entry, GTK_ALIGN_FILL);
 
 	/* we need the "sample" entry box; add it as data so callbacks can
 	 * get the entry box */
@@ -308,20 +272,20 @@ static GtkWidget *date_format_create(GtkButton *button, void *data)
 
 	label2 = gtk_label_new(_("Example"));
 	gtk_widget_show(label2);
-	gtk_table_attach(GTK_TABLE(table), label2, 0, 1, 1, 2,
-			 GTK_FILL, 0, 0, 0);
 	gtk_label_set_justify(GTK_LABEL(label2), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment(GTK_MISC(label2), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label2), 0.0);
+	gtk_grid_attach(GTK_GRID(table), label2, 0, 1, 1, 1);
 
 	label3 = gtk_label_new("");
 	gtk_widget_show(label3);
-	gtk_table_attach(GTK_TABLE(table), label3, 1, 2, 1, 2,
-			 (GTK_EXPAND | GTK_FILL), 0, 0, 0);
 	gtk_label_set_justify(GTK_LABEL(label3), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment(GTK_MISC(label3), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label3), 0.0);
+	gtk_grid_attach(GTK_GRID(table), label3, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(label3, TRUE);
+	gtk_widget_set_halign(label3, GTK_ALIGN_FILL);
 
-	gtkut_stock_button_set_create(&confirm_area, &cancel_btn, GTK_STOCK_CANCEL,
-				      &ok_btn, GTK_STOCK_OK, NULL, NULL);
+	gtkut_stock_button_set_create(&confirm_area, &cancel_btn, _("_Cancel"),
+				      &ok_btn, _("_OK"), NULL, NULL);
 
 	gtk_box_pack_start(GTK_BOX(vbox1), confirm_area, FALSE, FALSE, 0);
 	gtk_widget_show(confirm_area);
@@ -378,9 +342,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *entry_datefmt;
 	GtkWidget *button_dispitem;
 	GtkWidget *checkbtn_reopen_last_folder;
-	GtkWidget *checkbtn_startup_folder;
-	GtkWidget *startup_folder_entry;
-	GtkWidget *startup_folder_select;
 	GtkWidget *checkbtn_always_show_msg;
 	GtkWidget *checkbtn_show_on_folder_open;
 	GtkWidget *checkbtn_show_on_search_results;
@@ -391,7 +352,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkAdjustment *spinbtn_mark_as_read_delay_adj;
 	GtkWidget *checkbtn_immedexec;
 	GtkWidget *checkbtn_ask_mark_all_read;
-	GtkWidget *checkbtn_run_processingrules_mark_all_read;
 	GtkWidget *checkbtn_ask_override_colorlabel;
 	GtkWidget *label, *label_fill;
 	GtkListStore *menu;
@@ -413,27 +373,27 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	notebook = gtk_notebook_new();
 	gtk_widget_show(notebook);
 
-	vbox1 = gtk_vbox_new (FALSE, VSPACING);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox1,
 				 gtk_label_new(_("Folder list")));
 	
-	hbox0 = gtk_hbox_new (FALSE, 8);
+	hbox0 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox0, FALSE, TRUE, 0);
 
 	label = gtk_label_new(_("Displayed columns"));
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox0), label, FALSE, FALSE, 0);
-	button_dispitem = gtk_button_new_from_stock(GTK_STOCK_EDIT);
+	button_dispitem = gtk_button_new_with_mnemonic("_Edit");
 	gtk_widget_show (button_dispitem);
 	gtk_box_pack_start (GTK_BOX (hbox0), button_dispitem, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (button_dispitem), "clicked",
 			  G_CALLBACK (prefs_folder_column_open),
 			  NULL);
 
-	hbox0 = gtk_hbox_new (FALSE, 8);
+	hbox0 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox0);
 	gtk_box_pack_start(GTK_BOX (vbox1), hbox0, FALSE, FALSE, 0);
 
@@ -456,36 +416,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 		(vbox1, checkbtn_reopen_last_folder,
 		 _("Open last opened folder at start-up"));
 
-	hbox0 = gtk_hbox_new(FALSE, 8);
-	gtk_widget_show(hbox0);
-	gtk_box_pack_start(GTK_BOX(vbox1), hbox0, FALSE, FALSE, 0);
-
-	PACK_CHECK_BUTTON
-		(hbox0, checkbtn_startup_folder,
-		 _("Open selected folder at start-up"));
-
-	startup_folder_entry = gtk_entry_new();
-	gtk_widget_show(startup_folder_entry);
-	gtk_box_pack_start(GTK_BOX(hbox0), startup_folder_entry, TRUE, TRUE, 0);
-	startup_folder_select = gtkut_get_browse_directory_btn(_("_Browse"));
-	gtk_widget_show(startup_folder_select);
-	gtk_box_pack_start(GTK_BOX(hbox0), startup_folder_select, FALSE, FALSE, 0);
-
-	SET_TOGGLE_SENSITIVITY(checkbtn_startup_folder, startup_folder_entry)
-	SET_TOGGLE_SENSITIVITY(checkbtn_startup_folder, startup_folder_select)
-
-	g_signal_connect(G_OBJECT(checkbtn_reopen_last_folder), "toggled",
-			 G_CALLBACK(reopen_last_folder_toggled), checkbtn_startup_folder);
-	g_signal_connect(G_OBJECT(checkbtn_startup_folder), "toggled",
-			 G_CALLBACK(startup_folder_toggled), checkbtn_reopen_last_folder);
-	g_signal_connect(G_OBJECT(startup_folder_select), "clicked",
-			 G_CALLBACK(foldersel_cb), startup_folder_entry);
-
-	PACK_CHECK_BUTTON
-		(vbox1, checkbtn_run_processingrules_mark_all_read,
-		 _("Run processing rules before marking all messages in a folder as read or unread"));
-
-	hbox1 = gtk_hbox_new (FALSE, 8);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start(GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
@@ -507,20 +438,20 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_show (label_ng_abbrev);
 	gtk_box_pack_start (GTK_BOX (hbox1), label_ng_abbrev, FALSE, FALSE, 0);
 
-	vbox1 = gtk_vbox_new (FALSE, VSPACING);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox1,
 				 gtk_label_new(_("Message list")));
 
-	hbox0 = gtk_hbox_new (FALSE, 8);
+	hbox0 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox0, FALSE, TRUE, 0);
 	
 	label = gtk_label_new(_("Displayed columns"));
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox0), label, FALSE, FALSE, 0);
-	button_dispitem = gtk_button_new_from_stock(GTK_STOCK_EDIT);
+	button_dispitem = gtk_button_new_with_mnemonic("_Edit");
 	gtk_widget_show (button_dispitem);
 	gtk_box_pack_start (GTK_BOX (hbox0), button_dispitem, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (button_dispitem), "clicked",
@@ -530,7 +461,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	PACK_SPACER(hbox0, hbox1, 4);
 	PACK_CHECK_BUTTON(hbox0, checkbtn_summary_col_lock, _("Lock column headers"));
 
-	hbox1 = gtk_hbox_new (FALSE, 10);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
@@ -548,7 +479,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	COMBOBOX_ADD (menu, _("Name and Address"), SHOW_BOTH);
 
 	gtk_box_pack_start(GTK_BOX(hbox1), optmenu_summaryfromshow, FALSE, FALSE, 0);
-	hbox2 = gtk_hbox_new (FALSE, 8);
+	hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, TRUE, 0);
 
@@ -560,7 +491,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_show (entry_datefmt);
 	gtk_box_pack_start (GTK_BOX (hbox2), entry_datefmt, FALSE, FALSE, 0);
 
-	button_datefmt = gtk_button_new_from_stock(GTK_STOCK_INFO);
+	button_datefmt = gtkut_stock_button("dialog-information");
 
 	gtk_widget_show (button_datefmt);
 	gtk_box_pack_start (GTK_BOX (hbox2), button_datefmt, FALSE, FALSE, 0);
@@ -573,7 +504,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	CLAWS_SET_TIP(button_datefmt,
 			     _("Date format help"));
 
-	hbox1 = gtk_hbox_new (FALSE, 10);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, TRUE, 0);
 
@@ -606,7 +537,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	radio_mark_as_read_on_select = gtk_radio_button_new_with_label(NULL,
 			_("when selected, after"));
 
-	hbox1 = gtk_hbox_new (FALSE, 8);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_box_pack_start (GTK_BOX (hbox1), radio_mark_as_read_on_select, FALSE, FALSE, 0);
 
 	spinbtn_mark_as_read_delay_adj = GTK_ADJUSTMENT(gtk_adjustment_new (0, 0, 60, 1, 10, 0));
@@ -629,7 +560,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_show_all(vbox3);
 
 	/* Next Unread Message Dialog */
-	hbox1 = gtk_hbox_new (FALSE, 10);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
@@ -674,11 +605,11 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 		(vbox1, checkbtn_show_tooltips,
 		 _("Show tooltips"));
 
-	hbox2 = gtk_hbox_new (FALSE, 8);
+	hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
 
-	vbox1 = gtk_vbox_new (FALSE, VSPACING);
+	vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox1,
@@ -686,7 +617,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	vbox2 = gtkut_get_options_frame(vbox1, &frame_new_folders, _("New folders"));
 
-	hbox1 = gtk_hbox_new(FALSE, 10);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
 	gtk_widget_show(hbox1);
 	gtk_box_pack_start(GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);
 
@@ -748,8 +679,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_summaries->checkbtn_threadsubj = checkbtn_threadsubj;
 	prefs_summaries->entry_datefmt = entry_datefmt;
 	prefs_summaries->checkbtn_reopen_last_folder = checkbtn_reopen_last_folder;
-	prefs_summaries->checkbtn_startup_folder = checkbtn_startup_folder;
-	prefs_summaries->startup_folder_entry = startup_folder_entry;
 
 	prefs_summaries->checkbtn_always_show_msg = checkbtn_always_show_msg;
 	prefs_summaries->checkbtn_show_on_folder_open = checkbtn_show_on_folder_open;
@@ -762,7 +691,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_summaries->spinbtn_mark_as_read_delay = spinbtn_mark_as_read_delay;
 	prefs_summaries->checkbtn_immedexec = checkbtn_immedexec;
 	prefs_summaries->checkbtn_ask_mark_all_read = checkbtn_ask_mark_all_read;
-	prefs_summaries->checkbtn_run_processingrules_mark_all_read = checkbtn_run_processingrules_mark_all_read;
 	prefs_summaries->checkbtn_ask_override_colorlabel = checkbtn_ask_override_colorlabel;
 	prefs_summaries->optmenu_sort_key = optmenu_sort_key;
 	prefs_summaries->optmenu_sort_type = optmenu_sort_type;
@@ -800,10 +728,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 			prefs_common.date_format?prefs_common.date_format:"");	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_reopen_last_folder),
 			prefs_common.goto_last_folder_on_startup);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_startup_folder),
-			prefs_common.goto_folder_on_startup);
-	gtk_entry_set_text(GTK_ENTRY(startup_folder_entry),
-			   prefs_common.startup_folder?prefs_common.startup_folder:"");
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_always_show_msg),
 			prefs_common.always_show_msg);
@@ -826,8 +750,6 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 			prefs_common.immediate_exec);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_ask_mark_all_read),
 			prefs_common.ask_mark_all_read);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_run_processingrules_mark_all_read),
-			prefs_common.run_processingrules_before_mark_all);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_ask_override_colorlabel),
 			prefs_common.ask_override_colorlabel);
 
@@ -882,10 +804,6 @@ static void prefs_summaries_save(PrefsPage *_page)
 
 	prefs_common.goto_last_folder_on_startup = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_reopen_last_folder));
-	prefs_common.goto_folder_on_startup = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_startup_folder));
-	prefs_common.startup_folder = gtk_editable_get_chars(
-			GTK_EDITABLE(page->startup_folder_entry), 0, -1);
 
 	prefs_common.always_show_msg = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_always_show_msg));
@@ -906,8 +824,6 @@ static void prefs_summaries_save(PrefsPage *_page)
 		GTK_TOGGLE_BUTTON(page->checkbtn_immedexec));
 	prefs_common.ask_mark_all_read = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_ask_mark_all_read));
-	prefs_common.run_processingrules_before_mark_all = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_run_processingrules_mark_all_read));
 	prefs_common.ask_override_colorlabel = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_ask_override_colorlabel));
 	prefs_common.mark_as_read_delay = gtk_spin_button_get_value_as_int(
