@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2017 Hiroyuki Yamamoto & the Claws Mail team
+ * Copyright (C) 2002-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -156,7 +156,6 @@ static const gint ToolbarIcons[] =
 	STOCK_PIXMAP_MARK_ALLUNREAD,
 	STOCK_PIXMAP_MARK_READ,
 	STOCK_PIXMAP_MARK_UNREAD,
-	STOCK_PIXMAP_DIR_OPEN,
 	STOCK_PIXMAP_EMPTY,              /* last entry */
 };
 
@@ -891,31 +890,30 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 
 	debug_print("Creating custom toolbar window...\n");
 
-	main_vbox = gtk_vbox_new(FALSE, 0);
+	main_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(main_vbox);
 
 	PACK_FRAME (main_vbox, vbox_frame, _("Toolbar item"))
 	gtk_container_set_border_width(GTK_CONTAINER(vbox_frame), 8);
 	gtk_widget_show(vbox_frame);
 
-	toolbar_item_hbox = gtk_hbox_new (FALSE, 4);
+	toolbar_item_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_widget_show(toolbar_item_hbox);
 	gtk_container_add(GTK_CONTAINER (vbox_frame), toolbar_item_hbox);
 
-	table = gtk_table_new (3, 3, FALSE);
+	table = gtk_grid_new();
+	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 8);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
+
 	gtk_box_pack_start(GTK_BOX(toolbar_item_hbox), table,
 			   TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
 	/* toolbar item type */
 	label = gtk_label_new(_("Item type"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), label, 0, 0, 1, 1);
 
 	item_type_combo = gtkut_sc_combobox_create(NULL, TRUE);
 	item_type_model = GTK_LIST_STORE(gtk_combo_box_get_model(
@@ -925,58 +923,46 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 	COMBOBOX_ADD(item_type_model, _("Plugins"), ITEM_PLUGIN);
 	COMBOBOX_ADD(item_type_model, _("Separator"), ITEM_SEPARATOR);
 	gtk_widget_set_size_request(item_type_combo, 200, -1);
-	gtk_table_attach(GTK_TABLE(table), item_type_combo, 1, 3, 0, 1,
-			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), item_type_combo, 1, 0, 1, 1);
 
 	/* available actions */
 	label = gtk_label_new(_("Event executed on click"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-			  (GtkAttachOptions) (GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
+	gtk_grid_attach(GTK_GRID(table), label, 0, 1, 1, 1);
 
 	item_action_combo = gtk_combo_box_text_new();
 	gtk_widget_set_size_request(item_action_combo, 200, -1);
-	gtk_table_attach (GTK_TABLE (table), item_action_combo, 1, 3, 1, 2,
-			  (GtkAttachOptions) (GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), item_action_combo, 1, 1, 1, 1);
 
 	/* available internal functions */
 	item_func_combo = gtk_combo_box_text_new();
 	gtk_widget_set_size_request(item_func_combo, 200, -1);
-	gtk_table_attach (GTK_TABLE (table), item_func_combo, 1, 3, 1, 2,
-			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), item_func_combo, 1, 1, 1, 1);
 
 	/* plugin-registered items */
 	item_plugin_combo = gtk_combo_box_text_new();
 	gtk_widget_set_size_request(item_plugin_combo, 200, -1);
-	gtk_table_attach(GTK_TABLE(table), item_plugin_combo, 1, 3, 1, 2,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), item_plugin_combo, 1, 1, 1, 1);
 
 	/* toolbar item description */
 	label_icon_text = gtk_label_new(_("Toolbar text"));
-	gtk_misc_set_alignment(GTK_MISC(label_icon_text), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label_icon_text), 0.0);
 	gtk_widget_show (label_icon_text);
-	gtk_table_attach (GTK_TABLE (table), label_icon_text, 0, 1, 2, 3,
-			  (GtkAttachOptions) (GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), label_icon_text, 0, 2, 1, 1);
 
 	item_text_entry = gtk_entry_new();
-	gtk_table_attach (GTK_TABLE (table), item_text_entry, 1, 3, 2, 3,
-			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			  (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach(GTK_GRID(table), item_text_entry, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(item_text_entry, TRUE);
+	gtk_widget_set_halign(item_text_entry, GTK_ALIGN_FILL);
 
-	icon_vbox = gtk_vbox_new(FALSE, VBOX_BORDER);
+	icon_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_widget_show(icon_vbox);
 
 	icon_label = gtk_label_new(_("Icon"));
 	gtk_widget_set_size_request(icon_label, 100, -1);
 	gtk_box_pack_start(GTK_BOX(icon_vbox), icon_label, FALSE, FALSE, 0);
 
-	icon_hbox = gtk_hbox_new(FALSE, 0);
+	icon_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show(icon_hbox);
 
 	label = gtk_label_new("");
@@ -997,20 +983,18 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 	gtk_box_pack_start(GTK_BOX(toolbar_item_hbox), icon_vbox, FALSE, FALSE, 0);
 
 	/* register / substitute / delete */
-	reg_hbox = gtk_hbox_new(FALSE, 4);
+	reg_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start(GTK_BOX(main_vbox), reg_hbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(reg_hbox), 10);
 
-	arrow = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+	arrow = gtk_image_new_from_icon_name("pan-down-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start(GTK_BOX(reg_hbox), arrow, FALSE, FALSE, 0);
 	gtk_widget_set_size_request(arrow, -1, 16);
 
-	btn_hbox = gtk_hbox_new(TRUE, 4);
+	btn_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start(GTK_BOX(reg_hbox), btn_hbox, FALSE, FALSE, 0);
 
-	reg_btn = gtk_button_new_with_mnemonic (_("A_dd"));
-	gtk_button_set_image(GTK_BUTTON(reg_btn),
-			gtk_image_new_from_stock(GTK_STOCK_ADD,GTK_ICON_SIZE_BUTTON));
+	reg_btn = gtkut_stock_button("list-add");
 	gtk_box_pack_start(GTK_BOX(btn_hbox), reg_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(reg_btn), "clicked",
 			 G_CALLBACK(prefs_toolbar_register),
@@ -1022,9 +1006,7 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 			 G_CALLBACK(prefs_toolbar_substitute),
 			 prefs_toolbar);
 
-	del_btn = gtk_button_new_with_mnemonic (_("D_elete"));
-	gtk_button_set_image(GTK_BUTTON(del_btn),
-			gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_BUTTON));
+	del_btn = gtkut_stock_button("edit-delete");
 	gtk_box_pack_start(GTK_BOX(btn_hbox), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(del_btn), "clicked",
 			 G_CALLBACK(prefs_toolbar_delete),
@@ -1034,7 +1016,7 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 #ifndef GENERIC_UMPC
 	gtk_box_pack_end(GTK_BOX(reg_hbox), default_btn, FALSE, TRUE, 0);
 #else
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), default_btn, FALSE, FALSE, 0);
 #endif
@@ -1043,34 +1025,36 @@ static void prefs_toolbar_create(ToolbarPage *prefs_toolbar)
 			 prefs_toolbar);
 
 	/* currently active toolbar items */
-	vbox_toolbar_items = gtk_vbox_new(FALSE, VBOX_BORDER);
+	vbox_toolbar_items = gtk_box_new(GTK_ORIENTATION_VERTICAL, VBOX_BORDER);
 	gtk_box_pack_start(GTK_BOX(main_vbox), vbox_toolbar_items, TRUE, TRUE, 0);
 
-	hbox_bottom = gtk_hbox_new(FALSE, 0);
+	hbox_bottom = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_add(GTK_CONTAINER(vbox_toolbar_items), hbox_bottom);
 
 	scrolledwindow_list_view_set = gtk_scrolled_window_new(NULL, NULL);
 	gtk_box_pack_start(GTK_BOX(hbox_bottom), scrolledwindow_list_view_set, TRUE, TRUE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(scrolledwindow_list_view_set), 8);
+	gtk_container_set_border_width(GTK_CONTAINER(scrolledwindow_list_view_set), 8);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow_list_view_set),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwindow_list_view_set),
 					    GTK_SHADOW_IN);
+	gtk_scrolled_window_set_propagate_natural_height(GTK_SCROLLED_WINDOW(scrolledwindow_list_view_set), TRUE);
 
 	list_view_set = create_set_list_view(prefs_toolbar);
 	gtk_widget_show(list_view_set);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_list_view_set), list_view_set);
-	gtk_widget_set_size_request(list_view_set, 225, 120);
+	gtk_widget_set_vexpand(list_view_set, TRUE);
+	gtk_widget_set_hexpand(list_view_set, TRUE);
 
-	btn_vbox = gtk_vbox_new(FALSE, 0);
+	btn_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show(btn_vbox);
 	gtk_box_pack_start(GTK_BOX(hbox_bottom), btn_vbox, FALSE, FALSE, 0);
 
-	up_btn = gtk_button_new_from_stock(GTK_STOCK_GO_UP);
+	up_btn = gtkut_stock_button("go-up");
 	gtk_widget_show(up_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), up_btn, FALSE, FALSE, 4);
 
-	down_btn = gtk_button_new_from_stock(GTK_STOCK_GO_DOWN);
+	down_btn = gtkut_stock_button("go-down");
 	gtk_widget_show(down_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), down_btn, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(btn_vbox), 8);
@@ -1319,14 +1303,13 @@ static void set_visible_if_not_text(GtkTreeViewColumn *col,
 		gtk_tree_model_get(model, iter,
 				   SET_ICON, &pixbuf,
 				   -1);
-		/* note: getting a pixbuf from a tree model increases
+		/* note getting a pixbuf from a tree model increases
 		 * its refcount ... */
+		if (pixbuf != NULL)
+			g_object_unref(pixbuf);
 
 		g_object_set(renderer, "visible", TRUE, NULL);
 		g_object_set(renderer, "pixbuf",  pixbuf, NULL);
-
-		if (pixbuf != NULL)
-			g_object_unref(pixbuf);
 	}
 }
 
@@ -1711,6 +1694,7 @@ static void icon_chooser_create(GtkButton *button, ToolbarPage *prefs_toolbar)
 				GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrollwin),
 				GTK_SHADOW_OUT);
+	gtk_scrolled_window_set_propagate_natural_height(GTK_SCROLLED_WINDOW(scrollwin), TRUE);
 
 	icon_view = gtk_icon_view_new_with_model(GTK_TREE_MODEL(store));
 	gtk_icon_view_set_selection_mode(GTK_ICON_VIEW(icon_view), GTK_SELECTION_SINGLE);
