@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -126,7 +125,7 @@ static void quote_fmt_add_buttons(GtkWindow* parent_window, GtkWidget *parent_bo
 	if (!add_info_button && !set_defaults_func)
 		return;
 	
-	hbox_btns = gtk_hbox_new(FALSE, 0);
+	hbox_btns = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_end (GTK_BOX(parent_box), hbox_btns, FALSE, TRUE, 0);	
 
 	if (add_info_button)
@@ -173,18 +172,18 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 		PACK_CHECK_BUTTON (parent_box, checkbtn_use_format, 
 				   _("Use template when composing new messages"));
 
-	vbox_format = gtk_vbox_new (FALSE, 4);
+	vbox_format = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show(vbox_format);
 	gtk_container_add(GTK_CONTAINER (parent_box), vbox_format);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_format), 8);
 
 	if (override_from_format) {
-		hbox2_format = gtk_hbox_new (FALSE, 8);
+		hbox2_format = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show (hbox2_format);
 		gtk_box_pack_start (GTK_BOX (vbox_format), hbox2_format, FALSE, FALSE, 0);
 
 		label_from = gtk_label_new (prefs_common_translated_header_name("From"));
-		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
+		gtk_label_set_xalign(GTK_LABEL(label_from), 1.0);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox2_format), label_from, FALSE, FALSE, 0);
 		gtk_size_group_add_widget(size_group, label_from);
@@ -197,12 +196,12 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 				_("Override From header. This doesn't change the account used to compose the new message."));
 	}
 
-	hbox_format = gtk_hbox_new (FALSE, 8);
+	hbox_format = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox_format);
 	gtk_box_pack_start (GTK_BOX (vbox_format), hbox_format, FALSE, FALSE, 0);
 
 	label_subject = gtk_label_new (prefs_common_translated_header_name("Subject"));
-	gtk_misc_set_alignment(GTK_MISC(label_subject), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label_subject), 1.0);
 	gtk_widget_show (label_subject);
 	gtk_box_pack_start (GTK_BOX (hbox_format), label_subject, FALSE, FALSE, 0);
 	gtk_size_group_add_widget(size_group, label_subject);
@@ -220,6 +219,7 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 		 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type
 		(GTK_SCROLLED_WINDOW (scrolledwin_format), GTK_SHADOW_IN);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrolledwin_format), 260);
 
 	text_format = gtk_text_view_new ();
 	if (prefs_common.textfont) {
@@ -228,7 +228,7 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 		font_desc = pango_font_description_from_string
 						(prefs_common.textfont);
 		if (font_desc) {
-			gtk_widget_modify_font(text_format, font_desc);
+			gtk_widget_override_font(text_format, font_desc);
 			pango_font_description_free(font_desc);
 		}
 	}
@@ -296,18 +296,18 @@ void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 		PACK_CHECK_BUTTON (parent_box, checkbtn_use_format,
 				   _("Use template when replying to messages"));
 
-	vbox_quote = gtk_vbox_new (FALSE, 4);
+	vbox_quote = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show(vbox_quote);
 	gtk_container_add(GTK_CONTAINER (parent_box), vbox_quote);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_quote), 8);
 
 	if (override_from_format) {
-		hbox3 = gtk_hbox_new (FALSE, 8);
+		hbox3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show (hbox3);
 		gtk_box_pack_start (GTK_BOX (vbox_quote), hbox3, FALSE, FALSE, 0);
 
 		label_from = gtk_label_new (prefs_common_translated_header_name("From:"));
-		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
+		gtk_label_set_xalign(GTK_LABEL(label_from), 1.0);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox3), label_from, FALSE, FALSE, 0);
 		gtk_size_group_add_widget(size_group, label_from);
@@ -320,16 +320,16 @@ void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 				_("Override From header. This doesn't change the account used to reply."));
 	}
 
-	hbox1 = gtk_hbox_new (FALSE, 32);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 32);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox_quote), hbox1, FALSE, FALSE, 0);
 
-	hbox2 = gtk_hbox_new (FALSE, 8);
+	hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (hbox1), hbox2, FALSE, FALSE, 0);
 
 	label_quotemark = gtk_label_new (_("Quotation mark"));
-	gtk_misc_set_alignment(GTK_MISC(label_quotemark), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label_quotemark), 1.0);
 	gtk_widget_show (label_quotemark);
 	gtk_box_pack_start (GTK_BOX (hbox2), label_quotemark, FALSE, FALSE, 0);
 	gtk_size_group_add_widget(size_group, label_quotemark);
@@ -348,6 +348,7 @@ void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 		 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type
 		(GTK_SCROLLED_WINDOW (scrolledwin_quotefmt), GTK_SHADOW_IN);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrolledwin_quotefmt), 260);
 
 	text_quotefmt = gtk_text_view_new ();
 	if (prefs_common.textfont) {
@@ -356,7 +357,7 @@ void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 		font_desc = pango_font_description_from_string
 						(prefs_common.textfont);
 		if (font_desc) {
-			gtk_widget_modify_font(text_quotefmt, font_desc);
+			gtk_widget_override_font(text_quotefmt, font_desc);
 			pango_font_description_free(font_desc);
 		}
 	}
@@ -424,18 +425,18 @@ void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 		PACK_CHECK_BUTTON (parent_box, checkbtn_use_format,
 				   _("Use template when forwarding messages"));
 
-	vbox_quote = gtk_vbox_new (FALSE, 4);
+	vbox_quote = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	gtk_widget_show(vbox_quote);
 	gtk_container_add(GTK_CONTAINER (parent_box), vbox_quote);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_quote), 8);
 
 	if (override_from_format) {
-		hbox3 = gtk_hbox_new (FALSE, 8);
+		hbox3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 		gtk_widget_show (hbox3);
 		gtk_box_pack_start (GTK_BOX (vbox_quote), hbox3, FALSE, FALSE, 0);
 
 		label_from = gtk_label_new (prefs_common_translated_header_name("From:"));
-		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
+		gtk_label_set_xalign(GTK_LABEL(label_from), 1.0);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox3), label_from, FALSE, FALSE, 0);
 		gtk_size_group_add_widget(size_group, label_from);
@@ -448,16 +449,16 @@ void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 				_("Override From header. This doesn't change the account used to forward."));
 	}
 
-	hbox1 = gtk_hbox_new (FALSE, 32);
+	hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 32);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox_quote), hbox1, FALSE, FALSE, 0);
 
-	hbox2 = gtk_hbox_new (FALSE, 8);
+	hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (hbox1), hbox2, FALSE, FALSE, 0);
 
 	label_quotemark = gtk_label_new (_("Quotation mark"));
-	gtk_misc_set_alignment(GTK_MISC(label_quotemark), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label_quotemark), 1.0);
 	gtk_widget_show (label_quotemark);
 	gtk_box_pack_start (GTK_BOX (hbox2), label_quotemark, FALSE, FALSE, 0);
 	gtk_size_group_add_widget(size_group, label_quotemark);
@@ -477,6 +478,7 @@ void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 		 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type
 		(GTK_SCROLLED_WINDOW (scrolledwin_quotefmt), GTK_SHADOW_IN);
+	gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrolledwin_quotefmt), 260);
 
 	text_fw_quotefmt = gtk_text_view_new ();
 	if (prefs_common.textfont) {
@@ -485,7 +487,7 @@ void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 		font_desc = pango_font_description_from_string
 						(prefs_common.textfont);
 		if (font_desc) {
-			gtk_widget_modify_font(text_fw_quotefmt, font_desc);
+			gtk_widget_override_font(text_fw_quotefmt, font_desc);
 			pango_font_description_free(font_desc);
 		}
 	}
@@ -521,7 +523,7 @@ void quotefmt_add_info_button(GtkWindow *parent_window, GtkWidget *parent_box)
 {
 	GtkWidget *btn_formatdesc;
 
-	btn_formatdesc = gtk_button_new_from_stock(GTK_STOCK_INFO);
+	btn_formatdesc = gtkut_stock_button("dialog-information");
 	gtk_widget_show (btn_formatdesc);
 	gtk_box_pack_start (GTK_BOX (parent_box), btn_formatdesc, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(btn_formatdesc), "clicked",
@@ -538,7 +540,7 @@ void quotefmt_add_defaults_button(GtkWindow *parent_window,
 
 	btn_formatdesc = gtk_button_new_with_mnemonic (_("Defaults"));
 	gtk_button_set_image (GTK_BUTTON(btn_formatdesc),
-		gtk_image_new_from_stock(GTK_STOCK_UNDO, GTK_ICON_SIZE_BUTTON));
+		gtk_image_new_from_icon_name("edit-undo", GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (btn_formatdesc);
 	gtk_box_pack_end (GTK_BOX (parent_box), btn_formatdesc, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(btn_formatdesc), "clicked",
