@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <string.h>
+#include <dirent.h>
 #ifdef HAVE_SVG
 #include <librsvg/rsvg.h>
 #include <math.h>
@@ -235,18 +236,6 @@
 #include "pixmaps/mark_read.xpm"
 #include "pixmaps/mark_unread.xpm"
 
-typedef struct _PrivPixmapData	PrivPixmapData;
-
-struct _PrivPixmapData
-{
-	gchar **data;
-	cairo_surface_t *pixmap;
-	cairo_pattern_t *mask;
-	gchar *file;
-	gchar *icon_path;
-	GdkPixbuf *pixbuf;
-};
-
 typedef struct _StockPixmapData	StockPixmapData;
 
 struct _StockPixmapData
@@ -263,10 +252,6 @@ typedef struct _OverlayData OverlayData;
 
 struct _OverlayData
 {
-	gboolean is_pixmap;
-	cairo_surface_t *base_pixmap;
-	cairo_surface_t *overlay_pixmap;
-
 	GdkPixbuf *base_pixbuf;
 	GdkPixbuf *overlay_pixbuf;
 
@@ -282,18 +267,6 @@ struct _OverlayData
 
 static void stock_pixmap_find_themes_in_dir(GList **list, const gchar *dirname);
 
-static PrivPixmapData privpixmaps[] =
-{
-    {claws_mail_icon_xpm              , NULL, NULL, "claws_mail_icon", NULL, NULL},
-    {claws_mail_icon_64_xpm           , NULL, NULL, "claws_mail_icon_64", NULL, NULL},
-#ifndef GENERIC_UMPC
-    {claws_mail_logo_xpm              , NULL, NULL, "claws_mail_logo", NULL, NULL},
-#else
-    {claws_mail_logo_small_xpm        , NULL, NULL, "claws_mail_logo_small", NULL, NULL},
-#endif
-    {empty_xpm                        , NULL, NULL, "empty", NULL, NULL}
-};
-
 static StockPixmapData pixmaps[] =
 {
     {addr_one_xpm                     , NULL, NULL, "addr_one", NULL, NULL},
@@ -435,12 +408,19 @@ static StockPixmapData pixmaps[] =
     {privacy_emblem_failed_xpm        , NULL, NULL, "privacy_emblem_failed", NULL, NULL},
     {privacy_emblem_warn_xpm          , NULL, NULL, "privacy_emblem_warn", NULL, NULL},
     {mime_message_xpm                 , NULL, NULL, "mime_message", NULL, NULL},
+    {claws_mail_icon_xpm              , NULL, NULL, "claws_mail_icon", NULL, NULL},
+    {claws_mail_icon_64_xpm           , NULL, NULL, "claws_mail_icon_64", NULL, NULL},
     {read_xpm                         , NULL, NULL, "read", NULL, NULL},
     {delete_btn_xpm                   , NULL, NULL, "delete_btn", NULL, NULL},
     {delete_dup_btn_xpm               , NULL, NULL, "delete_dup_btn", NULL, NULL},
     {cancel_xpm                       , NULL, NULL, "cancel", NULL, NULL},
     {trash_btn_xpm                    , NULL, NULL, "trash_btn", NULL, NULL},
     {claws_mail_compose_logo_xpm      , NULL, NULL, "claws_mail_compose_logo", NULL, NULL},
+#ifndef GENERIC_UMPC
+    {claws_mail_logo_xpm              , NULL, NULL, "claws_mail_logo", NULL, NULL},
+#else
+    {claws_mail_logo_small_xpm        , NULL, NULL, "claws_mail_logo_small", NULL, NULL},
+#endif
     {dir_noselect_close_xpm           , NULL, NULL, "dir_noselect_close", NULL, NULL},
     {dir_noselect_close_mark_xpm      , NULL, NULL, "dir_noselect_close_mark", NULL, NULL},
     {dir_noselect_open_xpm            , NULL, NULL, "dir_noselect_open", NULL, NULL},
@@ -507,18 +487,6 @@ const char **stock_pixmap_theme_extensions(void)
 }
 
 /* return newly constructed GtkPixmap from GdkPixmap */
-GtkWidget *priv_pixmap_widget(PrivPixmap icon)
-{
-	GdkPixbuf *pixbuf;
-
-	cm_return_val_if_fail(icon < N_PRIV_PIXMAPS, NULL);
-
-	if (priv_pixbuf_gdk(icon, &pixbuf) != -1)
-		return gtk_image_new_from_pixbuf(pixbuf);
-
-	return NULL;
-}
-
 GtkWidget *stock_pixmap_widget(StockPixmap icon)
 {
 	GdkPixbuf *pixbuf;
@@ -541,26 +509,6 @@ GtkWidget *stock_pixmap_widget(StockPixmap icon)
  */
 void render_scaled_proportionally(RsvgHandle *handle, cairo_t *cr, int width, int height)
 {
-#if LIBRSVG_CHECK_VERSION(2, 46, 0)
-	if (cairo_status(cr) == CAIRO_STATUS_SUCCESS) {
-		const RsvgRectangle viewport = {
-			.x = 0,
-			.y = 0,
-			.width = width,
-			.height = height,
-		};
-		GError *err = NULL;
-
-		cairo_rectangle(cr, 0, 0, width, height);
-		cairo_clip(cr);
-
-		rsvg_handle_render_document(handle, cr, &viewport, &err);
-		if (err != NULL) {
-			g_warning("unable to render SVG document (%d): %s", err->code, err->message);
-			g_error_free(err);
-		}
-	}
-#else
 	RsvgDimensionData dimensions;
 	double x_factor, y_factor;
 	double scale_factor;
@@ -575,7 +523,6 @@ void render_scaled_proportionally(RsvgHandle *handle, cairo_t *cr, int width, in
 	cairo_scale(cr, scale_factor, scale_factor);
 
 	rsvg_handle_render_cairo(handle, cr);
-#endif
 }
 
 /*
@@ -694,19 +641,11 @@ GdkPixbuf *pixbuf_from_svg_like_icon(char *filename, GError **error, StockPixmap
 			height = (int) floor(factor * height);
 		}
 	} else { /* render using SVG size */
-#if LIBRSVG_CHECK_VERSION(2, 52, 0)
-		double svg_width, svg_height;
-
-		rsvg_handle_get_intrinsic_size_in_pixels(handle, &svg_width, &svg_height);
-		width = (int) svg_width;
-		height = (int) svg_height;
-#else
 		RsvgDimensionData dimension;
 
 		rsvg_handle_get_dimensions (handle, &dimension);
 		width = dimension.width;
 		height = dimension.height;
-#endif
 	}
 
 	/* create drawing context */
@@ -737,30 +676,6 @@ GdkPixbuf *pixbuf_from_svg_like_icon(char *filename, GError **error, StockPixmap
 /*!
  *\brief
  */
-gint priv_pixbuf_gdk(PrivPixmap icon, GdkPixbuf **pixbuf)
-{
-	PrivPixmapData *pix_d;
-
-	if (pixbuf)
-		*pixbuf = NULL;
-
-	cm_return_val_if_fail(icon < N_PRIV_PIXMAPS, -1);
-
-	pix_d = &privpixmaps[icon];
-
-	if (!pix_d->pixbuf)
-		pix_d->pixbuf = gdk_pixbuf_new_from_xpm_data((const gchar **) pix_d->data);
-
-	cm_return_val_if_fail(pix_d->pixbuf != NULL, -1);
-
-	if (pixbuf)
-		*pixbuf = pix_d->pixbuf;
-
-	/* pixbuf should have one ref outstanding */
-
-	return 0;
-}
-
 gint stock_pixbuf_gdk(StockPixmap icon, GdkPixbuf **pixbuf)
 {
 	StockPixmapData *pix_d;
@@ -885,21 +800,15 @@ static void stock_pixmap_find_themes_in_dir(GList **list, const gchar *dirname)
 
 gchar *stock_pixmap_get_system_theme_dir_for_theme(const gchar *theme)
 {
-	if (theme && *theme) {
+	const gchar *sep = NULL;
+	if (theme && *theme)
+		sep = G_DIR_SEPARATOR_S;
 #ifndef G_OS_WIN32
-		return g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
-	        	   PIXMAP_THEME_DIR, G_DIR_SEPARATOR_S, theme, NULL);
+	return g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
+	        	   PIXMAP_THEME_DIR, sep, theme, NULL);
 #else
-		return g_strconcat(w32_get_themes_dir(), G_DIR_SEPARATOR_S, theme, NULL);
+	return g_strconcat(w32_get_themes_dir(), sep, theme, NULL);
 #endif
-	} else {
-#ifndef G_OS_WIN32
-		return g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
-	        	   PIXMAP_THEME_DIR, NULL);
-#else
-		return g_strdup(w32_get_themes_dir());
-#endif
-	}
 }
 
 GList *stock_pixmap_themes_list_new(void)
@@ -935,6 +844,25 @@ void stock_pixmap_themes_list_free(GList *list)
 	g_list_free(list);
 }
 
+void stock_pixmap_invalidate_all_icons(void)
+{
+	StockPixmapData *pix_d;
+	int i = 0;
+
+	while (i < N_STOCK_PIXMAPS) {
+		pix_d = &pixmaps[i];
+		if (pix_d->pixbuf) {
+			g_object_unref(G_OBJECT(pix_d->pixbuf));
+			pix_d->pixbuf = NULL;
+		}
+		if (pix_d->pixmap) {
+			g_object_unref(G_OBJECT(pix_d->pixmap));
+			pix_d->pixmap = NULL;
+		}
+		i++;
+	}
+}
+
 gchar *stock_pixmap_get_name (StockPixmap icon)
 {
 	if (icon >= N_STOCK_PIXMAPS)
@@ -944,17 +872,6 @@ gchar *stock_pixmap_get_name (StockPixmap icon)
 
 }
 
-PrivPixmap priv_pixmap_get_icon (gchar *file)
-{
-	gint i;
-
-	for (i = 0; i < N_PRIV_PIXMAPS; i++) {
-		if (strcmp (pixmaps[i].file, file) == 0)
-			return i;
-	}
-	return -1;
-}
-
 StockPixmap stock_pixmap_get_icon (gchar *file)
 {
 	gint i;
@@ -973,11 +890,7 @@ static gboolean do_pix_draw(GtkWidget *widget, cairo_t *cr,
 	gint left = 0;
 	gint top = 0;
 
-	if (data->is_pixmap) {
-		cm_return_val_if_fail(data->base_pixmap != NULL, FALSE);
-	} else {
-		cm_return_val_if_fail(data->base_pixbuf != NULL, FALSE);
-	}
+	cm_return_val_if_fail(data->base_pixbuf != NULL, FALSE);
 
 	if (data->highlight) {
 		MainWindow *mw = NULL;
@@ -1000,15 +913,8 @@ static gboolean do_pix_draw(GtkWidget *widget, cairo_t *cr,
 		}
 	}
 
-	if (data->is_pixmap) {
-		cairo_set_source_surface(cr, data->base_pixmap, data->border_x, data->border_y);
-		cairo_pattern_set_extend(cairo_get_source(cr), CAIRO_EXTEND_REPEAT);
-		cairo_rectangle(cr, data->border_x, data->border_y, data->base_width, data->base_height);
-		cairo_fill(cr);
-	} else {
-		gdk_cairo_set_source_pixbuf(cr, data->base_pixbuf, data->border_x, data->border_y);
-		cairo_paint(cr);
-	}
+	gdk_cairo_set_source_pixbuf(cr, data->base_pixbuf, data->border_x, data->border_y);
+	cairo_paint(cr);
 
 	if (data->position != OVERLAY_NONE) {
 
@@ -1059,50 +965,25 @@ static gboolean do_pix_draw(GtkWidget *widget, cairo_t *cr,
 	}
 
 	if (data->position != OVERLAY_NONE) {
-		if (data->is_pixmap) {
-			cm_return_val_if_fail(data->overlay_pixmap != NULL, FALSE);
-			cairo_set_source_surface(cr, data->overlay_pixmap, left, top);
-			cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
-			cairo_rectangle (cr, left, top, data->overlay_width, data->overlay_height);
-			cairo_fill(cr);
-		} else {
-      cm_return_val_if_fail(data->overlay_pixbuf != NULL, FALSE);
-      gdk_cairo_set_source_pixbuf(cr, data->overlay_pixbuf, left, top);
-      cairo_paint(cr);
-		}
+     cm_return_val_if_fail(data->overlay_pixbuf != NULL, FALSE);
+     gdk_cairo_set_source_pixbuf(cr, data->overlay_pixbuf, left, top);
+     cairo_paint(cr);
 	}
 
 	return TRUE;
 }
 
-static gboolean pixmap_with_overlay_expose_event_cb(GtkWidget *widget, GdkEventExpose *expose,
-                                                   OverlayData *data)
+static gboolean pixmap_with_overlay_expose_event_cb(GtkWidget *widget, cairo_t *cr,
+						    OverlayData *data)
 {
-	cairo_t *cr;
-	GdkWindow *drawable = gtk_widget_get_window(widget);
-	gboolean result;
-
-	cr = gdk_cairo_create(drawable);
-	gdk_window_clear_area (drawable, expose->area.x, expose->area.y,
-                               expose->area.width, expose->area.height);
-
-	result = do_pix_draw(widget, cr, data);
-	cairo_destroy(cr);
-	return result;
+	return do_pix_draw(widget, cr, data);
 }
 
 static void pixmap_with_overlay_destroy_cb(GtkWidget *object, OverlayData *data)
 {
-	if (data->is_pixmap) {
-		cairo_surface_destroy(data->base_pixmap);
-		if (data->position != OVERLAY_NONE) {
-			cairo_surface_destroy(data->overlay_pixmap);
-		}
-	} else {
-		g_object_unref(data->base_pixbuf);
-		if (data->position != OVERLAY_NONE) {
-			g_object_unref(data->overlay_pixbuf);
-		}
+	g_object_unref(data->base_pixbuf);
+	if (data->position != OVERLAY_NONE) {
+		g_object_unref(data->overlay_pixbuf);
 	}
 	g_free(data);
 }
@@ -1124,73 +1005,41 @@ GtkWidget *stock_pixmap_widget_with_overlay(StockPixmap icon,
 					    StockPixmap overlay, OverlayPosition pos,
 					    gint border_x, gint border_y)
 {
-	cairo_surface_t *stock_pixmap = NULL;
 	GdkPixbuf *stock_pixbuf = NULL;
 	GtkWidget *widget = NULL;
 	GtkWidget *stock_wid = NULL;
-	GtkRequisition requisition;
+	gint height, width;
 	OverlayData *data = NULL;
 
 	data = g_new0(OverlayData, 1);
 
 	stock_wid = stock_pixmap_widget(icon);
 	g_object_ref_sink(stock_wid);
-	gtk_widget_get_requisition(stock_wid, &requisition);
 
-	if (gtk_image_get_storage_type(GTK_IMAGE(stock_wid)) == GTK_IMAGE_PIXMAP)
-		data->is_pixmap = TRUE;
-	else
-		data->is_pixmap = FALSE;
+	stock_pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(stock_wid));
+	g_object_ref(stock_pixbuf);
 
-	if (data->is_pixmap) {
-		cairo_t *cr = gdk_cairo_create(gtk_widget_get_window(stock_wid));
-		stock_pixmap = cairo_get_target(cr);
-		cairo_surface_reference(stock_pixmap);
-		cairo_destroy(cr);
-		data->base_pixmap = stock_pixmap;
-		data->base_height = requisition.height;
-		data->base_width  = requisition.width;
-		g_object_unref(stock_wid);
+	height = gdk_pixbuf_get_height(stock_pixbuf);
+	width = gdk_pixbuf_get_width(stock_pixbuf);
 
-		if (pos == OVERLAY_NONE) {
-			data->overlay_pixmap = NULL;
-		} else {
-			stock_wid = stock_pixmap_widget(overlay);
-			g_object_ref_sink(stock_wid);
+	data->base_pixbuf = stock_pixbuf;
+	data->base_height = height;
+	data->base_width  = width;
+	g_object_unref(stock_wid);
 
-			cr = gdk_cairo_create(gtk_widget_get_window(stock_wid));
-			stock_pixmap = cairo_get_target(cr);
-			cairo_surface_reference(stock_pixmap);
-			cairo_destroy(cr);
-			data->overlay_pixmap = stock_pixmap;
-			data->overlay_height = requisition.height;
-			data->overlay_width  = requisition.width;
+	if (pos != OVERLAY_NONE) {
+		stock_wid = stock_pixmap_widget(overlay);
+		g_object_ref_sink(stock_wid);
 
-			g_object_unref(stock_wid);
-		}
-	} else {
-		data->is_pixmap = FALSE;
 		stock_pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(stock_wid));
 		g_object_ref(stock_pixbuf);
-		data->base_pixbuf = stock_pixbuf;
-		data->base_height = requisition.height;
-		data->base_width  = requisition.width;
+		data->overlay_pixbuf = stock_pixbuf;
+		data->overlay_height = height;
+		data->overlay_width  = width;
+
 		g_object_unref(stock_wid);
-		if (pos == OVERLAY_NONE) {
-			data->overlay_pixmap = NULL;
-		} else {
-			stock_wid = stock_pixmap_widget(overlay);
-			g_object_ref_sink(stock_wid);
-
-			stock_pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(stock_wid));
-			g_object_ref(stock_pixbuf);
-			data->overlay_pixbuf = stock_pixbuf;
-			data->overlay_height = requisition.height;
-			data->overlay_width  = requisition.width;
-
-			g_object_unref(stock_wid);
-		}
 	}
+
 	data->position = pos;
 	data->border_x = border_x;
 	data->border_y = border_y;
@@ -1199,11 +1048,10 @@ GtkWidget *stock_pixmap_widget_with_overlay(StockPixmap icon,
 	widget = gtk_drawing_area_new();
 	gtk_widget_set_size_request(widget, data->base_width + border_x * 2,
 			      data->base_height + border_y * 2);
-	g_signal_connect(G_OBJECT(widget), "expose_event",
+	g_signal_connect(G_OBJECT(widget), "draw",
 			 G_CALLBACK(pixmap_with_overlay_expose_event_cb), data);
 	g_signal_connect(G_OBJECT(widget), "destroy",
 			 G_CALLBACK(pixmap_with_overlay_destroy_cb), data);
 	g_object_set_data(G_OBJECT(widget), "highlight", &(data->highlight));
 	return widget;
-
 }
