@@ -320,8 +320,8 @@ static void undo_add(const gchar *text,
 
 	undo_check_size(undostruct);
 
-	vadj = GTK_ADJUSTMENT(gtk_text_view_get_vadjustment(
-				GTK_TEXT_VIEW(undostruct->textview)));
+	vadj = GTK_ADJUSTMENT(gtk_scrollable_get_vadjustment(
+				GTK_SCROLLABLE(undostruct->textview)));
 	undoinfo = undo_object_new(g_strdup(text), start_pos, end_pos, action,
 				   gtk_adjustment_get_value(vadj));
 
@@ -376,7 +376,7 @@ void undo_undo(UndoMain *undostruct)
 
 	/* Move the view (scrollbars) to the correct position */
 	gtk_adjustment_set_value
-		(GTK_ADJUSTMENT(gtk_text_view_get_vadjustment(textview)),
+		(GTK_ADJUSTMENT(gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(textview))),
 		 undoinfo->window_position);
 	
 	switch (undoinfo->action) {
@@ -471,7 +471,7 @@ void undo_redo(UndoMain *undostruct)
 	gtk_text_buffer_place_cursor(buffer, &iter);
 
 	/* Move the view to the right position. */
-	gtk_adjustment_set_value(gtk_text_view_get_vadjustment(textview), 
+	gtk_adjustment_set_value(gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(textview)), 
 				 redoinfo->window_position);
 
 	switch (redoinfo->action) {
