@@ -1,6 +1,7 @@
 /*
- * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2022 the Claws Mail team and Colin Leroy
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2019 Colin Leroy <colin@colino.net>
+ * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -167,8 +168,8 @@ static PrefParam template_params[] = {
 	 &tmpl.smtpuser, P_STRING, NULL, NULL, NULL},
 	{"smtppass", "",
 	 &tmpl.smtppass, P_STRING, NULL, NULL, NULL},
-	{"recvtype", "0",
-	 &tmpl.recvtype, P_ENUM, NULL, NULL, NULL},
+	{"recvtype", A_POP3,
+	 &tmpl.recvtype, P_INT, NULL, NULL, NULL},
 	{"recvserver", "pop.$DOMAIN",
 	 &tmpl.recvserver, P_STRING, NULL, NULL, NULL},
 	{"recvuser", "$LOGIN",
@@ -238,7 +239,7 @@ static gchar *accountrc_tmpl =
 	"\n"
 	"#recvtype can be:\n"
 	"#0 for pop3\n"
-	"#1  for imap\n"
+	"#2  for imap\n"
 	"#3  for a local mbox file\n"
 	"#recvtype=\n"
 	"\n"
@@ -272,26 +273,26 @@ static gchar *accountrc_tmpl =
 	"#mailbox=\n"
 	"\n"
 	"#whether to use encryption on SMTP connections\n"
-	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
 	"#smtpssl=\n"
 	"\n"
 	"#whether to use encryption on POP3 or IMAP connections\n"
-	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
 	"#recvssl=\n"
 	"\n"
-	"#TLS client certificate path for SMTP\n"
+	"#SSL/TLS client certificate path for SMTP\n"
 	"#default is empty (no certificate)\n"
 	"#smtpssl_cert=\n"
 	"\n"
-	"#TLS client certificate path for POP/IMAP\n"
+	"#SSL/TLS client certificate path for POP/IMAP\n"
 	"#default is empty (no certificate)\n"
 	"#recvssl_cert=\n"
 	"\n"
-	"#TLS client certificate password for SMTP\n"
+	"#SSL/TLS client certificate password for SMTP\n"
 	"#default is empty (no password)\n"
 	"#smtpssl_cert_pass=\n"
 	"\n"
-	"#TLS client certificate password for POP/IMAP\n"
+	"#SSL/TLS client certificate password for POP/IMAP\n"
 	"#default is empty (no password)\n"
 	"#recvssl_cert_pass=\n"
 	;
@@ -537,7 +538,7 @@ static void write_welcome_email(WizardWindow *wizard)
 		"Face: %s\n"
 		"Content-Type: text/plain; charset=UTF-8\n",
 		enc_from_name,
-		WELCOME_MSG_ADDR,
+		USERS_ML_ADDR,
 		enc_to_name,
 		gtk_entry_get_text(GTK_ENTRY(wizard->email)),
 		date, enc_subject, XFACE, FACE);
@@ -843,12 +844,12 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 	GtkWidget *image;
 	char *title_string;
 
-	vbox = gtk_vbox_new (FALSE, 6);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_set_border_width  (GTK_CONTAINER(vbox), 10);
 
 	/* create the titlebar */
-	hbox = gtk_hbox_new (FALSE, 12);
-	image = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_ICON);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
+	image = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_ICON);
 	gtk_box_pack_start (GTK_BOX(hbox), image, FALSE, FALSE, 0);
      	title_string = g_strconcat ("<span size=\"xx-large\" weight=\"ultrabold\">", title ? title : "", "</span>", NULL);
 	w = gtk_label_new (title_string);
@@ -860,7 +861,7 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
 	/* pack the separator */
-	gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), FALSE, FALSE, 0);
 
 	/* pack space */
 	w = gtk_alignment_new (0, 0, 0, 0);
@@ -873,8 +874,7 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 #define PACK_BOX(hbox,text,entry) {					\
 	GtkWidget *label = gtk_label_new(text);				\
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);		\
-	if (GTK_IS_MISC(label))						\
-		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);	\
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);			\
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);	\
 	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);	\
 }
@@ -954,54 +954,56 @@ static void wizard_email_changed(GtkWidget *widget, gpointer data)
 
 static GtkWidget* user_page (WizardWindow * wizard)
 {
-	GtkWidget *table = gtk_table_new(1,1, FALSE);
+	GtkWidget *table = gtk_grid_new();
 	GtkWidget *vbox;
 	GtkWidget *label;
 	GtkWidget *user_table;
 	
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 4);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 
-	vbox = gtk_vbox_new(FALSE, VSPACING_NARROW);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), VSPACING_NARROW_2);
 
-	gtk_table_attach(GTK_TABLE(table), vbox, 0,1,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), vbox, 0, 1, 1, 1);
 
-	user_table = gtk_table_new(3, 2, FALSE);
-	gtk_table_set_row_spacings(GTK_TABLE(user_table), VSPACING_NARROW);
+	user_table = gtk_grid_new();
+	gtk_grid_set_row_spacing(GTK_GRID(user_table), VSPACING_NARROW);
 	gtk_box_pack_start(GTK_BOX(vbox), user_table, FALSE, FALSE, 0);
 
 	label = gtk_label_new(g_strconcat("<span weight=\"bold\">", _("Your name:"),
 					  "</span>", NULL));
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
-	gtk_table_attach(GTK_TABLE(user_table), label, 0,1,0,1, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_grid_attach(GTK_GRID(user_table), label, 0, 0, 1, 1);
+
 	wizard->full_name = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->full_name), tmpl.name?tmpl.name:"");
-	gtk_table_attach(GTK_TABLE(user_table), wizard->full_name, 1,2,0,1, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(user_table), wizard->full_name, 1, 0, 1, 1);
+	gtk_widget_set_hexpand(wizard->full_name, TRUE);
+	gtk_widget_set_halign(wizard->full_name, GTK_ALIGN_FILL);
 
 	label = gtk_label_new(g_strconcat("<span weight=\"bold\">", _("Your email address:"),
 					  "</span>", NULL));
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
-	gtk_table_attach(GTK_TABLE(user_table), label, 0,1,1,2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_grid_attach(GTK_GRID(user_table), label, 0, 1, 1, 1);
+
 	wizard->email = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->email), tmpl.email?tmpl.email:"");
-	gtk_table_attach(GTK_TABLE(user_table), wizard->email, 1,2,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(user_table), wizard->email, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(wizard->email, TRUE);
+	gtk_widget_set_halign(wizard->email, GTK_ALIGN_FILL);
 
 	label = gtk_label_new(_("Your organization:"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
-	gtk_table_attach(GTK_TABLE(user_table), label, 0,1,2,3, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_grid_attach(GTK_GRID(user_table), label, 0, 2, 1, 1);
+
 	wizard->organization = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->organization), tmpl.organization?tmpl.organization:"");
-	gtk_table_attach(GTK_TABLE(user_table), wizard->organization, 1,2,2,3, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(user_table), wizard->organization, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(wizard->organization, TRUE);
+	gtk_widget_set_halign(wizard->organization, GTK_ALIGN_FILL);
 	
 	g_signal_connect(G_OBJECT(wizard->email), "changed",
 			 G_CALLBACK(wizard_email_changed),
@@ -1011,29 +1013,27 @@ static GtkWidget* user_page (WizardWindow * wizard)
 
 static GtkWidget* mailbox_page (WizardWindow * wizard)
 {
-	GtkWidget *table = gtk_table_new(1,1, FALSE);
+	GtkWidget *table = gtk_grid_new();
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 4);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 
-	vbox = gtk_vbox_new(FALSE, VSPACING_NARROW);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), VSPACING_NARROW_2);
 
-	gtk_table_attach(GTK_TABLE(table), vbox, 0,1,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), vbox, 0, 1, 1, 1);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
 	wizard->mailbox_label = gtk_label_new(g_strconcat("<span weight=\"bold\">",
 							  _("Mailbox name:"), "</span>", NULL));
 	gtk_label_set_use_markup(GTK_LABEL(wizard->mailbox_label), TRUE);
-	if (GTK_IS_MISC(wizard->mailbox_label))						      
-		gtk_misc_set_alignment(GTK_MISC(wizard->mailbox_label), 1, 0.5);	      
-	wizard->mailbox_name = gtk_entry_new();
+	gtk_label_set_xalign(GTK_LABEL(wizard->mailbox_label), 1.0);
 
+	wizard->mailbox_name = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->mailbox_name), tmpl.mailbox?tmpl.mailbox:"");
 
 	CLAWS_SET_TIP(wizard->mailbox_name, _("You can also specify an absolute path, for example: "
@@ -1068,7 +1068,7 @@ static void cert_browse_cb(GtkWidget *widget, gpointer data)
 
 	utf8_filename = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 	if (!utf8_filename) {
-		g_warning("cert_browse_cb(): failed to convert character set");
+		g_warning("cert_browse_cb(): failed to convert character set.");
 		utf8_filename = g_strdup(filename);
 	}
 	gtk_entry_set_text(dest, utf8_filename);
@@ -1078,7 +1078,7 @@ static void cert_browse_cb(GtkWidget *widget, gpointer data)
 
 static GtkWidget* smtp_page (WizardWindow * wizard)
 {
-	GtkWidget *table = gtk_table_new(1, 1, FALSE);
+	GtkWidget *table = gtk_grid_new();
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *hbox_spc;
@@ -1090,16 +1090,15 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 #endif
 	gchar *text;
 	
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 4);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 
-	vbox = gtk_vbox_new(FALSE, VSPACING_NARROW);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), VSPACING_NARROW_2);
 
-	gtk_table_attach(GTK_TABLE(table), vbox, 0,1,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), vbox, 0, 1, 1, 1);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_server = gtk_entry_new();
 	text = get_default_server(wizard, "smtp");
@@ -1113,7 +1112,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	PACK_BOX(hbox, g_strconcat("<span weight=\"bold\">", _("SMTP server address:"),
 				   "</span>", NULL), wizard->smtp_server);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_auth = gtk_check_button_new_with_label(
 					_("Use authentication"));
@@ -1130,47 +1129,51 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	SET_TOGGLE_SENSITIVITY (wizard->smtp_auth, label);	
 	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	smtp_auth_table = gtk_table_new(2, 2, FALSE);
+
+	smtp_auth_table = gtk_grid_new();
 	SET_TOGGLE_SENSITIVITY (wizard->smtp_auth, smtp_auth_table);
 	gtk_box_pack_start(GTK_BOX(hbox), smtp_auth_table, TRUE, TRUE, 0);
 
 	wizard->smtp_username_label = gtk_label_new(_("SMTP username:"));
-	gtk_misc_set_alignment(GTK_MISC(wizard->smtp_username_label), 1, 0.5);	      
-	gtk_table_attach(GTK_TABLE(smtp_auth_table), wizard->smtp_username_label, 0,1,0,1, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(wizard->smtp_username_label), 1.0);
+	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_username_label, 0, 0, 1, 1);
+	
 	text = get_default_smtp_account(wizard);
 	wizard->smtp_username = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->smtp_username), text);
 	g_free(text);
-	gtk_table_attach(GTK_TABLE(smtp_auth_table), wizard->smtp_username, 1,2,0,1, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_username, 1, 0, 1, 1);
+	gtk_widget_set_hexpand(wizard->smtp_username, TRUE);
+	gtk_widget_set_halign(wizard->smtp_username, GTK_ALIGN_FILL);
 
 	wizard->smtp_password_label = gtk_label_new(_("SMTP password:"));
-	gtk_misc_set_alignment(GTK_MISC(wizard->smtp_password_label), 1, 0.5);	      
-	gtk_table_attach(GTK_TABLE(smtp_auth_table), wizard->smtp_password_label, 0,1,1,2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(wizard->smtp_password_label), 1.0);
+	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_password_label, 0, 1, 1, 1);
+
 	wizard->smtp_password = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->smtp_password), tmpl.smtppass?tmpl.smtppass:""); 
 	gtk_entry_set_visibility(GTK_ENTRY(wizard->smtp_password), FALSE);
-	gtk_table_attach(GTK_TABLE(smtp_auth_table), wizard->smtp_password, 1,2,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_password, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(wizard->smtp_password, TRUE);
+	gtk_widget_set_halign(wizard->smtp_password, GTK_ALIGN_FILL);
+
 #ifdef USE_GNUTLS
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_use_ssl = gtk_check_button_new_with_label(
-					_("Use TLS to connect to SMTP server"));
+					_("Use SSL/TLS to connect to SMTP server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->smtp_use_ssl),
 			tmpl.smtpssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_ssl, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	wizard->smtp_use_tls = gtk_check_button_new_with_label(
@@ -1180,47 +1183,54 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_tls, FALSE, FALSE, 0);
 	SET_TOGGLE_SENSITIVITY (wizard->smtp_use_ssl, wizard->smtp_use_tls);
 	
-	smtp_cert_table = gtk_table_new(3,3, FALSE);
+	smtp_cert_table = gtk_grid_new();
 	gtk_box_pack_start (GTK_BOX(vbox), smtp_cert_table, FALSE, FALSE, 4);
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client TLS certificate (optional)"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 0, 1, 1);
+
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	label = gtk_label_new(_("File"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), hbox, 0, 1, 1, 2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 1, 1, 1);
+
 	wizard->smtp_ssl_cert_file = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->smtp_ssl_cert_file), tmpl.smtpssl_cert?tmpl.smtpssl_cert:"");
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), wizard->smtp_ssl_cert_file, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), wizard->smtp_ssl_cert_file, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(wizard->smtp_ssl_cert_file, TRUE);
+	gtk_widget_set_halign(wizard->smtp_ssl_cert_file, GTK_ALIGN_FILL);
+
 	button = gtkut_get_browse_file_btn(_("Browse"));
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), button, 2, 3, 1, 2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), button, 2, 1, 1, 1);
+
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(cert_browse_cb), wizard->smtp_ssl_cert_file);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);	
 	label = gtk_label_new(_("Password"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), hbox, 0, 1, 2, 3, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 2, 1, 1);
+
 	wizard->smtp_ssl_cert_pass = gtk_entry_new();
 	gtk_entry_set_visibility(GTK_ENTRY(wizard->smtp_ssl_cert_pass), FALSE);
 	gtk_entry_set_text(GTK_ENTRY(wizard->smtp_ssl_cert_pass), tmpl.smtpssl_cert_pass?tmpl.smtpssl_cert_pass:"");
-	gtk_table_attach(GTK_TABLE(smtp_cert_table), wizard->smtp_ssl_cert_pass, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(smtp_cert_table), wizard->smtp_ssl_cert_pass, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(wizard->smtp_ssl_cert_pass, TRUE);
+	gtk_widget_set_halign(wizard->smtp_ssl_cert_pass, GTK_ALIGN_FILL);
+
 	SET_TOGGLE_SENSITIVITY (wizard->smtp_use_ssl, smtp_cert_table);
 	wizard->smtp_cert_table = smtp_cert_table;
 #endif
@@ -1454,7 +1464,7 @@ static void auto_configure_cb (GtkWidget *widget, gpointer data)
 
 static GtkWidget* recv_page (WizardWindow * wizard)
 {
-	GtkWidget *table = gtk_table_new(1,1, FALSE);
+	GtkWidget *table = gtk_grid_new();
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *hbox_spc;	
@@ -1474,24 +1484,23 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gchar *text;
 	gint index = 0;
 
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 8);
+	gtk_grid_set_row_spacing(GTK_GRID(table), 4);
+	gtk_grid_set_column_spacing(GTK_GRID(table), 8);
 
-	vbox = gtk_vbox_new(FALSE, VSPACING_NARROW);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, VSPACING_NARROW);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), VSPACING_NARROW_2);
 
-	gtk_table_attach(GTK_TABLE(table), vbox, 0,1,1,2, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(table), vbox, 0, 1, 1, 1);
 
-	recv_table = gtk_table_new(4, 2, FALSE); 
+	recv_table = gtk_grid_new(); 
 
 	gtk_box_pack_start(GTK_BOX(vbox), recv_table, FALSE, FALSE, 0);
 
 	label = gtk_label_new(g_strconcat("<span weight=\"bold\">", _("Server type:"), "</span>", NULL));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-	gtk_table_attach(GTK_TABLE(recv_table), label, 0,1,0,1, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), label, 0, 0, 1, 1);
+
 	wizard->recv_type = gtkut_sc_combobox_create(NULL, FALSE);
 	store = GTK_LIST_STORE(gtk_combo_box_get_model(
 			GTK_COMBO_BOX(wizard->recv_type)));
@@ -1517,18 +1526,17 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	g_signal_connect(G_OBJECT(wizard->recv_type), "changed",
 			 G_CALLBACK(wizard_protocol_changed),
 			 wizard);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_type, 1,2,0,1, 
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_type, 1, 0, 1, 1);
 
 #if defined USE_GNUTLS
 	auto_configure_btn = gtk_button_new_with_label(_("Auto-configure"));
 	auto_configure_cancel_btn = gtk_button_new_with_label(_("Cancel"));
-	gtk_table_attach(GTK_TABLE(recv_table), auto_configure_btn, 0,1,1,2,
-			GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), auto_configure_btn, 0, 1, 1, 1);
+
 	auto_configure_lbl = gtk_label_new("");
-	gtk_misc_set_alignment(GTK_MISC(auto_configure_lbl), 0, 0.5);
-	gtk_table_attach(GTK_TABLE(recv_table), auto_configure_lbl, 1,2,1,2,
-			GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(auto_configure_lbl), 0.0);
+	gtk_grid_attach(GTK_GRID(recv_table), auto_configure_lbl, 1, 1, 1, 1);
+
 	gtk_widget_show(auto_configure_btn);
 	gtk_widget_show(auto_configure_lbl);
 	wizard->auto_configure_lbl = auto_configure_lbl;
@@ -1542,10 +1550,10 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 
 	wizard->recv_label = gtk_label_new(g_strconcat("<span weight=\"bold\">",
 						_("Server address:"), "</span>", NULL));
-	gtk_misc_set_alignment(GTK_MISC(wizard->recv_label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(wizard->recv_label), 1.0);
 	gtk_label_set_use_markup(GTK_LABEL(wizard->recv_label), TRUE);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_label, 0,1,2,3,
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_label, 0, 2, 1, 1);
+
 	wizard->recv_server = gtk_entry_new();
 	text = get_default_server(wizard, "pop");
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_server), text);
@@ -1554,43 +1562,47 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	CLAWS_SET_TIP(wizard->recv_server,
 			     _("You can specify the port number by appending it at the end: "
 			       "\"mail.example.com:110\""));
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_server, 1,2,2,3,
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
-	
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_server, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(wizard->recv_server, TRUE);
+	gtk_widget_set_halign(wizard->recv_server, GTK_ALIGN_FILL);
+
 	wizard->recv_username_label = gtk_label_new(g_strconcat("<span weight=\"bold\">",
 								_("Username:"),"</span>", NULL));
-	gtk_misc_set_alignment(GTK_MISC(wizard->recv_username_label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(wizard->recv_username_label), 1.0);
 	gtk_label_set_use_markup(GTK_LABEL(wizard->recv_username_label), TRUE);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_username_label, 0,1,3,4,
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_username_label, 0, 3, 1, 1);
+
 	wizard->recv_username = gtk_entry_new();
 	text = get_default_account(wizard);
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_username), text);
 	g_free(text);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_username, 1,2,3,4,
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_username, 1, 3, 1, 1);
+	gtk_widget_set_hexpand(wizard->recv_username, TRUE);
+	gtk_widget_set_halign(wizard->recv_username, GTK_ALIGN_FILL);
 			 
 	wizard->recv_password_label = gtk_label_new(_("Password:"));
-	gtk_misc_set_alignment(GTK_MISC(wizard->recv_password_label), 1, 0.5);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_password_label, 0,1,4,5,
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_label_set_xalign(GTK_LABEL(wizard->recv_password_label), 1.0);
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_password_label, 0, 4, 1, 1);
+
 	wizard->recv_password = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_password), tmpl.recvpass?tmpl.recvpass:"");
 	gtk_entry_set_visibility(GTK_ENTRY(wizard->recv_password), FALSE);
-	gtk_table_attach(GTK_TABLE(recv_table), wizard->recv_password, 1,2,4,5,
-			 GTK_EXPAND|GTK_FILL, 0, 0, 0);	
+	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_password, 1, 4, 1, 1);
+	gtk_widget_set_hexpand(wizard->recv_password, TRUE);
+	gtk_widget_set_halign(wizard->recv_password, GTK_ALIGN_FILL);
+
 #ifdef USE_GNUTLS
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->recv_use_ssl = gtk_check_button_new_with_label(
-					_("Use TLS to connect to receiving server"));
+					_("Use SSL/TLS to connect to receiving server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->recv_use_ssl),
 			tmpl.recvssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_ssl, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);	
 	wizard->recv_use_tls = gtk_check_button_new_with_label(
@@ -1600,62 +1612,70 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_tls, FALSE, FALSE, 0);
 	SET_TOGGLE_SENSITIVITY (wizard->recv_use_ssl, wizard->recv_use_tls);
 
-	recv_cert_table = gtk_table_new(3,3, FALSE);
+	recv_cert_table = gtk_grid_new();
+	
 	gtk_box_pack_start (GTK_BOX(vbox), recv_cert_table, FALSE, FALSE, 4);
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client TLS certificate (optional)"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);	
-	gtk_table_attach(GTK_TABLE(recv_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 0, 1, 1);
+
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
+
 	label = gtk_label_new(_("File"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);	
-	gtk_table_attach(GTK_TABLE(recv_cert_table), hbox, 0, 1, 1, 2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 1, 1, 1);
 	wizard->recv_ssl_cert_file = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_ssl_cert_file), tmpl.recvssl_cert?tmpl.recvssl_cert:"");
-	gtk_table_attach(GTK_TABLE(recv_cert_table), wizard->recv_ssl_cert_file, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), wizard->recv_ssl_cert_file, 1, 1, 1, 1);
+	gtk_widget_set_hexpand(wizard->recv_ssl_cert_file, TRUE);
+	gtk_widget_set_halign(wizard->recv_ssl_cert_file, GTK_ALIGN_FILL);
+
 	button = gtkut_get_browse_file_btn(_("Browse"));
-	gtk_table_attach(GTK_TABLE(recv_cert_table), button, 2, 3, 1, 2, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), button, 2, 1, 1, 1);
+
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(cert_browse_cb), wizard->recv_ssl_cert_file);
 
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	label = gtk_label_new(_("Password"));
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-	gtk_table_attach(GTK_TABLE(recv_cert_table), hbox, 0, 1, 2, 3, 
-			 GTK_FILL, 0, VSPACING_NARROW, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 2, 1, 1);
+
 	wizard->recv_ssl_cert_pass = gtk_entry_new();
 	gtk_entry_set_visibility(GTK_ENTRY(wizard->recv_ssl_cert_pass), FALSE);
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_ssl_cert_pass), tmpl.recvssl_cert_pass?tmpl.recvssl_cert_pass:"");
-	gtk_table_attach(GTK_TABLE(recv_cert_table), wizard->recv_ssl_cert_pass, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
+	gtk_grid_attach(GTK_GRID(recv_cert_table), wizard->recv_ssl_cert_pass, 1, 2, 1, 1);
+	gtk_widget_set_hexpand(wizard->recv_ssl_cert_pass, TRUE);
+	gtk_widget_set_halign(wizard->recv_ssl_cert_pass, GTK_ALIGN_FILL);
+
 	SET_TOGGLE_SENSITIVITY (wizard->recv_use_ssl, recv_cert_table);	
 	wizard->recv_cert_table = recv_cert_table;
 #endif	
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->recv_imap_subdir = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_imap_subdir), tmpl.imapdir?tmpl.imapdir:"");
 	wizard->recv_imap_label = gtk_label_new(_("IMAP server directory:"));
-	gtk_misc_set_alignment(GTK_MISC(wizard->recv_imap_label), 1, 0.5);	      
+	gtk_label_set_xalign(GTK_LABEL(wizard->recv_imap_label), 1.0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_imap_label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_imap_subdir, TRUE, TRUE, 0);
 	
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	hbox_spc = gtk_hbox_new (FALSE, 0);
+	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	wizard->subsonly_checkbtn = gtk_check_button_new_with_label(
@@ -1664,7 +1684,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 			tmpl.subsonly);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->subsonly_checkbtn, FALSE, FALSE, 0);
 	
-	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->no_imap_warning = gtk_label_new(g_strconcat("<span weight=\"bold\">",
 			_("Warning: this version of Claws Mail\n"
@@ -1764,7 +1784,8 @@ static gint wizard_close_cb(GtkWidget *widget, GdkEventAny *event,
 
 #define PACK_WARNING(text) {						\
 	label = gtk_label_new(text);					\
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);			\
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);			\
+	gtk_label_set_yalign(GTK_LABEL(label), 0.0);			\
 	gtk_box_pack_end(GTK_BOX(widget), label, FALSE, FALSE, 0);	\
 }
 
@@ -1787,12 +1808,13 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	
 	wizard->window = gtk_dialog_new_with_buttons (_("Claws Mail Setup Wizard"),
 			NULL, 0, 
-			GTK_STOCK_GO_BACK, GO_BACK,
-			GTK_STOCK_GO_FORWARD, GO_FORWARD,
-			GTK_STOCK_SAVE, FINISHED,
-			GTK_STOCK_CANCEL, CANCEL,
+			_("_Previous"), GO_BACK,
+			_("_Next"), GO_FORWARD,
+			_("_Save"), FINISHED,
+			_("_Cancel"), CANCEL,
 			NULL);
 	gtk_window_set_position(GTK_WINDOW(wizard->window), GTK_WIN_POS_CENTER);
+	gtk_window_set_default_size(GTK_WINDOW(wizard->window), 390, 420);
 
 	g_signal_connect(wizard->window, "response", 
 			  G_CALLBACK(wizard_response_cb), wizard);
@@ -1821,7 +1843,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Welcome to Claws Mail"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
@@ -1844,8 +1866,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start(GTK_BOX(widget), scrolled_window, TRUE, TRUE, 0);
 
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window),
- 					      user_page(wizard));
+	gtk_container_add(GTK_CONTAINER(scrolled_window), user_page(wizard));
 	PACK_WARNING(_("Bold fields must be completed"));
 	
 	wizard->pages = g_slist_append(wizard->pages, widget);
@@ -1859,8 +1880,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start(GTK_BOX(widget), scrolled_window, TRUE, TRUE, 0);
 
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window),
- 					      recv_page(wizard));
+	gtk_container_add(GTK_CONTAINER(scrolled_window), recv_page(wizard));
 	PACK_WARNING(_("Bold fields must be completed"));
 	
 	wizard->pages = g_slist_append(wizard->pages, widget);
@@ -1874,8 +1894,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start(GTK_BOX(widget), scrolled_window, TRUE, TRUE, 0);
 
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window),
- 					      smtp_page(wizard));
+	gtk_container_add(GTK_CONTAINER(scrolled_window), smtp_page(wizard));
 	PACK_WARNING(_("Bold fields must be completed"));
 	
 	wizard->pages = g_slist_append(wizard->pages, widget);
@@ -1890,8 +1909,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_box_pack_start(GTK_BOX(widget), scrolled_window, TRUE, TRUE, 0);
 
-		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window),
- 					      mailbox_page(wizard));
+		gtk_container_add(GTK_CONTAINER(scrolled_window), mailbox_page(wizard));
 		PACK_WARNING(_("Bold fields must be completed"));
 	
 		wizard->pages = g_slist_append(wizard->pages, widget);
@@ -1903,7 +1921,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Configuration finished"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
